<?php

/**
 * This is the model class for table "{{activity}}".
 *
 * The followings are the available columns in table '{{activity}}':
 * @property integer $id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $notes
 * @property string $date_to_do
 * @property string $typ_of_activity
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property CompanyContact $contact
 * @property Company $company
 */
class Activity extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{activity}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('company_id, crm_user_id, contact_id, notes, date_to_do, typ_of_activity', 'required'),
            array('contact_id', 'numerical', 'integerOnly' => true),
            array('company_id', 'length', 'max' => 20),
            array('typ_of_activity, isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, company_id, contact_id, date_to_do, typ_of_activity, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'notes' => 'Notes',
            'date_to_do' => 'Date To Do',
            'typ_of_activity' => 'Typ Of Activity',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('company_id', Yii::app()->session['company_id']);
        $criteria->compare('contact_id', Yii::app()->session['contact_id']);
        $criteria->compare('date_to_do', $this->date_to_do);
        $criteria->compare('typ_of_activity', $this->typ_of_activity);
        $criteria->compare('isActive', $this->isActive);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.company_id',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    public function followups() {
        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('company_id', $this->company_id);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('date_to_do', $this->date_to_do);
        $criteria->compare('typ_of_activity', $this->typ_of_activity);
        $criteria->compare('isActive', $this->isActive);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.company_id',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }
    
    public function calls() {
        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('company_id', $this->company_id);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('date_to_do', $this->date_to_do);
        $criteria->compare('typ_of_activity', $this->typ_of_activity);
        $criteria->compare('isActive', $this->isActive);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.company_id',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Activity the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
