<?php

/**
 * This is the model class for table "{{allocated_materials}}".
 *
 * The followings are the available columns in table '{{allocated_materials}}':
 * @property integer $id
 * @property integer $product_id
 * @property integer $file_id
 * @property integer $count
 * @property string $allocation_date
 * @property string $allocated_from
 *
 * The followings are the available model relations:
 * @property MasterFile $file
 * @property Store $product
 */
class AllocatedMaterials extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{allocated_materials}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('product_id, file_id, count, allocation_date, allocated_from', 'required'),
			array('product_id, file_id, count', 'numerical', 'integerOnly'=>true),
			array('allocated_from', 'length', 'max'=>1),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, product_id, file_id, count, allocation_date, allocated_from', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
			'product' => array(self::BELONGS_TO, 'Store', 'product_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'product_id' => 'Product',
			'file_id' => 'File',
			'count' => 'Count',
			'allocation_date' => 'Allocation Date',
			'allocated_from' => 'Allocated From',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('file_id',$this->file_id);
		$criteria->compare('count',$this->count);
		$criteria->compare('allocation_date',$this->allocation_date,true);
		$criteria->compare('allocated_from',$this->allocated_from,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return AllocatedMaterials the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
