<?php

/**
 * This is the model class for table "{{company}}".
 *
 * The followings are the available columns in table '{{company}}':
 * @property string $id
 * @property integer $crm_user_id
 * @property string $company_name
 * @property string $billing_address
 * @property string $billing_city
 * @property string $billing_postalcode
 * @property string $billing_state
 * @property string $billing_country
 * @property string $billing_pinzip
 * @property string $shipping_address
 * @property string $shipping_city
 * @property string $shipping_state
 * @property string $shipping_country
 * @property string $shipping_postalcode
 * @property string $shipping_pinzip
 * @property string $facebook
 * @property string $skype
 * @property string $twitter
 * @property string $linkedin
 * @property string $instagram
 * @property string $myspace
 * @property string $youtube
 * @property string $googleplus
 * @property string $bank__taxid
 * @property string $bank_acno
 * @property string $bank_swift
 * @property string $bank_account_name
 * @property string $bank__name
 * @property string $bank__branch
 * @property string $bank_iban
 * @property string $bank_others
 * @property string $misc_notes
 * @property string $misc_email
 * @property string $misc_status
 * @property integer $pricing_group
 * @property string $genral_phno
 * @property string $genral_email
 * @property string $genral_location
 * @property string $genral_payment_term
 * @property string $genral_fax
 * @property string $genral_web
 * @property string $genral_industry
 * @property string $genral_latitude
 * @property string $genral_longitude
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property User $crmUser
 * @property CompanyContact[] $companyContacts
 * @property CreditNote[] $creditNotes
 * @property DeliveryNotes[] $deliveryNotes
 * @property Documents[] $documents
 * @property Event[] $events
 * @property GoodsReturn[] $goodsReturns
 * @property Invoice[] $invoices
 * @property Lead[] $leads
 * @property MasterFile[] $masterFiles
 * @property Order[] $orders
 * @property Quotes[] $quotes
 */
class Company extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{company}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, company_name, billing_address, billing_city,  
                billing_state, billing_country,  shipping_address, shipping_city, 
                shipping_state, shipping_country, bank__taxid, 
                bank_acno, bank_swift, bank_account_name, bank__name, bank__branch, bank_iban,bank_ifsc,
                pricing_group, genral_phno,genral_email, genral_location, genral_payment_term, 
                genral_fax, genral_industry,isActive', 'required'),
            array('crm_user_id, pricing_group', 'numerical', 'integerOnly' => true),
            array('company_name, billing_city, billing_postalcode, billing_state, billing_country, 
                billing_pinzip, shipping_address, shipping_city, shipping_state, shipping_country, 
                shipping_postalcode, shipping_pinzip, facebook, skype, twitter, linkedin, instagram, 
                myspace, youtube, googleplus, bank__taxid, bank_acno, bank_swift, bank_account_name, 
                bank__name, bank__branch, bank_iban, bank_others, misc_email, misc_status, genral_phno, 
                genral_email, genral_location, genral_payment_term, genral_fax, genral_web, genral_industry, 
                genral_latitude, genral_longitude', 'length', 'max' => 255),
            array('bank_id', 'numerical'),
            array('misc_notes', 'length', 'max' => 5000),
            array('isActive,shipping_address_same_as_billing', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, company_name, billing_address, billing_city, billing_postalcode, 
                billing_state, billing_country, billing_pinzip, shipping_address, shipping_city, 
                shipping_state, shipping_country, shipping_postalcode, shipping_pinzip, facebook, 
                skype, twitter, linkedin, instagram, myspace, youtube, googleplus, bank__taxid, 
                bank_acno, bank_swift, bank_account_name, bank__name, bank__branch, bank_iban, 
                bank_others, misc_notes, misc_email, misc_status, pricing_group, genral_phno, 
                genral_email, genral_location, genral_payment_term, genral_fax, genral_web, 
                genral_industry, genral_latitude, genral_longitude, isActive', 'safe', 'on' => 'search'),
            array('facebook,skype, twitter, linkedin, instagram, myspace, youtube, googleplus,genral_web', 'url', 'defaultScheme' => 'http'),
            array('misc_email,genral_email','email')
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'companyContacts' => array(self::HAS_MANY, 'CompanyContact', 'company_id'),
            'creditNotes' => array(self::HAS_MANY, 'CreditNote', 'company_id'),
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNotes', 'company_id'),
            'documents' => array(self::HAS_MANY, 'Documents', 'company_id'),
            'events' => array(self::HAS_MANY, 'Event', 'company_id'),
            'goodsReturns' => array(self::HAS_MANY, 'GoodsReturn', 'company_id'),
            'invoices' => array(self::HAS_MANY, 'Invoice', 'company_id'),
            'leads' => array(self::HAS_MANY, 'Lead', 'company_id'),
            'masterFiles' => array(self::HAS_MANY, 'MasterFile', 'company_id'),
            'orders' => array(self::HAS_MANY, 'Order', 'company_id'),
            'quotes' => array(self::HAS_MANY, 'Quotes', 'company_id'),
            'types' => array(self::HAS_MANY, 'CompanyTypeRelation', 'company_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'company_name' => 'Company Name',
            'billing_address' => 'Street Address',
            'billing_city' => 'Billing City',
            'billing_postalcode' => 'Postalcode',
            'billing_state' => 'State',
            'billing_country' => 'Country',
            'billing_pinzip' => 'Pin/Zip',
            'shipping_address' => 'Street Address',
            'shipping_city' => 'City',
            'shipping_state' => 'State',
            'shipping_country' => 'Country',
            'shipping_postalcode' => 'Postalcode',
            'shipping_pinzip' => 'Pin/Zip',
            'facebook' => 'Facebook',
            'skype' => 'Skype',
            'twitter' => 'Twitter',
            'linkedin' => 'Linkedin',
            'instagram' => 'Instagram',
            'myspace' => 'Myspace',
            'youtube' => 'Youtube',
            'googleplus' => 'Googleplus',
            'bank__taxid' => 'TaxId',
            'bank_acno' => 'Acc.No.',
            'bank_swift' => 'Swift Code',
            'bank_account_name' => 'Account Name',
            'bank__name' => 'Bank Name',
            'bank__branch' => 'Bank Branch',
            'bank_iban' => 'Iban No.',
            'bank_ifsc' => 'IFSC Code',
            'bank_others' => 'Other Details',
            'misc_notes' => 'Notes',
            'misc_email' => 'Other Email',
            'misc_status' => 'Status',
            'pricing_group' => 'Pricing Group',
            'genral_phno' => 'Phone No',
            'genral_email' => 'Email',
            'genral_location' => 'Location',
            'genral_payment_term' => 'Payment Term',
            'genral_fax' => 'Fax',
            'genral_web' => 'Website',
            'genral_industry' => 'Industry',
            'genral_latitude' => 'Latitude',
            'genral_longitude' => 'Longitude',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id, true);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('company_name', $this->company_name, true);
        $criteria->compare('billing_address', $this->billing_address, true);
        $criteria->compare('billing_city', $this->billing_city, true);
        $criteria->compare('billing_postalcode', $this->billing_postalcode, true);
        $criteria->compare('billing_state', $this->billing_state, true);
        $criteria->compare('billing_country', $this->billing_country, true);
        $criteria->compare('billing_pinzip', $this->billing_pinzip, true);
        $criteria->compare('shipping_address', $this->shipping_address, true);
        $criteria->compare('shipping_city', $this->shipping_city, true);
        $criteria->compare('shipping_state', $this->shipping_state, true);
        $criteria->compare('shipping_country', $this->shipping_country, true);
        $criteria->compare('shipping_postalcode', $this->shipping_postalcode, true);
        $criteria->compare('shipping_pinzip', $this->shipping_pinzip, true);
        $criteria->compare('facebook', $this->facebook, true);
        $criteria->compare('skype', $this->skype, true);
        $criteria->compare('twitter', $this->twitter, true);
        $criteria->compare('linkedin', $this->linkedin, true);
        $criteria->compare('instagram', $this->instagram, true);
        $criteria->compare('myspace', $this->myspace, true);
        $criteria->compare('youtube', $this->youtube, true);
        $criteria->compare('googleplus', $this->googleplus, true);
        $criteria->compare('bank__taxid', $this->bank__taxid, true);
        $criteria->compare('bank_acno', $this->bank_acno, true);
        $criteria->compare('bank_swift', $this->bank_swift, true);
        $criteria->compare('bank_account_name', $this->bank_account_name, true);
        $criteria->compare('bank__name', $this->bank__name, true);
        $criteria->compare('bank__branch', $this->bank__branch, true);
        $criteria->compare('bank_iban', $this->bank_iban, true);
        $criteria->compare('bank_others', $this->bank_others, true);
        $criteria->compare('misc_notes', $this->misc_notes, true);
        $criteria->compare('misc_email', $this->misc_email, true);
        $criteria->compare('misc_status', $this->misc_status, true);
        $criteria->compare('pricing_group', $this->pricing_group);
        $criteria->compare('genral_phno', $this->genral_phno, true);
        $criteria->compare('genral_email', $this->genral_email, true);
        $criteria->compare('genral_location', $this->genral_location, true);
        $criteria->compare('genral_payment_term', $this->genral_payment_term, true);
        $criteria->compare('genral_fax', $this->genral_fax, true);
        $criteria->compare('genral_web', $this->genral_web, true);
        $criteria->compare('genral_industry', $this->genral_industry, true);
        $criteria->compare('genral_latitude', $this->genral_latitude, true);
        $criteria->compare('genral_longitude', $this->genral_longitude, true);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.company_name',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Company the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public static function getCompanies() {
        $condition = 'isActive =  "Y"';
        $model = self::model()->findAll(array('condition' => $condition));
        return CHtml::listData($model, 'id', 'company_name');
    }
    public static function getVendors($type = array("C")) {
        $company_types = implode('","', $type);
        $condition = 'company.isActive =  "Y" and companyType.type_name in ("' . $company_types . '")';
        $model = CompanyTypeRelation::model()->with(array('companyType', 'company'))->findAll(array('condition' => $condition));
        return CHtml::listData($model, 'id','company.company_name');
    } 

    /* retuns full billing address */

    public function getBillingAddress() {
        return ($this->billing_address . ', ' .
                $this->billing_city . ', ' .
                $this->billing_postalcode . ', ' .
                $this->billing_state . ', ' .
                $this->billing_country . ', ' .
                $this->billing_pinzip
                );
    }

    /* retuns full shipping address */

    public function getShippingAddress() {
        return ($this->shipping_address . ', ' .
                $this->shipping_city . ', ' .
                $this->shipping_postalcode . ', ' .
                $this->shipping_state . ', ' .
                $this->shipping_country . ', ' .
                $this->shipping_pinzip
                );
    }

    /* retuns geo location */

    public function getGeoLoc() {
        return ($this->genral_latitude . ', ' .
                $this->genral_longitude
                );
    }

}
