<?php

/**
 * This is the model class for table "{{company_contact}}".
 *
 * The followings are the available columns in table '{{company_contact}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property string $company_id
 * @property string $person_name
 * @property string $designation
 * @property string $ph_no
 * @property integer $department
 * @property string $mobile1
 * @property string $mobile2
 * @property string $email1
 * @property string $email2
 * @property string $dob
 * @property integer $contact_method
 * @property string $notes
 * @property string $do_not_call
 * @property string $do_not_email
 * @property string $news_letter
 * @property string $facebook
 * @property string $skype
 * @property string $linkedin
 * @property string $instagram
 * @property string $googleplus
 * @property string $twitter
 * @property string $myspace
 * @property string $youtube
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property User $crmUser
 * @property Company $company
 * @property CreditNote[] $creditNotes
 * @property DeliveryNotes[] $deliveryNotes
 * @property Event[] $events
 * @property Quotes[] $quotes
 */
class CompanyContact extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{company_contact}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, company_id, person_name, designation, 
                ph_no, department,mobile1, email1,  
                dob, contact_method, notes, 
                ', 'required'),
            array('crm_user_id, department, contact_method', 'numerical', 'integerOnly' => true),
            array('company_id', 'length', 'max' => 20),
            array('person_name, designation, ph_no, mobile1, mobile2, email1, email2, 
                facebook, skype, linkedin, instagram, googleplus, twitter, myspace, youtube', 'length', 'max' => 255),
            array('do_not_call, do_not_email, news_letter, isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, company_id, person_name, designation, ph_no, 
                department, mobile1, mobile2, email1, email2, dob, contact_method, 
                notes, do_not_call, do_not_email, news_letter, facebook, skype, 
                linkedin, instagram, googleplus, twitter, myspace, youtube, isActive', 'safe', 'on' => 'search'),
            array('facebook, skype,linkedin, instagram, googleplus, twitter, myspace, youtube', 'url', 'defaultScheme' => 'http'),
            array('email1, email2', 'email')
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'creditNotes' => array(self::HAS_MANY, 'CreditNote', 'contact_id'),
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNotes', 'contact_id'),
            'events' => array(self::HAS_MANY, 'Event', 'contact_id'),
            'quotes' => array(self::HAS_MANY, 'Quotes', 'contact_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'company_id' => 'Company',
            'person_name' => 'Person Name',
            'designation' => 'Designation',
            'ph_no' => 'Ph No',
            'department' => 'Department',
            'mobile1' => 'Mobile1',
            'mobile2' => 'Mobile2',
            'email1' => 'Email1',
            'email2' => 'Email2',
            'dob' => 'DoB',
            'contact_method' => 'Contact Method',
            'notes' => 'Notes',
            'do_not_call' => 'Do Not Call',
            'do_not_email' => 'Do Not Email',
            'news_letter' => 'News Letter',
            'facebook' => 'Facebook',
            'skype' => 'Skype',
            'linkedin' => 'Linkedin',
            'instagram' => 'Instagram',
            'googleplus' => 'Googleplus',
            'twitter' => 'Twitter',
            'myspace' => 'Myspace',
            'youtube' => 'Youtube',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('company_id', Yii::app()->session['company_id'], true);
        $criteria->compare('person_name', $this->person_name, true);
        $criteria->compare('designation', $this->designation, true);
        $criteria->compare('ph_no', $this->ph_no, true);
        $criteria->compare('department', $this->department);
        $criteria->compare('mobile1', $this->mobile1, true);
        $criteria->compare('mobile2', $this->mobile2, true);
        $criteria->compare('email1', $this->email1, true);
        $criteria->compare('email2', $this->email2, true);
        $criteria->compare('dob', $this->dob, true);
        $criteria->compare('contact_method', $this->contact_method);
        $criteria->compare('notes', $this->notes, true);
        $criteria->compare('do_not_call', $this->do_not_call, true);
        $criteria->compare('do_not_email', $this->do_not_email, true);
        $criteria->compare('news_letter', $this->news_letter, true);
        $criteria->compare('facebook', $this->facebook, true);
        $criteria->compare('skype', $this->skype, true);
        $criteria->compare('linkedin', $this->linkedin, true);
        $criteria->compare('instagram', $this->instagram, true);
        $criteria->compare('googleplus', $this->googleplus, true);
        $criteria->compare('twitter', $this->twitter, true);
        $criteria->compare('myspace', $this->myspace, true);
        $criteria->compare('youtube', $this->youtube, true);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /* returning email ids */

    public function getEmailids() {
        return $this->email1 . ',' . $this->email2;
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return CompanyContact the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getFullname() {
        return $this->person_name;
    }

}
