<?php

/**
 * This is the model class for table "{{credit_note}}".
 *
 * The followings are the available columns in table '{{credit_note}}':
 * @property integer $id
 * @property integer $file_id
 * @property integer $crm_user_id
 * @property integer $invoice_id
 * @property string $company_id
 * @property integer $contact_id
 * @property integer $sales_group
 * @property double $exchange_rate
 * @property string $reference
 * @property string $currency
 * @property double $reduced_amount
 * @property double $final_addition_percentage
 * @property double $final_addition_amount
 * @property double $final_deduction_percentage
 * @property double $final_deduction_amount
 * @property integer $credit_final_amount
 * @property integer $credit_date
 * @property integer $reason
 * @property integer $goods_return_id
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property User $crmUser
 * @property Invoice $invoice
 * @property Company $company
 * @property MasterFile $file
 * @property CompanyContact $contact
 */
class CreditNote extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{credit_note}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('file_id, crm_user_id, invoice_id, company_id, contact_id, sales_group, exchange_rate, reference, currency, reduced_amount, credit_final_amount, credit_date, reason', 'required'),
			array('file_id, crm_user_id, invoice_id, contact_id, sales_group, credit_final_amount, credit_date, reason, goods_return_id', 'numerical', 'integerOnly'=>true),
			array('exchange_rate, reduced_amount, final_addition_percentage, final_addition_amount, final_deduction_percentage, final_deduction_amount', 'numerical'),
			array('company_id', 'length', 'max'=>20),
			array('reference, currency', 'length', 'max'=>255),
			array('isActive', 'length', 'max'=>1),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, file_id, crm_user_id, invoice_id, company_id, contact_id, sales_group, exchange_rate, reference, currency, reduced_amount, final_addition_percentage, final_addition_amount, final_deduction_percentage, final_deduction_amount, credit_final_amount, credit_date, reason, goods_return_id, isActive', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
			'invoice' => array(self::BELONGS_TO, 'Invoice', 'invoice_id'),
			'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
			'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
			'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'file_id' => 'File',
			'crm_user_id' => 'Crm User',
			'invoice_id' => 'Invoice',
			'company_id' => 'Company',
			'contact_id' => 'Contact',
			'sales_group' => 'Sales Group',
			'exchange_rate' => 'Exchange Rate',
			'reference' => 'Reference',
			'currency' => 'Currency',
			'reduced_amount' => 'Reduced Amount',
			'final_addition_percentage' => 'Final Addition Percentage',
			'final_addition_amount' => 'Final Addition Amount',
			'final_deduction_percentage' => 'Final Deduction Percentage',
			'final_deduction_amount' => 'Final Deduction Amount',
			'credit_final_amount' => 'Credit Final Amount',
			'credit_date' => 'Credit Date',
			'reason' => 'Reason',
			'goods_return_id' => 'Goods Return',
			'isActive' => 'Is Active',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('file_id',$this->file_id);
		$criteria->compare('crm_user_id',$this->crm_user_id);
		$criteria->compare('invoice_id',$this->invoice_id);
		$criteria->compare('company_id',$this->company_id,true);
		$criteria->compare('contact_id',$this->contact_id);
		$criteria->compare('sales_group',$this->sales_group);
		$criteria->compare('exchange_rate',$this->exchange_rate);
		$criteria->compare('reference',$this->reference,true);
		$criteria->compare('currency',$this->currency,true);
		$criteria->compare('reduced_amount',$this->reduced_amount);
		$criteria->compare('final_addition_percentage',$this->final_addition_percentage);
		$criteria->compare('final_addition_amount',$this->final_addition_amount);
		$criteria->compare('final_deduction_percentage',$this->final_deduction_percentage);
		$criteria->compare('final_deduction_amount',$this->final_deduction_amount);
		$criteria->compare('credit_final_amount',$this->credit_final_amount);
		$criteria->compare('credit_date',$this->credit_date);
		$criteria->compare('reason',$this->reason);
		$criteria->compare('goods_return_id',$this->goods_return_id);
		$criteria->compare('isActive',$this->isActive,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return CreditNote the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
