<?php

/**
 * This is the model class for table "{{delivery_notes}}".
 *
 * The followings are the available columns in table '{{delivery_notes}}':
 * @property integer $id
 * @property integer $file_id
 * @property integer $crm_user_id
 * @property string $company_id
 * @property integer $order_id
 * @property integer $contact_id
 * @property string $delivery_date
 * @property string $shipped_by
 * @property string $sales_group
 * @property string $awb_no
 * @property integer $no_of_boxes
 * @property string $tracking_no
 * @property string $total_weight
 * @property string $packed_by
 * @property string $shipping_conditions
 * @property string $lpo
 * @property string $others
 * @property string $delivery_status
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property DeliveryItem[] $deliveryItems
 * @property CompanyContact $contact
 * @property Order $order
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 * @property Invoice[] $invoices
 */
class DeliveryNote extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $company_name;
    public $shipping_by;
    public $billing_address;
    public $shipping_address;
    public $lead_owner_id;
    public $title;

    public function tableName() {
        return '{{delivery_note}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, company_id, contact_id, delivery_date, shipped_by, sales_group, awb_no, no_of_boxes, 
                tracking_no, total_weight, packed_by, shipping_conditions, lpo, others', 'required'),
            array('file_id, crm_user_id, order_id, contact_id, no_of_boxes', 'numerical', 'integerOnly' => true),
            array('company_id', 'length', 'max' => 20),
            //array('delivery_no', 'unique', 'on' => 'add'),
            array('shipped_by, sales_group, awb_no, tracking_no, packed_by, shipping_conditions, lpo, others', 'length', 'max' => 255),
            array('total_weight', 'length', 'max' => 10),
            array('delivery_status', 'length', 'max' => 8),
            array('isActive', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, file_id, crm_user_id, company_id, order_id, contact_id, delivery_date, 
                shipped_by, sales_group, awb_no, no_of_boxes, tracking_no, total_weight, 
                packed_by, shipping_conditions, lpo, others, delivery_status, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'items' => array(self::HAS_MANY, 'DeliveryNoteItem', 'delivery_note_id'),
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'order' => array(self::BELONGS_TO, 'Order', 'order_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'invoices' => array(self::HAS_MANY, 'Invoice', 'delivery_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'file_id' => 'File',
            'crm_user_id' => 'Crm User',
            'company_id' => 'Company',
            'order_id' => 'Order',
            'contact_id' => 'Contact',
            'delivery_date' => 'Delivery Date',
            'shipped_by' => 'Shipped By',
            'sales_group' => 'Sales Group',
            'awb_no' => 'Awb No',
            'no_of_boxes' => 'No Of Boxes',
            'tracking_no' => 'Tracking No',
            'total_weight' => 'Total Weight',
            'packed_by' => 'Packed By',
            'shipping_conditions' => 'Shipping Conditions',
            'lpo' => 'Lpo',
            'others' => 'Others',
            'delivery_status' => 'Delivery Status',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('file_id', $this->file_id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        if ((int) Yii::app()->session['company_id'] == 0)
            $criteria->compare('company_id', $this->company_id);
        else
            $criteria->compare('company_id', Yii::app()->session['company_id']);
        $criteria->compare('order_id', $this->order_id);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('delivery_date', $this->delivery_date, true);
        $criteria->compare('shipped_by', $this->shipped_by, true);
        $criteria->compare('sales_group', $this->sales_group, true);
        $criteria->compare('awb_no', $this->awb_no, true);
        $criteria->compare('no_of_boxes', $this->no_of_boxes);
        $criteria->compare('tracking_no', $this->tracking_no, true);
        $criteria->compare('total_weight', $this->total_weight, true);
        $criteria->compare('packed_by', $this->packed_by, true);
        $criteria->compare('shipping_conditions', $this->shipping_conditions, true);
        $criteria->compare('lpo', $this->lpo, true);
        $criteria->compare('others', $this->others, true);
        $criteria->compare('delivery_status', $this->delivery_status, true);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.file_id,t.company_id,t.delivery_date DESC',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    public function forInvoiceSearch() {
        $criteria = new CDbCriteria;
        if (isset(Yii::app()->session['file_id']))
            $criteria->condition = 'file_id=' . Yii::app()->session['file_id'];
        else
            $criteria->condition = 'file_id=0';
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.file_id,t.company_id,t.delivery_date DESC',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return DeliveryNote the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
