<?php

/**
 * This is the model class for table "{{delivery_item}}".
 *
 * The followings are the available columns in table '{{delivery_item}}':
 * @property integer $id
 * @property integer $delivery_note_id
 * @property integer $product_id
 * @property string $description
 * @property double $quantity
 * @property integer $unit
 * @property double $picked_qty
 * @property string $country_of_origin
 * @property string $hsir_code
 * @property string $incomming_shipment_ref
 *
 * The followings are the available model relations:
 * @property DeliveryNote $deliveryNote
 * @property Store $product
 */
class DeliveryNoteItem extends CActiveRecord {

    public $product_name;
    public $unit;
    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{delivery_item}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('product_id, description, quantity, unit, picked_qty, country_of_origin, hsir_code, incomming_shipment_ref', 'required'),
            array('delivery_note_id, product_id', 'numerical', 'integerOnly' => true),
            array('quantity, picked_qty', 'numerical'),
            array('product_name, description, country_of_origin, hsir_code, incomming_shipment_ref', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, delivery_note_id, product_id, description, quantity, unit, picked_qty, country_of_origin, hsir_code, incomming_shipment_ref', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'deliveryNote' => array(self::BELONGS_TO, 'DeliveryNote', 'delivery_note_id'),
            'product' => array(self::BELONGS_TO, 'Store', 'product_id'),
            /*'totalQuantity'=> array(self::STAT, 'DeliveryNoteItem', 'id', 'select' => 'SUM(quantity)'),
            'totalPickedQuantity'=> array(self::STAT, 'DeliveryNoteItem', 'id', 'select' => 'SUM(picked_qty)'),*/
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'delivery_note_id' => 'Delivery Note',
            'product_id' => 'Product',
            'description' => 'Description',
            'quantity' => 'Quantity',
            'unit' => 'Unit',
            'picked_qty' => 'Picked Qty',
            'country_of_origin' => 'Country Of Origin',
            'hsir_code' => 'Hsir Code',
            'incomming_shipment_ref' => 'Incomming Shipment Ref',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('delivery_note_id', $this->delivery_note_id);
        $criteria->compare('product_id', $this->product_id);
        $criteria->compare('description', $this->description, true);
        $criteria->compare('quantity', $this->quantity);
        $criteria->compare('unit', $this->unit);
        $criteria->compare('picked_qty', $this->picked_qty);
        $criteria->compare('country_of_origin', $this->country_of_origin, true);
        $criteria->compare('hsir_code', $this->hsir_code, true);
        $criteria->compare('incomming_shipment_ref', $this->incomming_shipment_ref, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,            
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return DeliveryItem the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
