<?php

/**
 * This is the model class for table "{{invoice}}".
 *
 * The followings are the available columns in table '{{invoice}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $billing_address
 * @property string $shipping_address
 * @property string $shipping_conditions
 * @property string $invoice_date
 * @property string $sales_group
 * @property string $reference
 * @property string $currency
 * @property double $exchange_rate
 * @property string $payment_terms
 * @property string $shipping_by
 * @property string $lpo
 * @property string $others
 * @property double $net_amount
 * @property double $grand_total
 * @property string $notes
 * @property string $terms_and_conditions
 * @property string $remarks
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property Company $company
 * @property MasterFile $file
 */
class Invoice extends CActiveRecord {

    public $order_id;
    public $company_name;    
    public $title;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{invoice}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('title, delivery_ids, company_id, contact_id, billing_address, shipping_address, 
                            invoice_date, sales_group, reference, currency, exchange_rate, payment_terms 
                            ', 'required'),
            array('crm_user_id, file_id, contact_id', 'numerical', 'integerOnly' => true),
            array('exchange_rate, net_amount, grand_total', 'numerical'),
            array('company_id', 'length', 'max' => 20),
            array('shipping_conditions, sales_group, reference, currency, payment_terms, shipping_by, lpo, others', 'length', 'max' => 255),
            array('isActive', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, billing_address, shipping_address, shipping_conditions, invoice_date, sales_group, reference, currency, exchange_rate, payment_terms, shipping_by, lpo, others, net_amount, grand_total, notes, terms_and_conditions, remarks, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'netAmount'=> array(self::STAT, 'InvoiceItem', 'invoice_id', 'select' => 'SUM(net_amount)'),
            'netQuantity'=> array(self::STAT, 'InvoiceItem', 'invoice_id', 'select' => 'SUM(quantity)'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'billing_address' => 'Billing Address',
            'shipping_address' => 'Shipping Address',
            'shipping_conditions' => 'Shipping Conditions',
            'invoice_date' => 'Invoice Date',
            'sales_group' => 'Sales Group',
            'reference' => 'Reference',
            'currency' => 'Currency',
            'exchange_rate' => 'Exchange Rate',
            'payment_terms' => 'Payment Terms',
            'shipping_by' => 'Shipping By',
            'lpo' => 'Lpo',
            'others' => 'Others',
            'net_amount' => 'Net Amount',
            'grand_total' => 'Grand Total',
            'notes' => 'Notes',
            'terms_and_conditions' => 'Terms And Conditions',
            'remarks' => 'Remarks',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('file_id', $this->file_id);
        $criteria->compare('company_id', $this->company_id, true);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('billing_address', $this->billing_address, true);
        $criteria->compare('shipping_address', $this->shipping_address, true);
        $criteria->compare('shipping_conditions', $this->shipping_conditions, true);
        $criteria->compare('invoice_date', $this->invoice_date, true);
        $criteria->compare('sales_group', $this->sales_group, true);
        $criteria->compare('reference', $this->reference, true);
        $criteria->compare('currency', $this->currency, true);
        $criteria->compare('exchange_rate', $this->exchange_rate);
        $criteria->compare('payment_terms', $this->payment_terms, true);
        $criteria->compare('shipping_by', $this->shipping_by, true);
        $criteria->compare('lpo', $this->lpo, true);
        $criteria->compare('others', $this->others, true);
        $criteria->compare('net_amount', $this->net_amount);
        $criteria->compare('grand_total', $this->grand_total);
        $criteria->compare('notes', $this->notes, true);
        $criteria->compare('terms_and_conditions', $this->terms_and_conditions, true);
        $criteria->compare('remarks', $this->remarks, true);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Invoice the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
