<?php

/**
 * This is the model class for table "{{lead}}".
 *
 * The followings are the available columns in table '{{lead}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $enq_date
 * @property string $closing_date
 * @property string $title
 * @property string $notes
 * @property string $status
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 */
class Lead extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $lead_owner_id;
    public $mobile1;
    public $email1;
    public $company_name;

    public function tableName() {
        return '{{lead}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, company_id, contact_id, enq_date, closing_date, title, notes, status, lead_owner_id', 'required'),
            array('crm_user_id, file_id, contact_id', 'numerical', 'integerOnly' => true),
            array('company_id', 'length', 'max' => 20),
            array('title', 'length', 'max' => 255),
            array('status, isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, enq_date, closing_date, title, notes, status, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'enq_date' => 'Enq Date',
            'closing_date' => 'Closing Date',
            'title' => 'File Title',
            'notes' => 'Notes',
            'status' => 'Status',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('file_id', $this->file_id);
        if ((int) Yii::app()->session['company_id'] == 0)
            $criteria->compare('company_id', $this->company_id);
        else
            $criteria->compare('company_id', Yii::app()->session['company_id']);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('enq_date', $this->enq_date, true);
        $criteria->compare('closing_date', $this->closing_date, true);
        $criteria->compare('title', $this->title, true);
        $criteria->compare('notes', $this->notes, true);
        $criteria->compare('status', $this->status, true);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.company_id,t.enq_date DESC',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Lead the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
