<?php

/**
 * This is the model class for table "{{mas_company_branch}}".
 *
 * The followings are the available columns in table '{{mas_company_branch}}':
 * @property integer $id
 * @property integer $company_id
 * @property string $contact_number_1
 * @property string $contact_number_2
 * @property string $mobile_number
 * @property string $fax
 * @property string $email
 * @property integer $number_of_employees
 * @property string $annual_revenue
 * @property string $skype_id
 * @property string $facbook_link
 * @property string $twitter_link
 * @property string $google_plus
 * @property string $linkedin
 * @property string $instagram
 * @property string $myspace
 * @property string $bill_address1
 * @property string $bill_address2
 * @property string $bill_city
 * @property string $bill_state
 * @property integer $bill_country
 * @property string $bill_pin_or_zip
 * @property string $bill_postal_code
 * @property string $tax_id
 * @property string $acc_no
 * @property string $swift_code
 * @property integer $bank
 * @property string $iban_no
 * @property string $main_contact
 * @property string $shipp_address1
 * @property string $shipp_address2
 * @property string $shipp_city
 * @property string $shipp_state
 * @property integer $shipp_country
 * @property string $shipp_pin_or_zip
 * @property string $ship_postal_code
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property MasCompany $company
 * @property MasUser[] $masUsers
 */
class MasCompanyBranch extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{mas_company_branch}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('company_id, contact_number_1,branch_name, contact_number_2, mobile_number, fax, email, number_of_employees, annual_revenue, skype_id, facbook_link, twitter_link, google_plus, linkedin, instagram, myspace, bill_address1, bill_address2, bill_city, bill_state, bill_country, bill_pin_or_zip, bill_postal_code, tax_id, acc_no, swift_code, bank, iban_no, main_contact, shipp_address1, shipp_address2, shipp_city, shipp_state, shipp_country, shipp_pin_or_zip, ship_postal_code', 'required'),
			array('company_id, number_of_employees, bill_country, bank, shipp_country', 'numerical', 'integerOnly'=>true),
			array('contact_number_1, contact_number_2, mobile_number, fax, email, annual_revenue, skype_id, facbook_link, twitter_link, google_plus, linkedin, instagram, myspace, bill_address1, bill_address2, bill_city, bill_state, bill_pin_or_zip, bill_postal_code, tax_id, acc_no, swift_code, iban_no, main_contact, shipp_address1, shipp_address2, shipp_city, shipp_state, shipp_pin_or_zip, ship_postal_code', 'length', 'max'=>255),
			array('isActive', 'length', 'max'=>1),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, company_id, contact_number_1, contact_number_2, mobile_number, fax, email, number_of_employees, annual_revenue, skype_id, facbook_link, twitter_link, google_plus, linkedin, instagram, myspace, bill_address1, bill_address2, bill_city, bill_state, bill_country, bill_pin_or_zip, bill_postal_code, tax_id, acc_no, swift_code, bank, iban_no, main_contact, shipp_address1, shipp_address2, shipp_city, shipp_state, shipp_country, shipp_pin_or_zip, ship_postal_code, isActive', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'company' => array(self::BELONGS_TO, 'MasCompany', 'company_id'),
			'masUsers' => array(self::HAS_MANY, 'MasUser', 'branch_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'company_id' => 'Company',
			'contact_number_1' => 'Contact Number 1',
			'contact_number_2' => 'Contact Number 2',
			'mobile_number' => 'Mobile Number',
			'fax' => 'Fax',
			'email' => 'Email',
			'number_of_employees' => 'Number Of Employees',
			'annual_revenue' => 'Annual Revenue',
			'skype_id' => 'Skype',
			'facbook_link' => 'Facbook Link',
			'twitter_link' => 'Twitter Link',
			'google_plus' => 'Google Plus',
			'linkedin' => 'Linkedin',
			'instagram' => 'Instagram',
			'myspace' => 'Myspace',
			'bill_address1' => 'Bill Address1',
			'bill_address2' => 'Bill Address2',
			'bill_city' => 'Bill City',
			'bill_state' => 'Bill State',
			'bill_country' => 'Bill Country',
			'bill_pin_or_zip' => 'Bill Pin Or Zip',
			'bill_postal_code' => 'Bill Postal Code',
			'tax_id' => 'Tax',
			'acc_no' => 'Acc No',
			'swift_code' => 'Swift Code',
			'bank' => 'Bank',
			'iban_no' => 'Iban No',
			'main_contact' => 'Main Contact',
			'shipp_address1' => 'Shipp Address1',
			'shipp_address2' => 'Shipp Address2',
			'shipp_city' => 'Shipp City',
			'shipp_state' => 'Shipp State',
                    'branch_name' => 'Branch Name',
			'shipp_country' => 'Shipp Country',
			'shipp_pin_or_zip' => 'Shipp Pin Or Zip',
			'ship_postal_code' => 'Ship Postal Code',
			'isActive' => 'Is Active',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('company_id',$this->company_id);
                
                
		$criteria->compare('contact_number_1',$this->contact_number_1,true);
		$criteria->compare('contact_number_2',$this->contact_number_2,true);
                $criteria->compare('contact_number_2',$this->branch_name,true);
		$criteria->compare('mobile_number',$this->mobile_number,true);
		$criteria->compare('fax',$this->fax,true);
		$criteria->compare('email',$this->email,true);
		$criteria->compare('number_of_employees',$this->number_of_employees);
		$criteria->compare('annual_revenue',$this->annual_revenue,true);
		$criteria->compare('skype_id',$this->skype_id,true);
		$criteria->compare('facbook_link',$this->facbook_link,true);
		$criteria->compare('twitter_link',$this->twitter_link,true);
		$criteria->compare('google_plus',$this->google_plus,true);
		$criteria->compare('linkedin',$this->linkedin,true);
		$criteria->compare('instagram',$this->instagram,true);
		$criteria->compare('myspace',$this->myspace,true);
		$criteria->compare('bill_address1',$this->bill_address1,true);
		$criteria->compare('bill_address2',$this->bill_address2,true);
		$criteria->compare('bill_city',$this->bill_city,true);
		$criteria->compare('bill_state',$this->bill_state,true);
		$criteria->compare('bill_country',$this->bill_country);
		$criteria->compare('bill_pin_or_zip',$this->bill_pin_or_zip,true);
		$criteria->compare('bill_postal_code',$this->bill_postal_code,true);
		$criteria->compare('tax_id',$this->tax_id,true);
		$criteria->compare('acc_no',$this->acc_no,true);
		$criteria->compare('swift_code',$this->swift_code,true);
		$criteria->compare('bank',$this->bank);
		$criteria->compare('iban_no',$this->iban_no,true);
		$criteria->compare('main_contact',$this->main_contact,true);
		$criteria->compare('shipp_address1',$this->shipp_address1,true);
		$criteria->compare('shipp_address2',$this->shipp_address2,true);
		$criteria->compare('shipp_city',$this->shipp_city,true);
		$criteria->compare('shipp_state',$this->shipp_state,true);
		$criteria->compare('shipp_country',$this->shipp_country);
		$criteria->compare('shipp_pin_or_zip',$this->shipp_pin_or_zip,true);
		$criteria->compare('ship_postal_code',$this->ship_postal_code,true);
		$criteria->compare('isActive',$this->isActive,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return MasCompanyBranch the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
          public static function getCompanyBranches() {

        $condition = 'isActive =  "Y"';

        $model = self::model()->findAll(array('condition' => $condition));

        return CHtml::listData($model, 'id', 'branch_name');

    }
        
}
