<?php

/**
 * This is the model class for table "{{mas_user}}".
 *
 * The followings are the available columns in table '{{mas_user}}':
 * @property integer $id
 * @property integer $company_id
 * @property integer $branch_id
 * @property integer $user_group_id
 * @property string $first_name
 * @property string $last_name
 * @property string $username
 * @property string $password
 * @property string $designation
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property MasUserGroup $userGroup
 * @property MasCompany $company
 * @property MasCompanyBranch $branch
 * @property MasUserRelations[] $masUserRelations
 * @property MasUserRelations[] $masUserRelations1
 */
class MasUser extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $parent_id;

    public function tableName() {
        return '{{mas_user}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('company_id, branch_id, user_group_id, first_name, last_name, username, password, designation', 'required'),
            array('username', 'unique', 'on' => 'add'),
            array('company_id, branch_id, user_group_id', 'numerical', 'integerOnly' => true),
            array('first_name, last_name, username, password, designation', 'length', 'max' => 255),
            array('isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, company_id,parent_id, branch_id, user_group_id, first_name, last_name, username, password, designation, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'userGroup' => array(self::BELONGS_TO, 'MasUserGroup', 'user_group_id'),
            'company' => array(self::BELONGS_TO, 'MasCompany', 'company_id'),
            'branch' => array(self::BELONGS_TO, 'MasCompanyBranch', 'branch_id'),
            'masUserRelations' => array(self::HAS_MANY, 'MasUserRelations', 'parent_id'),
            'masUserRelations1' => array(self::HAS_MANY, 'MasUserRelations', 'user_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'company_id' => 'Company',
            'branch_id' => 'Branch',
            'user_group_id' => 'User Group',
            'first_name' => 'First Name',
            'last_name' => 'Last Name',
            'username' => 'Username',
            'password' => 'Password',
            'designation' => 'Designation',
            'parent_id' => 'Parent',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('company_id', $this->company_id);
        $criteria->compare('branch_id', $this->branch_id);
        $criteria->compare('user_group_id', $this->user_group_id);
        $criteria->compare('first_name', $this->first_name, true);

        $criteria->compare('last_name', $this->last_name, true);
        $criteria->compare('username', $this->username, true);
        $criteria->compare('password', $this->password, true);
        $criteria->compare('designation', $this->designation, true);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.first_name ASC',
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return MasUser the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /* public function getFullname()
      {
      return ($this->first_name.' '.$this->last_name);
      } */

    public static function getUser() {

        $condition = 'isActive =  "Y"';
        $model = self::model()->findAll(array('condition' => $condition));
        return CHtml::listData($model, 'id', 'first_name');
    }

}
