<?php

/**
 * This is the model class for table "{{master_file}}".
 *
 * The followings are the available columns in table '{{master_file}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $company_id
 * @property string $start_from
 * @property string $current_process_status
 * @property integer $lead_owner_id
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property AllocatedMaterials[] $allocatedMaterials
 * @property CreditNote[] $creditNotes
 * @property DeliveryNotes[] $deliveryNotes
 * @property Document[] $documents
 * @property Invoice[] $invoices
 * @property Lead[] $leads
 * @property Order[] $orders
 * @property Quotes[] $quotes
 */
class MasterFile extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{master_file}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, start_from, current_process_status', 'required'),
            array('file_number, crm_user_id, company_id, lead_owner_id', 'numerical', 'integerOnly' => true),
            array('start_from, isActive', 'length', 'max' => 1),
            array('current_process_status', 'length', 'max' => 2),
            array('file_title', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, company_id, start_from, current_process_status, lead_owner_id, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'allocatedMaterials' => array(self::HAS_MANY, 'AllocatedMaterials', 'file_id'),
            'creditNotes' => array(self::HAS_MANY, 'CreditNote', 'file_id'),
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNotes', 'file_id'),
            'documents' => array(self::HAS_MANY, 'Document', 'file_id'),
            'invoices' => array(self::HAS_MANY, 'Invoice', 'file_id'),
            'lead' => array(self::HAS_ONE, 'Lead', 'file_id'),
            'order' => array(self::HAS_ONE, 'Order', 'file_id'),
            'quote' => array(self::HAS_ONE, 'Quotes', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'company_id' => 'Company',
            'file_title'=>'File Title',
            'start_from' => 'Start From',
            'current_process_status' => 'Current Process Status',
            'lead_owner_id' => 'Lead Owner',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('company_id', $this->company_id);
        $criteria->compare('start_from', $this->start_from, true);
        $criteria->compare('current_process_status', $this->current_process_status, true);
        $criteria->compare('lead_owner_id', $this->lead_owner_id);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return MasterFile the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public static function getFiles($current_process_status = null) {
        $condition = 'isActive="Y"';
        if ($current_process_status != null)
            $condition.=' AND current_process_status="' . $current_process_status . '"';
        $model = self::model()->findAll(array('condition' => $condition));
        return CHtml::listData($model, 'id', 'id');
    }

}
