<?php

/**
 * This is the model class for table "{{order}}".
 *
 * The followings are the available columns in table '{{order}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $order_date
 * @property string $delivery_date
 * @property string $sales_group
 * @property string $reference
 * @property string $currency
 * @property double $exchange_rate
 * @property string $payment_terms
 * @property string $shipping_by
 * @property string $lpo
 * @property string $others
 * @property double $net_amount
 * @property double $final_addition_percentage
 * @property double $final_addition_amount
 * @property double $final_deduction_percentage
 * @property double $final_deduction_amount
 * @property double $net_total
 * @property double $grand_total
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property DeliveryNotes[] $deliveryNotes
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 * @property OrderItem[] $orderItems
 */
class Order extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $company_name;
    public $lead_owner_id;
    public $shipping_conditions;
    public $title;

    public function tableName() {
        return '{{order}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, company_id, contact_id, order_date, delivery_date, sales_group,
                billing_address,shipping_address, currency, exchange_rate, payment_terms, shipping_by,title', 'required'),
            array('crm_user_id, file_id, contact_id', 'numerical', 'integerOnly' => true),
            array('exchange_rate, net_amount, final_addition_amount, final_deduction_amount, net_total, grand_total', 'numerical'),
            array('company_id', 'length', 'max' => 20),
            array('sales_group, reference, currency, payment_terms, shipping_by, lpo, others, shipping_conditions', 'length', 'max' => 255),
            array('isActive', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, order_date, delivery_date, sales_group, reference, currency, exchange_rate, payment_terms, shipping_by, lpo, others, net_amount, final_addition_percentage, final_addition_amount, final_deduction_percentage, final_deduction_amount, net_total, grand_total, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNotes', 'order_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'items' => array(self::HAS_MANY, 'OrderItem', 'order_id'),
            'adItems' => array(self::HAS_MANY, 'OrderAddition', 'order_id'),
            'dedItems' => array(self::HAS_MANY, 'OrderDeduction', 'order_id'),
            'netAmount'=> array(self::STAT, 'OrderItem', 'order_id', 'select' => 'SUM(net_amount)'),
            'netQuantity'=> array(self::STAT, 'OrderItem', 'order_id', 'select' => 'SUM(quantity)'),
            'adTotal' => array(self::STAT, 'OrderAddition', 'order_id', 'select' => 'SUM(calculated_value)'),
            'dedTotal' => array(self::STAT, 'OrderDeduction', 'order_id', 'select' => 'SUM(calculated_value)'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'title' => 'File Title',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'order_date' => 'Order Date',
            'delivery_date' => 'Delivery Date',
            'sales_group' => 'Sales Group',
            'reference' => 'Reference',
            'currency' => 'Currency',
            'exchange_rate' => 'Exchange Rate',
            'payment_terms' => 'Payment Terms',
            'shipping_by' => 'Shipping By',
            'lpo' => 'Lpo',
            'others' => 'Others',
            'net_amount' => 'Net Amount',
            'final_addition_percentage' => 'Final Addition Percentage',
            'final_addition_amount' => 'Final Addition Amount',
            'final_deduction_percentage' => 'Final Deduction Percentage',
            'final_deduction_amount' => 'Final Deduction Amount',
            'net_total' => 'Net Total',
            'grand_total' => 'Grand Total',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('file_id', $this->file_id);
        if ((int) Yii::app()->session['company_id'] == 0)
            $criteria->compare('company_id', $this->company_id);
        else
            $criteria->compare('company_id', Yii::app()->session['company_id']);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('order_date', $this->order_date, true);
        $criteria->compare('delivery_date', $this->delivery_date, true);
        $criteria->compare('sales_group', $this->sales_group, true);
        $criteria->compare('reference', $this->reference, true);
        $criteria->compare('currency', $this->currency, true);
        $criteria->compare('exchange_rate', $this->exchange_rate);
        $criteria->compare('payment_terms', $this->payment_terms, true);
        $criteria->compare('shipping_by', $this->shipping_by, true);
        $criteria->compare('lpo', $this->lpo, true);
        $criteria->compare('others', $this->others, true);
        $criteria->compare('net_amount', $this->net_amount);
        $criteria->compare('final_addition_percentage', $this->final_addition_percentage);
        $criteria->compare('final_addition_amount', $this->final_addition_amount);
        $criteria->compare('final_deduction_percentage', $this->final_deduction_percentage);
        $criteria->compare('final_deduction_amount', $this->final_deduction_amount);
        $criteria->compare('net_total', $this->net_total);
        $criteria->compare('grand_total', $this->grand_total);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.file_id,t.company_id,t.order_date DESC',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Order the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
