<?php

/**
 * This is the model class for table "{{purchasing_enquiry}}".
 *
 * The followings are the available columns in table '{{purchasing_enquiry}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property integer $requisition_id
 * @property string $enquiry_date
 * reference
 * @property string $note
 * @property string $delivery_date
 */
class PurchasingEnquiry extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
        public $title;
	public function tableName()
	{
		return '{{purchasing_enquiry}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('crm_user_id,vendor_id,requisition_id, enquiry_date, note, delivery_date,reference,isActive,title', 'required'),
			array('crm_user_id, file_id, requisition_id', 'numerical', 'integerOnly'=>true),
			array('note,vendor_id,title', 'length', 'max'=>255),
                        array('isActive', 'length', 'max'=>1),
                        array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, crm_user_id,vendor_id,file_id, requisition_id, enquiry_date, notes, delivery_date,reference,isActive', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'crm_user_id' => 'Crm User',
			'file_id' => 'File',
			'requisition_id' => 'Requisition',
			'enquiry_date' => 'Enquiry Date',
			'note' => 'Notes',
			'delivery_date' => 'Delivery Date',
                        'vendor_id' => 'Vendor ID',
                        'reference' => 'Reference',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('crm_user_id',$this->crm_user_id);
		$criteria->compare('file_id',$this->file_id);
		$criteria->compare('requisition_id',$this->requisition_id);
		$criteria->compare('enquiry_date',$this->enquiry_date,true);
		$criteria->compare('note',$this->notes,true);
		$criteria->compare('delivery_date',$this->delivery_date,true);
                $criteria->compare('vendor_id',$this->vendor_id,true);
                $criteria->compare('reference',$this->reference,true);
		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PurchasingEnquiry the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
