<?php

/**
 * This is the model class for table "{{purchasing_invoice}}".
 *
 * The followings are the available columns in table '{{purchasing_invoice}}':
 * @property integer $id
 * @property integer $file_id
 * @property integer $po_id
 * @property integer $vend_id
 * @property string $vend_name
 * @property string $dly_no
 * @property string $dly_date
 * @property string $shipped_by
 * @property string $awb_no
 * @property integer $mrv_no
 * @property integer $tracking_no
 * @property string $others
 * @property string $storekeeper_notes
 * @property string $qc_check
 * @property integer $qc_notes
 * @property integer $qc_check_date
 * @property integer $mtl_receipt_date
 * @property integer $invoice_date
 */
class PurchasingInvoice extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{purchasing_invoice}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('file_id, po_id, vend_id, vend_name, dly_no, dly_date, shipped_by, awb_no, mrv_no, tracking_no, others, storekeeper_notes, qc_check, qc_notes, qc_check_date, mtl_receipt_date, invoice_date', 'required'),
			array('file_id, po_id, vend_id, mrv_no, tracking_no, qc_notes, qc_check_date, mtl_receipt_date, invoice_date', 'numerical', 'integerOnly'=>true),
			array('vend_name, dly_no, shipped_by, awb_no, others', 'length', 'max'=>255),
			array('qc_check', 'length', 'max'=>1),
                        array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, file_id, po_id, vend_id, vend_name, dly_no, dly_date, shipped_by, awb_no, mrv_no, tracking_no, others, storekeeper_notes, qc_check, qc_notes, qc_check_date, mtl_receipt_date, invoice_date', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'file_id' => 'File',
			'po_id' => 'Po',
			'vend_id' => 'Vend',
			'vend_name' => 'Vend Name',
			'dly_no' => 'Dly No',
			'dly_date' => 'Dly Date',
			'shipped_by' => 'Shipped By',
			'awb_no' => 'Awb No',
			'mrv_no' => 'Mrv No',
			'tracking_no' => 'Tracking No',
			'others' => 'Others',
			'storekeeper_notes' => 'Storekeeper Notes',
			'qc_check' => 'Qc Check',
			'qc_notes' => 'Qc Notes',
			'qc_check_date' => 'Qc Check Date',
			'mtl_receipt_date' => 'Mtl Receipt Date',
			'invoice_date' => 'Invoice Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('file_id',$this->file_id);
		$criteria->compare('po_id',$this->po_id);
		$criteria->compare('vend_id',$this->vend_id);
		$criteria->compare('vend_name',$this->vend_name,true);
		$criteria->compare('dly_no',$this->dly_no,true);
		$criteria->compare('dly_date',$this->dly_date,true);
		$criteria->compare('shipped_by',$this->shipped_by,true);
		$criteria->compare('awb_no',$this->awb_no,true);
		$criteria->compare('mrv_no',$this->mrv_no);
		$criteria->compare('tracking_no',$this->tracking_no);
		$criteria->compare('others',$this->others,true);
		$criteria->compare('storekeeper_notes',$this->storekeeper_notes,true);
		$criteria->compare('qc_check',$this->qc_check,true);
		$criteria->compare('qc_notes',$this->qc_notes);
		$criteria->compare('qc_check_date',$this->qc_check_date);
		$criteria->compare('mtl_receipt_date',$this->mtl_receipt_date);
		$criteria->compare('invoice_date',$this->invoice_date);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PurchasingInvoice the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
