<?php

/**
 * This is the model class for table "{{purchasing_material_receipts}}".
 *
 * The followings are the available columns in table '{{purchasing_material_receipts}}':
 * @property integer $id
 * @property integer $file_id
 * @property integer $po_id
 * @property integer $vendor_id
 * @property string $dly_no
 * @property string $dly_date
 * @property string $shipped_by
 * @property string $awb_no
 * @property string $tracking_no
 * @property string $others
 * @property string $storekeeper_notes
 * @property string $qc_check_notes
 * @property string $qc_check_date
 * @property integer $lot_no
 * @property string $mrv_receipt_date
 */
class PurchasingMaterialreceipt extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
        public $vendor_name;
        public $title;
	public function tableName()
	{
		return '{{purchasing_material_receipt}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('crm_user_id,po_id, vendor_id, dly_no, dly_date, shipped_by, awb_no, tracking_no, others, storekeeper_notes, qc_check_notes, qc_check_date, lot_no, mrv_receipt_date', 'required'),
			array('crm_user_id,file_id, po_id, vendor_id, lot_no', 'numerical', 'integerOnly'=>true),
			array('dly_no, shipped_by, awb_no, tracking_no, others, storekeeper_notes, qc_check_notes, qc_check_date', 'length', 'max'=>255),
                        array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('crm_user_id,id, file_id, po_id, vendor_id, dly_no, dly_date, shipped_by, awb_no, tracking_no, others, storekeeper_notes, qc_check_notes, qc_check_date, lot_no, mrv_receipt_date', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'file_id' => 'File',
			'po_id' => 'Po',
			'vendor_id' => 'Vendor',
			'dly_no' => 'Dly No',
			'dly_date' => 'Dly Date',
			'shipped_by' => 'Shipped By',
			'awb_no' => 'Awb No',
			'tracking_no' => 'Tracking No',
			'others' => 'Others',
			'storekeeper_notes' => 'Storekeeper Notes',
			'qc_check_notes' => 'Qc Check Notes',
			'qc_check_date' => 'Qc Check Date',
			'lot_no' => 'Lot No',
			'mrv_receipt_date' => 'Mrv Receipt Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('file_id',$this->file_id);
		$criteria->compare('po_id',$this->po_id);
		$criteria->compare('vendor_id',$this->vendor_id);
		$criteria->compare('dly_no',$this->dly_no,true);
		$criteria->compare('dly_date',$this->dly_date,true);
		$criteria->compare('shipped_by',$this->shipped_by,true);
		$criteria->compare('awb_no',$this->awb_no,true);
		$criteria->compare('tracking_no',$this->tracking_no,true);
		$criteria->compare('others',$this->others,true);
		$criteria->compare('storekeeper_notes',$this->storekeeper_notes,true);
		$criteria->compare('qc_check_notes',$this->qc_check_notes,true);
		$criteria->compare('qc_check_date',$this->qc_check_date,true);
		$criteria->compare('lot_no',$this->lot_no);
		$criteria->compare('mrv_receipt_date',$this->mrv_receipt_date,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PurchasingMaterialReceipts the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
