<?php

/**
 * This is the model class for table "{{purchase_order}}".
 *
 * The followings are the available columns in table '{{purchase_order}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $vendor_id
 * @property integer $connected_file_id
 * @property integer $contact_id
 * @property string $order_date
 * @property string $required_date
 * @property integer $currency
 * @property integer $exchange_rate
 * @property string $reference
 * @property integer $payment_term
 * file_id
 */
class PurchasingOrder extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
        public $vendor_name;
        public $title;
	public function tableName()
	{
		return '{{purchasing_order}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('crm_user_id, vendor_id, connected_file_id, contact_id, order_date, required_date, currency, exchange_rate, reference, payment_term', 'required'),
			array('crm_user_id, vendor_id, connected_file_id, contact_id, currency, exchange_rate, payment_term', 'numerical', 'integerOnly'=>true),
			array('reference,title', 'length', 'max'=>255),
                        array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, crm_user_id,file_id, vendor_id, connected_file_id, contact_id, order_date, required_date, currency, exchange_rate, reference, payment_term', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                      'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'crm_user_id' => 'Crm User',
			'vendor_id' => 'Vendor',
			'connected_file_id' => 'Connected File',
			'contact_id' => 'Contact',
			'order_date' => 'Order Date',
			'required_date' => 'Required Date',
			'currency' => 'Currency',
			'exchange_rate' => 'Exchange Rate',
			'reference' => 'Reference',
			'payment_term' => 'Payment Term',
                        'file_id' => 'File ID',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('crm_user_id',$this->crm_user_id);
		$criteria->compare('vendor_id',$this->vendor_id);
		$criteria->compare('connected_file_id',$this->connected_file_id);
		$criteria->compare('contact_id',$this->contact_id);
		$criteria->compare('order_date',$this->order_date,true);
		$criteria->compare('required_date',$this->required_date,true);
		$criteria->compare('currency',$this->currency);
		$criteria->compare('exchange_rate',$this->exchange_rate);
		$criteria->compare('reference',$this->reference,true);
		$criteria->compare('payment_term',$this->payment_term);
                $criteria->compare('file_id',$this->file_id);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PurchaseOrder the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
