<?php

/**
 * This is the model class for table "{{purchase_order_item}}".
 *
 * The followings are the available columns in table '{{purchase_order_item}}':
 * @property integer $id
 * @property integer $order_id
 * @property integer $product_id
 * @property string $description
 * @property double $quantity
 * @property double $rate
 * @property double $amount
 * @property double $addition_percentage
 * @property double $addition_amount
 * @property double $deduction_percentage
 * @property double $deduction_amount
 * @property double $net_amount
 */
class PurchasingOrderItem extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
        public $product_name;
        public $unit;
	public function tableName()
	{
		return '{{purchasing_order_item}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('product_id, description, quantity, rate, amount', 'required'),
			array('purchasing_order_id, product_id', 'numerical', 'integerOnly'=>true),
			array('quantity, rate, amount', 'numerical'),
			array('description', 'length', 'max'=>255),
                        // The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, purchasing_order_id, product_id, description, quantity, rate, amount', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'purchasing_order_id' => 'Purchasing Order',
			'product_id' => 'Product',
			'description' => 'Description',
			'quantity' => 'Quantity',
			'rate' => 'Rate',
			'amount' => 'Amount',
			'addition_percentage' => 'Addition Percentage',
			'addition_amount' => 'Addition Amount',
			'deduction_percentage' => 'Deduction Percentage',
			'deduction_amount' => 'Deduction Amount',
			'net_amount' => 'Net Amount',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('purchasing_order_id',$this->purchasing_order_id);
		$criteria->compare('product_id',$this->product_id);
		$criteria->compare('description',$this->description,true);
		$criteria->compare('quantity',$this->quantity);
		$criteria->compare('rate',$this->rate);
		$criteria->compare('amount',$this->amount);
		$criteria->compare('addition_percentage',$this->addition_percentage);
		$criteria->compare('addition_amount',$this->addition_amount);
		$criteria->compare('deduction_percentage',$this->deduction_percentage);
		$criteria->compare('deduction_amount',$this->deduction_amount);
		$criteria->compare('net_amount',$this->net_amount);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PurchaseOrderItem the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
