<?php

/**
 * This is the model class for table "{{quotes}}".
 *
 * The followings are the available columns in table '{{quotes}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $qtn_start_date
 * @property string $qtn_close_date
 * @property string $sales_group
 * @property string $reference
 * @property string $currency
 * @property double $exchange_rate
 * @property string $payment_terms
 * @property string $shipping_by
 * @property string $qtn_validity
 * @property string $qtn_date
 * @property string $shipping_conditions
 * @property integer $probability
 * @property double $grand_total
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property CompanyContact $contact
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 * @property QuotesItem[] $quotesItems
 */
class Quotes extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $company_name;
    public $lead_owner_id;
    public $title;

    public function tableName() {
        return '{{quotes}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, company_id, lead_owner_id, contact_id, qtn_start_date,qtn_delivery_date, 
                qtn_close_date,billing_address,shipping_address, sales_group, currency, 
                exchange_rate, payment_terms, shipping_by, qtn_validity, shipping_conditions, probability , title', 'required'),
            array('crm_user_id, file_id, contact_id, lead_owner_id, probability', 'numerical', 'integerOnly' => true),
            array('exchange_rate, grand_total', 'numerical'),
            array('company_id', 'length', 'max' => 20),
            array('sales_group, reference, currency, payment_terms, shipping_by, shipping_conditions, title', 'length', 'max' => 255),
            array('isActive', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, qtn_start_date, qtn_close_date, sales_group, reference, currency, exchange_rate, payment_terms, shipping_by, qtn_validity, qtn_date, shipping_conditions, probability, grand_total, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'items' => array(self::HAS_MANY, 'QuotesItem', 'quotes_id'),
            'adItems' => array(self::HAS_MANY, 'QuotesAddition', 'quotes_id'),
            'dedItems' => array(self::HAS_MANY, 'QuotesDeduction', 'quotes_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'title'=>'File Title',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'qtn_start_date' => 'Qtn Start Date',
            'qtn_close_date' => 'Qtn Close Date',
            'sales_group' => 'Sales Group',
            'reference' => 'Reference',
            'currency' => 'Currency',
            'exchange_rate' => 'Exchange Rate',
            'payment_terms' => 'Payment Terms',
            'shipping_by' => 'Shipping By',
            'qtn_validity' => 'Qtn Validity',
            'qtn_date' => 'Qtn Date',
            'qtn_delivery_date' => 'Delivery Date',
            'shipping_conditions' => 'Shipping Conditions',
            'probability' => 'Probability',
            'grand_total' => 'Grand Total',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('file_id', $this->file_id);
        if ((int) Yii::app()->session['company_id'] == 0)
            $criteria->compare('company_id', $this->company_id);
        else
            $criteria->compare('company_id', Yii::app()->session['company_id']);
        $criteria->compare('contact_id', $this->contact_id);
        $criteria->compare('qtn_start_date', $this->qtn_start_date, true);
        $criteria->compare('qtn_close_date', $this->qtn_close_date, true);
        $criteria->compare('sales_group', $this->sales_group, true);
        $criteria->compare('reference', $this->reference, true);
        $criteria->compare('currency', $this->currency, true);
        $criteria->compare('exchange_rate', $this->exchange_rate);
        $criteria->compare('payment_terms', $this->payment_terms, true);
        $criteria->compare('shipping_by', $this->shipping_by, true);
        $criteria->compare('qtn_validity', $this->qtn_validity, true);
        $criteria->compare('qtn_date', $this->qtn_date, true);
        $criteria->compare('shipping_conditions', $this->shipping_conditions, true);
        $criteria->compare('probability', $this->probability);
        $criteria->compare('grand_total', $this->grand_total);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.file_id,t.company_id,t.qtn_date DESC',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Quotes the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
