<?php

/**
 * This is the model class for table "{{store}}".
 *
 * The followings are the available columns in table '{{store}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property string $part_number
 * @property string $generic_name
 * @property string $description
 * @property string $product_class
 * @property double $rate
 * @property integer $unit_id
 * @property string $non_stock_item
 * @property string $isActive
 * @property integer $status
 * @property integer $tax_code
 * @property integer $mark_up
 * @property double $total_value
 * @property integer $country
 * @property integer $total_quantity
 *
 * The followings are the available model relations:
 * @property GoodsReturnItem[] $goodsReturnItems
 * @property InvoiceItem[] $invoiceItems
 * @property MasInvTax $taxCode
 * @property Unit $unit
 * @property MasCountry $country0
 * @property MasInvStatus $status0
 */
class Store extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{store}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('crm_user_id, part_number,  description,  rate, unit_id, status, tax_code,  total_value,  total_quantity', 'required'),
			array('crm_user_id, unit_id, status, tax_code, mark_up, country, total_quantity', 'numerical', 'integerOnly'=>true),
			array('rate, total_value', 'numerical'),
			array('part_number, generic_name, description, product_class', 'length', 'max'=>255),
                        array('part_number', 'unique','on'=>'add'),
			array('non_stock_item, isActive', 'length', 'max'=>1),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, crm_user_id, part_number, generic_name, description, product_class, rate, unit_id, non_stock_item, isActive, status, tax_code, mark_up, total_value, country, total_quantity', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'goodsReturnItems' => array(self::HAS_MANY, 'GoodsReturnItem', 'product_id'),
			'invoiceItems' => array(self::HAS_MANY, 'InvoiceItem', 'product_id'),
			'taxCode' => array(self::BELONGS_TO, 'MasInvTax', 'tax_code'),
			'unit' => array(self::BELONGS_TO, 'Unit', 'unit_id'),
			'country0' => array(self::BELONGS_TO, 'MasCountry', 'country'),
			'status0' => array(self::BELONGS_TO, 'MasInvStatus', 'status'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'crm_user_id' => 'Crm User',
			'part_number' => 'Part Number',
			'generic_name' => 'Generic Name',
			'description' => 'Description',
			'product_class' => 'Product Class',
			'rate' => 'Rate',
			'unit_id' => 'Unit',
			'non_stock_item' => 'Non Stock Item',
			'isActive' => 'Is Active',
			'status' => 'Status',
			'tax_code' => 'Tax Code',
			'mark_up' => 'Mark Up',
			'total_value' => 'Total Value',
			'country' => 'Country',
			'total_quantity' => 'Total Quantity',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('crm_user_id',$this->crm_user_id);
		$criteria->compare('part_number',$this->part_number,true);
		$criteria->compare('generic_name',$this->generic_name,true);
		$criteria->compare('description',$this->description,true);
		$criteria->compare('product_class',$this->product_class,true);
		$criteria->compare('rate',$this->rate);
		$criteria->compare('unit_id',$this->unit_id);
		$criteria->compare('non_stock_item',$this->non_stock_item,true);
		$criteria->compare('isActive',$this->isActive,true);
		$criteria->compare('status',$this->status);
		$criteria->compare('tax_code',$this->tax_code);
		$criteria->compare('mark_up',$this->mark_up);
		$criteria->compare('total_value',$this->total_value);
		$criteria->compare('country',$this->country);
		$criteria->compare('total_quantity',$this->total_quantity);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Store the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
