<?php

/**
 * This is the model class for table "{{form_permission}}".
 *
 * The followings are the available columns in table '{{form_permission}}':
 * @property integer $id
 * @property integer $form_id
 * @property string $user_id
 * @property integer $level
 */
class FormPermission extends CActiveRecord {

    public $levels_count;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_permission}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('name,form_id, user_id, level', 'required'),
            array('levels_count,form_id, level', 'numerical', 'integerOnly' => true),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, form_id, user_id, level', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'form' => array(self::BELONGS_TO, 'Form', 'form_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'name' => 'Give a name',
            'form_id' => 'Form',
            'user_id' => 'Approval can be done by ',
            'level' => 'Level',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('form_id', $this->form_id);
        $criteria->compare('user_id', $this->user_id, true);
        $criteria->compare('level', $this->level);
        $criteria->order = "form_id ASC,level ASC";
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormPermission the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getForms() {
        $model = Form::model()->findAll(array('order' => 'form_order'));
        return CHtml::listData($model, 'id', 'name');
    }

    public function getLevels() {
        $levels_count = self::model()->count('form_id=' . $this->form_id);
        return range(0, $levels_count);
    }

    public function getPermittedUsers() {
        $usernames = array();
        $userids = unserialize($this->user_id);
        if (is_array($userids)) {
            $users = User::model()->findAll(array('condition' => 'id in (' . implode(',', $userids) . ')'));
            if (!empty($users)) {
                foreach ($users as $eachUser)
                    $usernames[] = $eachUser->fullName;
            }
        }
        return implode(',', $usernames);
    }
    
    public function getUsersInLevel() {
        return (unserialize($this->user_id));
    }

}
