<?php

/**
 * This is the model class for table "{{form_rfq_misc}}".
 *
 * The followings are the available columns in table '{{form_rfq_misc}}':

 * @property string $form_rfq_id
 * @property string $power_supply_voltage
 * @property string $power_supply_phase
 * @property string $power_supply_frequency
 * @property integer $plant_type_skid_mount
 * @property integer $plant_type_containerised
 * @property integer $plant_type_loose_supply
 * @property integer $scope_of_work_site_piping
 * @property integer $scope_of_work_site_cabling
 * @property integer $scope_of_work_site_support
 * @property integer $scope_of_work_food_accomodation
 */
class FormRfqMisc extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_rfq_misc}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('scope_of_service_supply,scope_of_service_installation,scope_of_service_commissioning,scope_of_service_operation,scope_of_service_pact_team,scope_of_service_pact_supervision,
                notes,power_supply_voltage, power_supply_phase, power_supply_frequency, plant_type_skid_mount, plant_type_containerised, plant_type_built_at_site, scope_of_work_site_piping, scope_of_work_site_cabling, scope_of_work_out_of_pact_piping, scope_of_work_out_of_pact_cabling ', 'safe'),
            array('plant_type_skid_mount, plant_type_containerised, plant_type_built_at_site, scope_of_work_site_piping, scope_of_work_site_cabling, scope_of_work_out_of_pact_piping, scope_of_work_out_of_pact_cabling ', 'numerical', 'integerOnly' => true),
            array('form_rfq_id, power_supply_voltage, power_supply_phase, power_supply_frequency', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('form_rfq_id, power_supply_voltage, power_supply_phase, power_supply_frequency, plant_type_skid_mount, plant_type_containerised, plant_type_built_at_site, scope_of_work_site_piping, scope_of_work_site_cabling, scope_of_work_out_of_pact_piping, scope_of_work_out_of_pact_cabling', 'safe', 'on' => 'search'),
            array('form_rfq_id', 'safe')
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'form_rfq_id' => 'Form Rfq',
            'power_supply_voltage' => 'Voltage',
            'power_supply_phase' => 'Phase',
            'power_supply_frequency' => 'Frequency',
            'plant_type_skid_mount' => 'Skid Mount',
            'plant_type_containerised' => 'Containerised',
            'plant_type_built_at_site' => 'Built At Site',
            'scope_of_work_site_piping' => 'PACT Boundary Interconnection Piping',
            'scope_of_work_site_cabling' => 'PACT Boundary Interconnection Cabling',
            'scope_of_work_out_of_pact_piping' => 'Out of PACT Boundary Interconnection Piping',
            'scope_of_work_out_of_pact_cabling' => 'Out of PACT Boundary Interconnection Cabling',
            'scope_of_work_civil_construction' => 'Civil Construction',
            'scope_of_service_supply' => 'Supply',
            'scope_of_service_installation' => 'Installation',
            'scope_of_service_commissioning' => 'Commissioning',
            'scope_of_service_operation' => 'Operation',
            'scope_of_service_pact_team' => 'PACT Team',
            'scope_of_service_pact_supervision' => 'PACT Supervision',
            'notes' => 'Notes'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;


        $criteria->compare('form_rfq_id', $this->form_rfq_id, true);
        $criteria->compare('power_supply_voltage', $this->power_supply_voltage, true);
        $criteria->compare('power_supply_phase', $this->power_supply_phase, true);
        $criteria->compare('power_supply_frequency', $this->power_supply_frequency, true);
        $criteria->compare('plant_type_skid_mount', $this->plant_type_skid_mount);
        $criteria->compare('plant_type_containerised', $this->plant_type_containerised);
        $criteria->compare('plant_type_built_at_site', $this->plant_type_built_at_site);
        $criteria->compare('scope_of_work_site_piping', $this->scope_of_work_site_piping);
        $criteria->compare('scope_of_work_site_cabling', $this->scope_of_work_site_cabling);
        $criteria->compare('scope_of_work_out_of_pact_piping', $this->scope_of_work_out_of_pact_piping);
        $criteria->compare('scope_of_work_out_of_pact_cabling', $this->scope_of_work_out_of_pact_cabling);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormRfqMisc the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
