<?php

/**
 * This is the model class for table "{{invoice}}".
 *
 * The followings are the available columns in table '{{invoice}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $billing_address
 * @property string $shipping_address
 * @property string $shipping_conditions
 * @property string $invoice_date
 * @property string $sales_group
 * @property string $reference
 * @property string $currency
 * @property double $exchange_rate
 * @property string $payment_terms
 * @property string $shipping_by
 * @property string $lpo
 * @property string $others
 * @property double $net_amount
 * @property double $grand_total
 * @property string $notes
 * @property string $terms_and_conditions
 * @property string $remarks
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property Company $company
 * @property MasterFile $file
 */
class Invoice extends CActiveRecord {

    //public $order_id;
    public $company_name;
    public $lead_owner_id;
    public $title;
    public $received_amt;
    public $searchstartdate;
    public $searchenddate;
    public $value;
    public $country;
    public $lead_owner;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{invoice}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('order_id, file_id, company_id, contact_id, billing_address, 
                            invoice_date, sales_group, exchange_rate, payment_terms 
                            ', 'required'),
            //array('delivery_ids', 'required', 'message' => 'Please choose atleast one delivery note for invoicing'),
            /* array(
              'qtn_close_date',
              'compare',
              'compareAttribute'=>'qtn_start_date',
              'operator'=>'>=',
              'allowEmpty'=>false ,
              'message'=>'{attribute} must be greater than "{compareValue}".'
              ), */
            array('crm_user_id, file_id,invoice_no, contact_id', 'numerical', 'integerOnly' => true),
            array('exchange_rate, net_amount, grand_total', 'numerical'),
            array('company_id', 'length', 'max' => 20),
            array('customer_name,shipping_conditions, sales_group, reference, currency, payment_terms, shipping_by, lpo, others', 'length', 'max' => 255),
            array('isActive,paid', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, billing_address, shipping_address, shipping_conditions, invoice_date, sales_group, reference, currency, exchange_rate, payment_terms, shipping_by, lpo, others, net_amount,final_addition_percentage, 
                final_addition_amount, final_deduction_percentage, final_deduction_amount, net_total, grand_total, notes, terms_and_conditions, remarks, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'currency0' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'netAmount' => array(self::STAT, 'InvoiceItem', 'invoice_id', 'select' => 'SUM(net_amount)'),
            'netQuantity' => array(self::STAT, 'InvoiceItem', 'invoice_id', 'select' => 'SUM(quantity)'),
            'processedInvoice' => array(self::HAS_MANY, 'ReceivedInvoices', 'invoice_id'),
            'receivedAmount' => array(self::STAT, 'ReceivedInvoices', 'invoice_id', 'select' => 'SUM(received_amt)'),
            'items' => array(self::HAS_MANY, 'InvoiceItem', 'invoice_id'),
            'currencyname' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'paymentTerm' => array(self::BELONGS_TO, 'MasPaymentTerm', 'payment_terms'),
            'adItems' => array(self::HAS_MANY, 'InvoiceAddition', 'invoice_id'),
            'dedItems' => array(self::HAS_MANY, 'InvoiceDeduction', 'invoice_id'),
            'adTotal' => array(self::STAT, 'InvoiceAddition', 'inoice_id', 'select' => 'SUM(calculated_value)'),
            'dedTotal' => array(self::STAT, 'InvoiceDeduction', 'inoice_id', 'select' => 'SUM(calculated_value)'),
            'costTotal' => array(self::STAT, 'InvoiceItem', 'invoice_id', 'select' => 'SUM(cost_rate*quantity)'),
            'salesgroup' => array(self::BELONGS_TO, 'MasSalesGroup', 'sales_group'),
            'returned' => array(self::HAS_ONE, 'Creditnote', 'invoice_id'),
            'returnedAmount' => array(self::STAT, 'Creditnote', 'invoice_id', 'select' => 'SUM(credited_amount)'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'billing_address' => 'Billing Address',
            'shipping_address' => 'Shipping Address',
            'shipping_conditions' => 'Shipping Conditions',
            'invoice_date' => 'Invoice Date',
            'sales_group' => 'Sales Group',
            'reference' => 'Reference',
            'currency' => 'Currency',
            'exchange_rate' => 'Exchange Rate',
            'payment_terms' => 'Payment Terms',
            'shipping_by' => 'Shipping By',
            'lpo' => ' PO Ref :',
            'others' => 'Others',
            'net_amount' => 'Net Amount',
            'final_addition_percentage' => 'Final Addition Percentage',
            'final_addition_amount' => 'Final Addition Amount',
            'final_deduction_percentage' => 'Final Deduction Percentage',
            'final_deduction_amount' => 'Final Deduction Amount',
            'net_total' => 'Net Total',
            'grand_total' => 'Grand Total',
            'notes' => 'Notes',
            'terms_and_conditions' => 'Terms And Conditions',
            'remarks' => 'Remarks',
            'isActive' => 'Is Active',
            'order_id' => 'Order ID'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function report() {
        $criteria = new CDbCriteria;
        $criteria->with = array('file', 'file.company');
        if (!empty($this->company_id))
            $condition[] = 't.company_id="' . $this->company_id . '"';
        if (!empty($this->sales_group))
            $condition[] = 'sales_group="' . $this->sales_group . '"';
        if (!empty($this->country))
            $condition[] = 'company.billing_country="' . $this->country . '"';
        if (!empty($this->lead_owner))
            $condition[] = 'file.lead_owner_id="' . $this->lead_owner . '"';
        if (!empty($this->value))
            $condition[] = 'grand_total<="' . $this->value . '"';
        if (is_array($condition))
            $criteria->condition = implode(' AND ', $condition);
        if (!empty($this->searchstartdate) && !empty($this->searchenddate)) {
            $criteria->addBetweenCondition('invoice_date', $this->searchstartdate, $this->searchenddate);
        }
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.invoice_date DESC,t.file_id DESC,t.company_id DESC',
            ),
            'pagination' => false
        ));
    }

  /*  public function search($searchterm = null) {
        

       $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();
        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=13'));
        $notification = Notification::model()->findAll(array('condition' => 'form_id=13'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if (in_array(Yii::app()->user->id, $Dpt_id))
                $file_id[] = $eachnotifcation->file_id;
            $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
        }
        $temp_userids = array();
        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval !== "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=13 AND level=' . (int) $eachApproval->level))->user_id);
            
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }
        $file_ids = array_unique($file_id);
        $Dpt_ids = array_unique($Dpt_ids);
        $temp_userid = array_unique($temp_userids);

        
        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','13')";
            Yii::app()->db->createCommand($query)->execute();
        }

        $temp_userids = implode(',', array_unique($temp_userids));
        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','1')";
        Yii::app()->db->createCommand($query)->execute();

        if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
          
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('inv_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT OUTER JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        } else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('inv_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'RIGHT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        } else {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('inv_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
       
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%" OR
                                        leadowner.first_name like "%' . $searchterm . '%" OR
                                        leadowner.last_name like "%' . $searchterm . '%"
                                            ', 'AND');
        }
        $comp_id = isset($_GET['comp_id']) ? $_GET['comp_id'] : ((int) Yii::app()->session['company_id'] > 0 ? Yii::app()->session['company_id'] : 0);
        if ($comp_id > 0 && !isset($_GET['month']))
            $criteria->addCondition('file.company_id=' . $comp_id, 'AND');
        if (isset($_GET['month']))
            $criteria->addCondition("YEAR(invoice_date)='" . date('Y') . "' AND MONTH(invoice_date) ='" . $_GET['month'] . "'", 'AND');
        if (empty($searchterm) && !isset($_GET['month']))
            $criteria->addCondition('(file.current_process_status="I" OR file.current_process_status="PI")', 'AND');

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.file_id DESC,t.invoice_date DESC,t.company_id',
            ),
            'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
        ));
    }*/
    
     public function search($searchterm = null) {
        $criteria = new CDbCriteria;
        $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('inv_search')) : $searchterm;
        $criteria->with = array('file', 'file.company', 'file.leadowner',);
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        $userModel = User::model()->findByPK(Yii::app()->user->id);
        //$criteria->addCondition('file.lead_owner_id in (' . implode(',', $userModel->subordinates) . ')', 'AND');
        (int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%" 
                                            ', 'AND');
        }
        if (empty($searchterm))
            $criteria->addCondition('t.isActive="Y"', 'AND');
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.file_id DESC,t.invoice_date DESC,t.company_id',
            ),
           'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
       ));
    }

    public function seacrhInvoice() {
        $criteria = new CDbCriteria;
        $criteria->with = "file";
        $comp_id = isset($_GET['comp_id']) ? $_GET['comp_id'] : ((int) Yii::app()->session['company_id'] > 0 ? Yii::app()->session['company_id'] : 0);
        $criteria->condition = "file.company_id=" . $comp_id;
        $criteria->order = "paid DESC";
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Invoice the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getTotals($ids) {
        $ids = implode(",", $ids);
        $connection = Yii::app()->db;
        if (!empty($ids)) {
            $command = $connection->createCommand("SELECT SUM(i.grand_total*o.exchange_rate)-SUM(IFNULL(c.credited_amount, 0)*o.exchange_rate) FROM `crm_invoice` i 
                join `crm_order` o
                on o.id=i.order_id
                left outer join `crm_creditnote` c 
               on i.id=c.invoice_id where i.id in ($ids)");
            return $command->queryScalar();

            /* $command = $connection->createCommand("SELECT SUM(credited_amount) FROM `crm_creditnote` where invoice_id in ($ids)");
              $total_credit_amnt = $command->queryScalar();
              return (($total_inv_amnt - $total_credit_amnt) - $this->file->order->exchange_rate); */
        }
        else
            return "";
    }

    public function calcIndividualProfit($items) {
        $costrate = true;
        foreach ($items as $eachItem) {
            if (empty($eachItem->cost_rate) || $eachItem->cost_rate == 0) {
                if ($eachItem->product->rate != 0) {
                    $eachItem->cost_rate = $eachItem->product->rate;
                    $eachItem->save();
                }
                else
                    $costrate = false;
            }
        }
        if ($costrate) {
            if ($this->file->current_process_status == "C" && ($this->grand_total == $this->returnedAmount)) {
                $profit = '0.00';
            } else {
                $profit = $this->grandTotalLC - $this->costTotal;
            }
            return $profit;
        } else {
            return false;
        }
    }

    public function getSumOfProfits($ids = null) {
        $sumOfprofit = 0;
        if (count($ids) > 0) {
            $ids = implode(",", $ids);

            $invoices = self::model()->findAll('id in (' . $ids . ')');
            foreach ($invoices as $eachInvoice) {
                $sumOfprofit += $eachInvoice->calcIndividualProfit($eachInvoice->items);
            }
        }
        return $sumOfprofit;
    }

    public function getGrandTotalLC() {
        return (($this->grand_total - $this->returnedAmount) * $this->file->order->exchange_rate);
    }

    public function getGrandTotal() {
        return (($this->grand_total - $this->returnedAmount) );
    }

    public function getProfit() {

        $profit = $this->calcIndividualProfit($this->items);
        return (!$profit) ? '<span color="red">CR0</span>' : Yii::app()->numberFormatter->formatCurrency($profit, "");
    }

    public function getStatus() {   
        $status = Masterfile::model()->find(array('condition' =>'id='.$this->file_id));
        if (count($this->returned) > 0)
            return 'CN';
        else{
            if($status->current_process_status == "PI")
                return 'P.Inv';
            else
            return 'INVOICED';
        }
    }
    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }

}
