<?php

/**
 * This is the model class for table "{{lead}}".
 *
 * The followings are the available columns in table '{{lead}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $enq_date
 * @property string $closing_date
 * @property string $title
 * @property string $notes
 * @property string $status
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 */
class Lead extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $lead_owner_id;
    //public $mobile1;
    //public $email1;
    public $company_name;
    public $searchstartdate;
    public $searchenddate;
    public $value;
    public $country;

    public function tableName() {
        return '{{lead}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id,company_id,  enq_date, closing_date, notes, status, lead_owner_id, form_id', 'required'),
            array('crm_user_id, file_id, contact_id, lead_owner_id', 'numerical', 'integerOnly' => true),
            array('company_id', 'length', 'max' => 20),
            array('email1,title', 'length', 'max' => 255),
            array('mobile1', 'length', 'max' => 150),
            array('status, isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, enq_date, closing_date, title, notes, status, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'leadOwner' => array(self::BELONGS_TO, 'User', 'lead_owner_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'companycontact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'formApproval' => array(self::HAS_ONE, 'FormApproval', 'form_id'),
            'formPermission' => array(self::HAS_ONE, 'FormPermission', 'form_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'enq_date' => 'Enquiry Date',
            'closing_date' => 'Closing Date',
            'title' => 'File Title',
            'notes' => 'Notes',
            'status' => 'Status',
            'lead_owner_id' => 'Lead Owner',
            'isActive' => 'Is Active',
            'email1' => 'E-mail',
            'mobile1' => 'Phone',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($searchterm = null) {
        $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();
        $temp_userids = array();
        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=1'));
        $notification  = Notification::model()->findAll(array('condition' => 'form_id=1'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if(is_array($Dpt_id)){
            if (in_array(Yii::app()->user->id, $Dpt_id))
                $file_id[] = $eachnotifcation->file_id;
            $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
            }
        }
       
        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval != "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=1 AND level=' . (int) $eachApproval->level))->user_id);
            /* else 
              $temp = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachApproval->level))->user_ids); */
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }
         if(is_array($file_id))
        $file_ids = array_unique($file_id);
         if(is_array($Dpt_ids))
        $Dpt_ids = array_unique($Dpt_ids); 
         if(is_array($temp_userids))
        $temp_userid = array_unique($temp_userids);
        //$file_ids = implode(',', array_unique($file_ids));
        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','1')";
            Yii::app()->db->createCommand($query)->execute();
        }

        $temp_userids = implode(',', array_unique($temp_userids));
        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','1')";
        Yii::app()->db->createCommand($query)->execute();

        if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
          
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('lead_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT OUTER JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        } else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('lead_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('t.file_id IN (tf.file_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'OR');
            //$criteria->addCondition('t.file_id IN (tf.file_id)','AND');
            
        }
           else {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('lead_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
        (int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        t.title like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%" OR
                                        leadowner.first_name like "%' . $searchterm . '%" OR
                                        leadowner.last_name like "%' . $searchterm . '%"
                                            ', 'AND');
        }
        if (empty($searchterm))
            $criteria->addCondition('status="Y" AND file.current_process_status="L"', 'AND');
        //if(Yii::app()->controller->id != "export")
        //$criteria->together = false;
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.enq_date DESC,t.id DESC,t.company_id DESC',
            ),
            'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
        ));
    }

    public function report() {
        $criteria = new CDbCriteria;
        $criteria->with = array('file', 'file.company');
        if (!empty($this->company_id))
            $condition[] = 't.company_id="' . $this->company_id . '"';
        if (!empty($this->sales_group))
            $condition[] = 'sales_group="' . $this->sales_group . '"';
        if (!empty($this->lead_owner_id))
            $condition[] = 'lead_owner_id="' . $this->lead_owner_id . '"';
        if (!empty($this->country))
            $condition[] = 'company.billing_country="' . $this->country . '"';
        if (!empty($this->value))
            $condition[] = 'grand_total<="' . $this->value . '"';
        if (!empty($this->status)) {
            switch ($this->status) {
                case 'C':
                    $condition[] = 'file.current_process_status <> "L"';
                    break;
                case 'P':
                    $condition[] = 'file.current_process_status="L" AND status="Y"';
                    break;
                case 'CL':
                    $condition[] = 'file.current_process_status="L" AND status="C"';
                    break;
                case 'L':
                    $condition[] = 'file.current_process_status="L" AND status="L"';
                    break;
            }
        }
        if (is_array($condition))
            $criteria->condition = implode(' AND ', $condition);
        if (!empty($this->searchstartdate) && !empty($this->searchenddate)) {
            $criteria->addBetweenCondition('enq_date', $this->searchstartdate, $this->searchenddate);
        }
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.company_id,t.enq_date DESC',
            ),
            'pagination' => false
        ));
    }

    public function getStatusOfLead() {
        switch ($this->status) {
            case 'Y':
                return "Open";
                break;
            case 'N':
                return "Not reachable";
                break;
            case 'F':
                return "FollowUp Calls";
                break;
            case 'S':
                return "Send Profile";
                break;
            case 'M':
                return "Meet in Person";
                break;
            case 'C':
                return "Closed";
                break;
            case 'O':
                return "Others";
                break;
            case 'L':
                return "Lost";
                break;
        }
    }

    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }
public function getFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->file_id.' and form_id='.$this->form_id, 'order' => 'id asc'));
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_send_for_approval).(($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);;
                
           // $html[].= (($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);
                
            }
        return implode('<br/>', $html);
    }
}
