<?php

/**
 * This is the model class for table "{{mas_shipping}}".
 *
 * The followings are the available columns in table '{{mas_shipping}}':
 * @property integer $id
 * @property string $via
 * @property string $description
 * @property string $isActive
 */
class MasShipping extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{mas_shipping}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('via', 'required'),
            //array('via', 'unique', 'on' => 'add'),
            array('id', 'numerical', 'integerOnly' => true),
            array('via, description', 'length', 'max' => 255),
            array('isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, via, description, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'via' => 'Via',
            'description' => 'Description',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */

        public function search() {
        $criteria = new CDbCriteria;
        $searchterm = trim(Yii::app()->request->getParam('via'));
        $criteria->addCondition('isActive =  "Y" AND company_id=' . Yii::app()->user->master_user_company_id, 'AND');
        if (!empty($searchterm))
            $criteria->addCondition('via like "%' . $searchterm . '%"', 'AND');
        return new CActiveDataProvider($this, array(
            'pagination' => array(
                'pageSize' => 5,
            ),
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.via ASC',
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return MasShipping the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    //function written by 

    public static function getShipping() {

        $condition = 'isActive =  "Y" AND company_id=' . Yii::app()->user->master_user_company_id;
        $model = self::model()->findAll(array('condition' => $condition,'order'=>'via'));
        return CHtml::listData($model, 'id', 'via');
    }

}
