<?php

/**
 * This is the model class for table "{{order}}".
 *
 * The followings are the available columns in table '{{order}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $order_date
 * @property string $delivery_date
 * @property string $sales_group
 * @property string $reference
 * @property string $currency
 * @property double $exchange_rate
 * @property string $payment_terms
 * @property string $shipping_by
 * @property string $lpo
 * @property string $others
 * @property double $net_amount
 * @property double $final_addition_percentage
 * @property double $final_addition_amount
 * @property double $final_deduction_percentage
 * @property double $final_deduction_amount
 * @property double $net_total
 * @property double $grand_total
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property DeliveryNotes[] $deliveryNotes
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 * @property OrderItem[] $orderItems
 */
class Order extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $company_name;
    public $lead_owner_id;
    public $shipping_conditions;
    public $title;
    public $no_of_orders;
    public $searchstartdate;
    public $searchenddate;
    public $total_value;
    public $month;
    public $value;
    public $country;
    public $status;
    public $netQuantity;

    public function tableName() {
        return '{{order}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, file_id,company_id, contact_id, order_date, delivery_date, sales_group,
                billing_address,shipping_address, currency, exchange_rate, payment_terms,lead_owner_id, shipping_by', 'required'),
            array('crm_user_id, file_id, contact_id, lead_owner_id', 'numerical', 'integerOnly' => true),
            array('exchange_rate, net_amount, final_addition_amount, final_deduction_amount, net_total, grand_total', 'numerical'),
            array('company_id', 'length', 'max' => 20),
            array('sales_group, reference, currency, payment_terms, shipping_by, lpo, others, shipping_conditions', 'length', 'max' => 255),
            array('isActive,materials_allocated,form_id', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            array(
                'delivery_date',
                'compare',
                'compareAttribute' => 'order_date',
                'operator' => '>=',
                'allowEmpty' => false,
                'message' => '{attribute} must be greater than "{compareValue}".'
            ),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, order_date, delivery_date, sales_group, reference, 
                currency, exchange_rate, payment_terms, shipping_by, lpo, others, net_amount, final_addition_percentage, 
                final_addition_amount, final_deduction_percentage, final_deduction_amount, net_total, grand_total, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNotes', 'order_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'currency0' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'items' => array(self::HAS_MANY, 'OrderItem', 'order_id'),
            'items1' => array(self::HAS_MANY, 'OrderItem', 'order_id'),
            'adItems' => array(self::HAS_MANY, 'OrderAddition', 'order_id'),
            'dedItems' => array(self::HAS_MANY, 'OrderDeduction', 'order_id'),
            'netAmount' => array(self::STAT, 'OrderItem', 'order_id', 'select' => 'SUM(net_amount)'),
            'netQuantity' => array(self::STAT, 'OrderItem', 'order_id', 'select' => 'SUM(quantity)'),
            //'deliveredQuantity'=>array(self::STAT, 'OrderItem', 'order_id', 'select' => 'SUM(quantity)'),
            'adTotal' => array(self::STAT, 'OrderAddition', 'order_id', 'select' => 'SUM(calculated_value)'),
            'dedTotal' => array(self::STAT, 'OrderDeduction', 'order_id', 'select' => 'SUM(calculated_value)'),
            'paymentTerm' => array(self::BELONGS_TO, 'MasPaymentTerm', 'payment_terms'),
            'currencyname' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'companycontact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'salesgroup' => array(self::BELONGS_TO, 'MasSalesGroup', 'sales_group'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'title' => 'File Title',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'company_name' => 'Company',
            'company_id' => 'Company ID',
            'contact_id' => 'Contact',
            'order_date' => 'Order Date',
            'delivery_date' => 'Delivery Date',
            'sales_group' => 'Sales Group',
            'reference' => 'Reference',
            'currency' => 'Currency',
            'exchange_rate' => 'Exchange Rate',
            'payment_terms' => 'Payment Terms',
            'shipping_by' => 'Delivery Terms',
            'lpo' => ' PO Ref :',
            'others' => 'Others',
            'net_amount' => 'Net Amount',
            'final_addition_percentage' => 'Final Addition Percentage',
            'final_addition_amount' => 'Final Addition Amount',
            'final_deduction_percentage' => 'Final Deduction Percentage',
            'final_deduction_amount' => 'Final Deduction Amount',
            'net_total' => 'Net Total',
            'grand_total' => 'Grand Total',
            'isActive' => 'Is Active',
            'lead_owner_id' => 'Lead Owner'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($searchterm = null) {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();

        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=4'));
        $notification = Notification::model()->findAll(array('condition' => 'form_id=4'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if (in_array(Yii::app()->user->id, $Dpt_id))
                $file_id[] = $eachnotifcation->file_id;
            $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
        }
        $temp_userids = array();
        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval !== "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=4 AND level=' . (int) $eachApproval->level))->user_id);
            /* else
              $temp = unserialize(PactDepartment::model()->find(array('condition' => 'id='.$eachApproval->level))->user_ids); */
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }
        $file_ids = array_unique($file_id);
        $Dpt_ids = array_unique($Dpt_ids);
        $temp_userid = array_unique($temp_userids);

        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','4')";
            Yii::app()->db->createCommand($query)->execute();
        }

        $temp_userids = implode(',', array_unique($temp_userids));
        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','4')";
        Yii::app()->db->createCommand($query)->execute();

         if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('order_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        } else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('order_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('t.file_id IN (tf.file_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'OR');
            //$criteria->addCondition('t.file_id IN (tf.file_id)','AND');
            
        } else {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('order_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
        (int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%" OR
                                        leadowner.first_name like "%' . $searchterm . '%" OR
                                        leadowner.last_name like "%' . $searchterm . '%"
                                            ', 'AND');
        }
        if (is_array($_GET['month']))
            $_GET['month'] = $_GET['month'][0];
        if (isset($_GET['month']))
            $criteria->addCondition("YEAR(order_date)='" . date('Y') . "' AND MONTH(order_date) ='" . $_GET['month'] . "'", 'AND');

        if (isset($_GET['sales_man'])) {
            $sales_man = (int) ($_GET['sales_man']);
            $criteria->addCondition("file.lead_owner_id=" . $sales_man, 'AND');
        }
        if (isset($_GET['sales_group'])) {
            $sales_group_id = (int) ($_GET['sales_group']);
            $criteria->addCondition("sales_group=" . $sales_group_id, 'AND');
        }
        if (isset($_GET['company_id'])) {
            $company_id = (int) ($_GET['company_id']);
            $criteria->addCondition("file.company_id=" . $company_id, 'AND');
        }
        if ((isset($_GET['sales_man']) || isset($_GET['sales_group']) || isset($_GET['company_id'])) && !isset($_GET['month'])) {
            $criteria->group = 'MONTH(order_date)';
            $criteria->select = 'MONTH(`order_date`) as id,MONTHNAME(`order_date`) as month,SUM(grand_total*exchange_rate) as total_value';
        }

        if (empty($searchterm) && !isset($_GET['month']) && !isset($_GET['sales_group']) && !isset($_GET['sales_man']) && !isset($_GET['company_id'])) {
            ((int) Yii::app()->session['company_id'] > 0) ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
            $criteria->addCondition('file.current_process_status="O" OR file.current_process_status="PD"', 'AND');
        }

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.file_id DESC,t.company_id,t.order_date DESC',
            ),
            'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
                // 'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) :!empty($searchterm)?array('pageSize' => 20):false,
        ));
    }

    public function report() {
        $criteria = new CDbCriteria;
        $criteria->with = array('file', 'file.company', 'netQuantity', 'file.deliveredQuantity');
        $criteria->together = true;
        if (!empty($this->company_id))
            $condition[] = 't.company_id="' . $this->company_id . '"';
        if (!empty($this->sales_group))
            $condition[] = 'sales_group="' . $this->sales_group . '"';
        if (!empty($this->lead_owner_id))
            $condition[] = 'lead_owner_id="' . $this->lead_owner_id . '"';
        if (!empty($this->country))
            $condition[] = 'company.billing_country="' . $this->country . '"';
        if (!empty($this->value))
            $condition[] = 'grand_total<="' . $this->value . '"';
        if (!empty($this->status)) {
            switch ($this->status) {
                case 'P':
                    $condition[] = 'file.current_process_status="O"';
                    break;
                case 'D':
                    $condition[] = 'file.current_process_status<>"O" AND t.netQuantity=file.deliveredQuantity';
                    break;
            }
        }
        if (is_array($condition))
            $criteria->condition = implode(' AND ', $condition);
        if (!empty($this->searchstartdate) && !empty($this->searchenddate)) {
            $criteria->addBetweenCondition('order_date', $this->searchstartdate, $this->searchenddate);
        }
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.order_date DESC,t.id DESC,t.file_id DESC,t.company_id DESC',
            ),
            'pagination' => false
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Order the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getTotals($ids) {
        $ids = implode(",", $ids);
        $connection = Yii::app()->db;
        if (!empty($ids)) {
            $command = $connection->createCommand("SELECT SUM(grand_total*exchange_rate) FROM `crm_order` where id in ($ids)");
            return $command->queryScalar();
        }
        else
            return "";
    }

    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }
 public function getPaymentTerm($payment_terms) {
        if($payment_terms){
        $model_PaymentTerms = MasPaymentTerm::model()->find(array('condition' => 'id=' . $payment_terms));
        return $model_PaymentTerms->payment_code.':'.$model_PaymentTerms->payment_terms;
        }
    }    
    public function getFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->file_id.' and form_id='.$this->form_id, 'order' => 'id asc'));
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_send_for_approval).(($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);;
                
           // $html[].= (($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);
                
            }
        return implode('<br/>', $html);
    }

}
