<?php

/**
 * This is the model class for table "crm_pre_quotation".
 *
 * The followings are the available columns in table 'crm_pre_quotation':
 * @property integer $id
 * @property integer $file_id
 * @property integer $rfq_id
 * @property integer $lead_owner_id
 * @property string $project_name
 * @property string $rfq_receive_date
 * @property string $date_project_bid_date
 * @property string $created_date
 */
class PreQuotation extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{pre_quotation}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('file_id, rfq_id, project_name, rfq_receive_date, date_project_bid_date', 'required'),
            array('file_id, rfq_id, lead_owner_id,creator_id', 'numerical', 'integerOnly' => true),
            array('project_name', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, file_id, rfq_id, lead_owner_id, project_name, rfq_receive_date, date_project_bid_date, created_date', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'creator_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'file_id' => 'File',
            'rfq_id' => 'RFQ-No.',
            'lead_owner_id' => 'Lead Owner',
            'project_name' => 'Project Name',
            'rfq_receive_date' => 'Rfq Receive Date',
            'date_project_bid_date' => 'Date Project Bid Date',
            'created_date' => 'Created Date',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($searchterm = null) {
        $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();
        $temp_userids = array();
        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=15'));
        $notification = Notification::model()->findAll(array('condition' => 'form_id=15'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if (is_array($Dpt_id)) {
                if (in_array(Yii::app()->user->id, $Dpt_id))
                    $file_id[] = $eachnotifcation->file_id;
                $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
            }
        }

        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval != "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=15 AND level=' . (int) $eachApproval->level))->user_id);
            /* else 
              $temp = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachApproval->level))->user_ids); */
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }
        if (is_array($file_id))
            $file_ids = array_unique($file_id);
        if (is_array($Dpt_ids))
            $Dpt_ids = array_unique($Dpt_ids);
        if (is_array($temp_userids))
            $temp_userid = array_unique($temp_userids);
        //$file_ids = implode(',', array_unique($file_ids));
        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','15')";
            Yii::app()->db->createCommand($query)->execute();
        }

        $temp_userids = implode(',', array_unique($temp_userids));
        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','15')";
        Yii::app()->db->createCommand($query)->execute();
        $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('prequote_search')) : $searchterm;
        if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT OUTER JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        } else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('t.file_id IN (tf.file_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'OR');
            //$criteria->addCondition('t.file_id IN (tf.file_id)','AND');
        } else {
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
        (int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('company.id=' . Yii::app()->session['company_id'], 'AND') : '';
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%" OR
                                        leadowner.first_name like "%' . $searchterm . '%" OR
                                        leadowner.last_name like "%' . $searchterm . '%"
                                            ', 'AND');
        }
        else
            $criteria->addCondition('file.current_process_status="PQ"', 'AND');
        //if(Yii::app()->controller->id != "export")
        //$criteria->together = false;
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,company.id DESC',
            ),
            'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return CrmPreQuotation the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }

}
