<?php

/**
 * This is the model class for table "{{purchasing_material_receipt_item}}".
 *
 * The followings are the available columns in table '{{purchasing_material_receipt_item_details}}':
 * @property integer $id
 * @property integer $material_receipt_id
 * @property string $description
 * @property double $quantity
 * @property integer $unit
 * @property double $received_quantity
 * @property string $country_of_origin
 * @property string $hsir_code
 * @property string $incomming_shipment_ref
 */
class PurchasingMaterialreceiptItem extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $product_name;
    
    public $remainig_quantity;
    public $materialreceipt_country_search;

    public function tableName() {
        return '{{purchasing_material_receipt_item}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('product_name,description, quantity,warehouse', 'required'),
            array('purchasing_materialreceipt_id,warehouse,product_id', 'numerical', 'integerOnly' => true),
            array('quantity, received_quantity,qcchecked_quantity', 'numerical'),
            array('description, country_of_origin, hsir_code, incomming_shipment_ref', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, purchasing_materialreceipt_id,warehouse,description, quantity, unit, received_quantity,qcchecked_quantity, country_of_origin, hsir_code, incomming_shipment_ref', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'purchasingmatrialreceipt' => array(self::BELONGS_TO, 'PurchasingMaterialReceipt', 'purchasing_materialreceipt_id'),
            'product' => array(self::BELONGS_TO, 'Store', 'product_id'),
            'warehousename' => array(self::BELONGS_TO, 'MasInvWarehouse', 'warehouse'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'purchasing_materialreceipt_id' => 'Material Receipt',
            'description' => 'Description',
            'quantity' => 'Quantity',
            'product_id' => 'Product',
            'unit' => 'Unit',
            'received_quantity' => 'Received Quantity',
            'qcchecked_quantity' => 'QCChecked Quantity',
            'country_of_origin' => 'Country Of Origin',
            'hsir_code' => 'Hsir Code',
            'incomming_shipment_ref' => 'Batch',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('purchasing_materialreceipt_id', $this->purchasing_materialreceipt_id);
        $criteria->compare('description', $this->description, true);
        $criteria->compare('product_id', $this->product_id);
        $criteria->compare('quantity', $this->quantity);
        $criteria->compare('unit', $this->unit);
        $criteria->compare('received_quantity', $this->received_quantity);
        $criteria->compare('qcchecked_quantity', $this->qcchecked_quantity);
        $criteria->compare('country_of_origin', $this->country_of_origin, true);
        $criteria->compare('hsir_code', $this->hsir_code, true);
        $criteria->compare('incomming_shipment_ref', $this->incomming_shipment_ref, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id ASC',
            ),
            'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 5) : false,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return PurchasingMaterialReceiptItemDetails the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
