<?php

/**
 * This is the model class for table "{{quotes}}".
 *
 * The followings are the available columns in table '{{quotes}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $company_id
 * @property integer $contact_id
 * @property string $qtn_start_date
 * @property string $qtn_close_date
 * @property string $sales_group
 * @property string $reference
 * @property string $currency
 * @property double $exchange_rate
 * @property string $payment_terms
 * @property string $shipping_by
 * @property string $qtn_validity
 * @property string $qtn_date
 * @property string $shipping_conditions
 * @property integer $probability
 * @property double $grand_total
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property CompanyContact $contact
 * @property User $crmUser
 * @property MasterFile $file
 * @property Company $company
 * @property QuotesItem[] $quotesItems
 */
class Quotes extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $company_name;
    public $lead_owner_id;
    public $title;
    public $searchstartdate;
    public $searchenddate;
    public $value;
    public $country;
    public $company_id1;

    public function tableName() {
        return '{{quotes}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('file_id,crm_user_id, company_id, lead_owner_id, contact_id, qtn_start_date, 
                 sales_group, currency, 
                exchange_rate, payment_terms,qtn_validity', 'required'),
            array('crm_user_id,form_id, file_id, contact_id, lead_owner_id,qtn_close_reason,probability', 'numerical', 'integerOnly' => true),
            array('exchange_rate, grand_total', 'numerical'),
            array('company_id', 'length', 'max' => 20),
            array('enq_ref,sales_group, reference, currency, payment_terms,shipping_address,billing_address, shipping_by, shipping_conditions,qtn_delivery_date, title', 'length', 'max' => 255),
            array('isActive,materials_allocated,status', 'length', 'max' => 1),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
           /* array(
                'qtn_close_date',
                'compare',
                'compareAttribute' => 'qtn_start_date',
                'operator' => '>=',
                'allowEmpty' => false,
                'message' => '{attribute} must be greater than "{compareValue}".'
            ),*/
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, company_id, contact_id, qtn_start_date, qtn_close_date, 
                sales_group, reference, currency, exchange_rate, payment_terms, shipping_by, qtn_validity, 
                qtn_date,expected_order_date, shipping_conditions, probability, grand_total, isActive,qtn_close_reason,status', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'leadowner' => array(self::BELONGS_TO, 'User', 'lead_owner_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'currency0' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'items' => array(self::HAS_MANY, 'QuotesItem', 'quotes_id'),
            'adItems' => array(self::HAS_MANY, 'QuotesAddition', 'quotes_id'),
            'dedItems' => array(self::HAS_MANY, 'QuotesDeduction', 'quotes_id'),
            'netAmount' => array(self::STAT, 'QuotesItem', 'quotes_id', 'select' => 'SUM(net_amount)'),
            'netQuantity' => array(self::STAT, 'QuotesItem', 'quotes_id', 'select' => 'SUM(quantity)'),
            'adTotal' => array(self::STAT, 'QuotesAddition', 'quotes_id', 'select' => 'SUM(calculated_value)'),
            'dedTotal' => array(self::STAT, 'QuotesDeduction', 'quotes_id', 'select' => 'SUM(calculated_value)'),
            'paymentTerm' => array(self::BELONGS_TO, 'MasPaymentTerm', 'payment_terms'),
            'companycontact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'currencyname' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'salesgroup' => array(self::BELONGS_TO, 'MasSalesGroup', 'sales_group'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'title' => 'File Title',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'enq_ref' => 'Enquiry Ref.',
            'company_name' => 'Company',
            'company_id' => 'Company',
            'contact_id' => 'Contact',
            'qtn_start_date' => 'Qtn Date',
            'qtn_close_date' => 'Qtn Closing',
            'sales_group' => 'Sales Group',
            'reference' => 'Revision',
            'currency' => 'Currency',
            'exchange_rate' => 'Exchange Rate',
            'payment_terms' => 'Payment Terms',
            'shipping_by' => 'Delivery Terms',
            'qtn_validity' => 'Qtn Validity',
            'qtn_date' => 'Qtn date',
            'qtn_delivery_date' => 'Qtn delivery Date',
            'shipping_conditions' => 'Shipping Conditions',
            'probability' => 'Probability',
            'grand_total' => 'Grand Total',
            'isActive' => 'Is Active',
            'lead_owner_id' => 'Lead Owner',
            'expected_order_date' => 'Expected Order Date'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($searchterm = null) {
        $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();

        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=3'));
        $notification = Notification::model()->findAll(array('condition' => 'form_id=3'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if (in_array(Yii::app()->user->id, $Dpt_id))
                $file_id[] = $eachnotifcation->file_id;
            $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
        }
        $temp_userids = array();
        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval !== "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=3 AND level=' . (int) $eachApproval->level))->user_id);
            /* else
              $temp = unserialize(PactDepartment::model()->find(array('condition' => 'id='.$eachApproval->level))->user_ids); */
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }
        $file_ids = array_unique($file_id);
        $Dpt_ids = array_unique($Dpt_ids);
        $temp_userid = array_unique($temp_userids);
        $temp_userids = implode(',', array_unique($temp_userids));

        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','3')";
            Yii::app()->db->createCommand($query)->execute();
        }

        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','3')";
        Yii::app()->db->createCommand($query)->execute();

        if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('quote_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        } else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('quote_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('t.file_id IN (tf.file_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'OR');
            //$criteria->addCondition('t.file_id IN (tf.file_id)','AND');
            
        } else {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('quote_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
        (int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%" OR
                                        leadowner.first_name like "%' . $searchterm . '%" OR
                                        leadowner.last_name like "%' . $searchterm . '%"
                                            ', 'AND');
        }
        if (empty($searchterm)) {
            // $criteria->addCondition('file.current_process_status="Q"', 'AND');
            $criteria->addCondition('t.status="Y" AND file.current_process_status="Q"', 'AND');
        }
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.qtn_date DESC,t.id DESC,t.file_id DESC,t.company_id DESC',
            ),
            'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
        ));
    }

    public function report() {
        $criteria = new CDbCriteria;
        $criteria->with = array('file', 'file.company');
        if (!empty($this->company_id))
            $condition[] = 't.company_id="' . $this->company_id . '"';
        if (!empty($this->sales_group))
            $condition[] = 'sales_group="' . $this->sales_group . '"';
        if (!empty($this->lead_owner_id))
            $condition[] = 'lead_owner_id="' . $this->lead_owner_id . '"';
        if (!empty($this->country))
            $condition[] = 'company.billing_country="' . $this->country . '"';
        if (!empty($this->value))
            $condition[] = 'grand_total<="' . $this->value . '"';
        if (!empty($this->probability))
            $condition[] = 'probability>="' . $this->probability . '"';
        if (!empty($this->status))
            $condition[] = 'status="' . $this->status . '"';
        if (is_array($condition))
            $criteria->condition = implode(' AND ', $condition);
        if (!empty($this->searchstartdate) && !empty($this->searchenddate)) {
            $criteria->addBetweenCondition('qtn_start_date', $this->searchstartdate, $this->searchenddate);
        }
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.file_id DESC,t.company_id,t.qtn_date DESC',
            ),
            'pagination' => false
        ));
    }

    public function printOut() {
        //dfg
        $criteria = new CDbCriteria;
        //$criteria->condition = "isActive='Y'";
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC,t.file_id DESC,t.company_id,t.qtn_date DESC',
            ),
                //'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Quotes the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getTotals($ids) {
        $ids = implode(",", $ids);
        $connection = Yii::app()->db;
        if (!empty($ids)) {
            $command = $connection->createCommand("SELECT SUM(grand_total*exchange_rate) FROM `crm_quotes` where id in ($ids)");
            return $command->queryScalar();
        }
        else
            return "";
    }

    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }
    
    public function getPaymentTerm($payment_terms) {
        if($payment_terms){
        $model_PaymentTerms = MasPaymentTerm::model()->find(array('condition' => 'id=' . $payment_terms));
        return $model_PaymentTerms->payment_code.':'.$model_PaymentTerms->payment_terms;
        }
    }
    
     public function getFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->file_id.' and form_id='.$this->form_id, 'order' => 'id asc'));
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_send_for_approval).(($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);;
                
           // $html[].= (($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);
                
            }
        return implode('<br/>', $html);
    }

}
