<?php

class DashboardController extends Controller {

    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array(),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array('Invoice', 'Order', 'Pymntrcvd', 'OrderBySalesGroup', 'SalesManByOrder', 'inventoryByAllocated', 'InventoryByExpiry',
                    'InventoryByClass', 'OrdersDelayed', 'PurchaseOrder', 'PurchaseOrderByVendor', 'OrderByCustomer', 'InventoryByGN', 'OrderByCountry',
                    'orderMtd', 'InvoiceMtd', 'leadsToQuotes', 'quotesToOrder', 'quotesStatus',
                ),
                'expression' => '$user->isMember()',
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    public function filters() {
        return array('accessControl'); // perform access control for CRUD operations
    }

    public function actionDeliveryNoteGraph() {
        $data_array = array();
        $totla_q = $total_v = 0;
        $modelDeliveryNotes = DeliveryNote::model()->with('file', 'items')->findAll(array(
            'select' => 'delivery_date,SUM(items.quantity) as tot_qty',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(delivery_date)="' . date('Y') . '"',
            'group' => 'MONTH(delivery_date)'));
        foreach ($modelDeliveryNotes as $i => $eachDelivryNote) {
            $data_array['q'][$i]['name'] = $data_array['v'][$i]['name'] = date('M', strtotime($eachDelivryNote->delivery_date));
            $data_array['q'][$i]['y'] = floatval($eachDelivryNote->tot_qty);
            $data_array['q'][$i]['color'] = $data_array['v'][$i]['color'] = $this->getARandomColor();
            $total_q +=$data_array['q'][$i]['y'];
        }
        $modelOrders = DeliveryNote::model()->with('file')->findAll(array(
            'select' => '*',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(delivery_date)="' . date('Y') . '"',
            'group' => 'MONTH(delivery_date)'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array['v'][$i]['y'] = floatval($eachOrder->order->netAmount * $eachOrder->order->exchange_rate);
            $total_v +=$data_array['v'][$i]['y'];
        }
        $JsonArray['total_v'] = number_format($total_v);
        $JsonArray['total_q'] = number_format($total_q);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionInvoice() {
        $data_array = array();
        $total = 0;
        $modelInvoices = Invoice::model()->with('file')->findAll(array(
            'select' => 'MONTH(t.invoice_date) as invoice_date , sum(t.grand_total * t.exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(invoice_date)="' . date('Y') . '"',
            'group' => 'MONTH(invoice_date)'));
        foreach ($modelInvoices as $i => $eachInvoice) {
            $credittedAmount = Creditnote::model()->find('invoice_id=' . $eachInvoice->id)->netAmount;
            $data_array[$i]['name'] = date("F", mktime(0, 0, 0, $eachInvoice->invoice_date, 10));
            $data_array[$i]['y'] = floatval(round(($eachInvoice->grand_total - $credittedAmount), 2));
            $data_array[$i]['id'] = $eachInvoice->invoice_date;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total +=round(($eachInvoice->grand_total - $credittedAmount));
        }
        // $JsonArray['total'] = Yii::app()->numberFormatter->formatCurrency($total, "");
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionOrder() {
        $data_array = array();
        $total = 0;
        $modelOrders = Order::model()->with('file')->findAll(array(
            'select' => 'MONTH(order_date) as order_date, sum(grand_total*exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 'MONTH(order_date)'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = date("F", mktime(0, 0, 0, $eachOrder->order_date, 10));
            $data_array[$i]['y'] = floatval(round($eachOrder->grand_total, 2));
            $data_array[$i]['id'] = $eachOrder->order_date;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total +=round($eachOrder->grand_total);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionorderMtd() {
        $data_array = array();
        $month = (isset($_POST['month']) && (int) $_POST['month'] > 0) ? $_POST['month'] : date('m');
        //$command = Yii::app()->db->createCommand('call load_order_mtd_graph(' . Yii::app()->user->master_user_company_id . ',' . Yii::app()->user->master_user_branch_id . ',' . date('m') . ')');
        $command = Yii::app()->db->createCommand('call load_order_mtd_graph(' . Yii::app()->user->master_user_company_id . ',' . Yii::app()->user->master_user_branch_id . ',' . $month . ')');
        $modelOrders = $command->queryAll();
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array['x'][$i]['name'] = $data_array['cats'][] = User::model()->findByPK($eachOrder['lead_owner_id'])->first_name;
            $data_array['x'][$i]['y'] = floatval(round($eachOrder['grand_total'], 2));
            $data_array['x'][$i]['color'] = $this->getARandomColor();
            $data_array['x'][$i]['id'] = $eachOrder['lead_owner_id'];
        }
        echo CJSON::encode($data_array);
    }

    public function actionActivity() {
        $data_array = array();
        $month = (isset($_POST['month']) && (int) $_POST['month'] > 0) ? $_POST['month'] : date('m');
        /* $modelOrders = Activity::model()->with('user')->findAll(array(
          'select' => ' t.crm_user_id',
          'condition' => 't.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND
          t.own_branch_id=' . Yii::app()->user->master_user_branch_id,
          'order' => 'user.first_name',
          'group' => 't.crm_user_id')); */
        $users = User::model()->findAll();
        foreach ($users as $eachuser) {
            /* $data['M'][] = Activity::model()->count('crm_user_id=' . $eachuser->id.' AND typ_of_activity="M"');
              $data['T'][] = Activity::model()->count('crm_user_id=' . $eachuser->id.' AND typ_of_activity="T"');
              $data['V'][] = Activity::model()->count('crm_user_id=' . $eachuser->id.' AND typ_of_activity="V"');
              $data['C'][] = Activity::model()->count('crm_user_id=' . $eachuser->id.' AND typ_of_activity="C"');
              $data_array['cats'][] = $eachuser->first_name; */
            $data_array['cats'][] = User::model()->findByPK($eachOrder['lead_owner_id'])->first_name;
            $data_array['x0'][$i]['name'] = "Meeting";
            $data_array['x0'][$i]['y'] = floatval(Activity::model()->count('crm_user_id=' . $eachuser->id . ' AND typ_of_activity="M"'));
            $data_array['x0'][$i]['color'] = $this->getARandomColor();
            $data_array['x0'][$i]['id'] = $eachOrder['lead_owner_id'];

            $data_array['x1'][$i]['name'] = "T";
            $data_array['x1'][$i]['y'] = floatval(Activity::model()->count('crm_user_id=' . $eachuser->id . ' AND typ_of_activity="T"'));
            $data_array['x1'][$i]['color'] = $this->getARandomColor();
            $data_array['x1'][$i]['id'] = $eachOrder['lead_owner_id'];

            $data_array['x2'][$i]['name'] = "Visit";
            $data_array['x2'][$i]['y'] = floatval(Activity::model()->count('crm_user_id=' . $eachuser->id . ' AND typ_of_activity="V"'));
            $data_array['x2'][$i]['color'] = $this->getARandomColor();
            $data_array['x2'][$i]['id'] = $eachOrder['lead_owner_id'];

            $data_array['x3'][$i]['name'] = "Call";
            $data_array['x3'][$i]['y'] = floatval(Activity::model()->count('crm_user_id=' . $eachuser->id . ' AND typ_of_activity="C"'));
            $data_array['x3'][$i]['color'] = $this->getARandomColor();
            $data_array['x3'][$i]['id'] = $eachOrder['lead_owner_id'];
        }
        /* $data_array['x0'] = array('name' => 'Meeting', 'data' => $data['M']);
          $data_array['x1'] = array('name' => 'Quotes', 'data' => $data['T']);
          $data_array['x2'] = array('Visit' => 'Orders', 'data' => $data['V']);
          $data_array['x3'] = array('Call' => 'Orders', 'data' => $data['C']); */
        echo CJSON::encode($data_array);
    }

    public function actionLeadsToQuotes() {
        $data_array = array();
        $modelFiles = MasterFile::model()->with('leadowner')->findAll(array(
            'select' => ' t.lead_owner_id,t.current_process_status',
            'condition' => 't.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND 
                t.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND 
                    (start_from="L" OR start_from="Q")',
            'order' => 'leadowner.first_name',
            'group' => 't.lead_owner_id'));

        foreach ($modelFiles as $eachFile) {
            $data['leads'][] = floatval(Lead::model()->with('file')->count('file.lead_owner_id=' . $eachFile->lead_owner_id . ' AND YEAR(enq_date)="' . date('Y') . '"'));
            $data['quotes'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachFile->lead_owner_id . ' AND YEAR(qtn_start_date)="' . date('Y') . '"'));
            $data['orders'][] = floatval(Order::model()->with('file')->count('file.lead_owner_id=' . $eachFile->lead_owner_id . ' AND YEAR(order_date)="' . date('Y') . '"'));
            $data_array['cats'][] = $eachFile->leadowner->first_name;
        }

        $data_array['x0'] = array('name' => 'Leads', 'data' => $data['leads']);
        $data_array['x1'] = array('name' => 'Quotes', 'data' => $data['quotes']);
        $data_array['x2'] = array('name' => 'Orders', 'data' => $data['orders']);
        echo CJSON::encode($data_array);
    }

    public function actionQuotesToOrder() {
        $data_array = array();
        $modelOrders = MasterFile::model()->with('order', 'leadowner')->findAll(array(
            'select' => ' t.lead_owner_id, COUNT(*) as avariable',
            'condition' => 't.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND 
                t.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order.order_date)="' . date('Y') . '"
                AND start_from="Q" AND current_process_status<>"Q"',
            'order' => 'leadowner.first_name',
            'group' => 't.lead_owner_id'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array['x'][$i]['name'] = $data_array['cats'][] = $eachOrder->leadowner->first_name;
            $data_array['x'][$i]['y'] = floatval($eachOrder->avariable);
            $data_array['x'][$i]['color'] = $this->getARandomColor();
            $data_array['x'][$i]['id'] = $eachOrder->lead_owner_id;
        }
        echo CJSON::encode($data_array);
    }

    public function actionInvoiceMtd() {
        $data_array = array();
        $month = (isset($_POST['month']) && (int) $_POST['month'] > 0) ? $_POST['month'] : date('m');
        $command = Yii::app()->db->createCommand('call load_invoice_mtd_graph(' . Yii::app()->user->master_user_company_id . ',' . Yii::app()->user->master_user_branch_id . ',' . $month . ')');
        //$command = Yii::app()->db->createCommand('call load_invoice_mtd_graph(' . Yii::app()->user->master_user_company_id . ',' . Yii::app()->user->master_user_branch_id . ',' . date('m') . ')');
        $modelOrders = $command->queryAll();
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array['x'][$i]['name'] = $data_array['cats'][] = User::model()->findByPK($eachOrder['lead_owner_id'])->first_name;
            $data_array['x'][$i]['y'] = floatval(round($eachOrder['grand_total'], 2));
            $data_array['x'][$i]['color'] = $this->getARandomColor();
            $data_array['x'][$i]['id'] = $eachOrder['lead_owner_id'];
        }
        echo CJSON::encode($data_array);
    }

    public function actionQuotesStatus() {
        $data_array = array();
        $data_array_new = array();
        /*if (isset($_POST['month_from']) && isset($_POST['month_to'])) {
            $users = Quotes::model()->with('file')->findAll(array('condition' => 'qtn_start_date BETWEEN "' . $_POST['month_from'] . '" AND "' . $_POST['month_to'] . '"', 'group' => 'file.lead_owner_id'));
            foreach ($users as $eachuser) {
                $data['total'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND qtn_start_date BETWEEN "' . $_POST['month_from'] . '" AND "' . $_POST['month_to'] . '"'));
                $data['order'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND file.current_process_status <> "Q" AND qtn_start_date BETWEEN "' . $_POST['month_from'] . '" AND "' . $_POST['month_to'] . '"'));
                $data['lost'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND file.current_process_status = "Q" AND status = "L" AND qtn_start_date BETWEEN "' . $_POST['month_from'] . '" AND "' . $_POST['month_to'] . '"'));
                $data['closed'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND file.current_process_status = "Q" AND status = "C" AND qtn_start_date BETWEEN "' . $_POST['month_from'] . '" AND "' . $_POST['month_to'] . '"'));
                $data_array['cats'][] = $eachuser->file->leadowner->first_name;
            }
        } else {*/
            $users = Quotes::model()->with('file')->findAll(array('group' => 'file.lead_owner_id'));
            foreach ($users as $eachuser) {
                $data['total'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id));
                $data['order'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND file.current_process_status <> "Q"'));
                $data['lost'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND file.current_process_status = "Q" AND status = "L"'));
                $data['closed'][] = floatval(Quotes::model()->with('file')->count('file.lead_owner_id=' . $eachuser->file->lead_owner_id . ' AND file.current_process_status = "Q" AND status = "C"'));
                $data_array['cats'][] = $eachuser->file->leadowner->first_name;
           /* }*/
        }
        $modelDashboard = new Dashboard;
        $data_array['x0'] = array('name' => 'Total', 'data' => $data['total'], 'color' => $modelDashboard->randomColor);
        $data_array['x1'] = array('name' => 'Order', 'data' => $data['order'], 'color' => $modelDashboard->randomColor);
        $data_array['x2'] = array('name' => 'Lost', 'data' => $data['lost'], 'color' => $modelDashboard->randomColor);
        $data_array['x3'] = array('name' => 'Closed', 'data' => $data['closed'], 'color' => $modelDashboard->randomColor);
        //$data_array_new['x'] = array($data_array['x0'], $data_array['x1'], $data_array['x2'], $data_array['x3']);
        //$data_array_new['cats'] = $data_array['cats'];
        echo CJSON::encode($data_array);
    }

    //invoiceMtd

    public function actionPymntrcvd() {
        $data_array = array();
        $total = 0;
        $modelRcvdInvoices = ReceivedInvoices::model()->with('recpt', 'invoice', 'invoice.file')->findAll(array(
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id .
            ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id .
            ' AND YEAR(recpt.received_date)=' . date('Y'),
            'select' => 'recpt.received_date as received_date, sum(t.received_amt*invoice.exchange_rate) as received_amt',
            'group' => 'MONTH(recpt.received_date)'));
        foreach ($modelRcvdInvoices as $i => $eachRcvdInvoice) {
            $data_array[$i]['name'] = date('M', strtotime($eachRcvdInvoice->received_date));
            $data_array[$i]['y'] = floatval(round($eachRcvdInvoice->received_amt, 2));
            //$data_array[$i]['id'] = $eachRcvdInvoice->order_date;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachRcvdInvoice->received_amt);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionOrderBySalesGroup() {
        $data_array = array();
        $total = 0;
        $modelOrders = Order::model()->with('file', 'salesgroup')->findAll(array(
            'select' => 'sales_group, order_date, sum(grand_total*exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 't.sales_group'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = $eachOrder->salesgroup->group_name;
            $data_array[$i]['y'] = floatval(round($eachOrder->grand_total, 2));
            $data_array[$i]['id'] = $eachOrder->sales_group;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachOrder->grand_total);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionSalesManByOrder() {
        $data_array = array();
        $total = 0;
        $modelOrders = Order::model()->with('file')->findAll(array(
            'select' => 'order_date, sum(grand_total*exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 'file.lead_owner_id'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = $eachOrder->file->leadowner->fullname;
            $data_array[$i]['y'] = floatval(round($eachOrder->grand_total, 2));
            $data_array[$i]['id'] = $eachOrder->file->lead_owner_id;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachOrder->grand_total);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionOrderByCustomer() {
        $data_array = array();
        $total = 0;
        $modelOrders = Order::model()->with('file')->findAll(array(
            'select' => 'file.company_id, order_date, sum(grand_total*exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 'file.company_id'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = $eachOrder->file->company->company_name;
            $data_array[$i]['y'] = floatval(round($eachOrder->grand_total, 2));
            $data_array[$i]['id'] = $eachOrder->file->company_id;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachOrder->grand_total);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionOrderByCountry() {
        $data_array = array();
        $total = 0;
        $modelOrders = Order::model()->with('file', 'file.company')->findAll(array(
            'select' => 'file.company_id, order_date, sum(grand_total*exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 'company.billing_country'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = $eachOrder->file->company->countryBilling->country_name;
            $data_array[$i]['y'] = floatval(round($eachOrder->grand_total, 2));
            $data_array[$i]['id'] = $eachOrder->file->company_id;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachOrder->grand_total);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionInventoryByClass() {
        $data_array = array();
        $totla_q = $total_v = 0;
        $modelItems = Store::model()->with('location')->findAll(array(
            'condition' => 'company_id =' . Yii::app()->user->master_user_company_id,
            'select' => 'sum(location.quantity) as tot_quantity_by_class,sum(location.quantity*rate) as tot_value_by_class, product_class_id, rate',
            'group' => 'product_class_id'));
        foreach ($modelItems as $i => $eachItem) {
            $data_array['q'][$i]['name'] = $data_array['v'][$i]['name'] = empty($eachItem->product_class_id) ? "No class" : $eachItem->productclass->product_class;
            $data_array['q'][$i]['y'] = floatval($eachItem->tot_quantity_by_class > 0 ? $eachItem->tot_quantity_by_class : 1);
            $data_array['q'][$i]['id'] = $data_array['v'][$i]['id'] = $eachItem->product_class_id;
            $data_array['v'][$i]['y'] = floatval($eachItem->tot_value_by_class);
            $data_array['q'][$i]['color'] = $this->getARandomColor();
            $data_array['v'][$i]['color'] = $this->getARandomColor();
            $total_q +=$data_array['q'][$i]['y'];
            $total_v +=$eachItem->tot_value_by_class;
        }
        $JsonArray['total_v'] = number_format($total_v);
        $JsonArray['total_q'] = number_format($total_q);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionInventoryByGN() {
        $data_array = array();
        $totla_q = $total_v = 0;
        $modelItems = Store::model()->with('location')->findAll(array(
            'condition' => 'company_id =' . Yii::app()->user->master_user_company_id,
            'select' => 'sum(location.quantity) as tot_quantity_by_class,sum(location.quantity*rate) as tot_value_by_class, product_class_id, rate',
            'group' => 'generic_name'));
        foreach ($modelItems as $i => $eachItem) {
            $data_array['q'][$i]['name'] = $data_array['v'][$i]['name'] = empty($eachItem->generic_name) ? "-none-" : $eachItem->generic_name;
            $data_array['q'][$i]['y'] = floatval($eachItem->tot_quantity_by_class > 0 ? $eachItem->tot_quantity_by_class : 1);
            $data_array['q'][$i]['id'] = $data_array['v'][$i]['id'] = $eachItem->product_class_id;
            $data_array['v'][$i]['y'] = floatval($eachItem->tot_value_by_class);
            $data_array['q'][$i]['color'] = $data_array['v'][$i]['color'] = $this->getARandomColor();
            $total_q +=$data_array['q'][$i]['y'];
            $total_v +=$eachItem->tot_value_by_class;
        }
        $JsonArray['total_v'] = number_format($total_v);
        $JsonArray['total_q'] = number_format($total_q);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionInventoryByExpiry() {
        $data_array = array();
        $totla_q = $total_v = 0;
        $modelItems = InventoryItems::model()->with('store', 'store.location')->findAll(array(
            'condition' => 'YEAR(t.expiry_date)=' . date('Y') . ' AND location.quantity >0 ',
            'select' => 'expiry_date, sum(location.quantity) as sum_of_quantity, sum(location.quantity*rate) as sum_of_total_value',
            'group' => 'MONTH(t.expiry_date)'));
        foreach ($modelItems as $i => $eachItem) {
            $data_array['q'][$i]['name'] = $data_array['v'][$i]['name'] = date('M', strtotime($eachItem->expiry_date));
            $data_array['q'][$i]['y'] = floatval($eachItem->sum_of_quantity);
            $data_array['v'][$i]['y'] = floatval($eachItem->sum_of_total_value);
            $data_array['q'][$i]['color'] = $data_array['v'][$i]['color'] = $this->getARandomColor();
            $total_q +=$eachItem->sum_of_quantity;
            $total_v +=$eachItem->sum_of_total_value;
        }
        $JsonArray['total_v'] = number_format($total_v);
        $JsonArray['total_q'] = number_format($total_q);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionInventoryByAllocated() {
        $data_array = array();
        $totla_q = $total_v = 0;
        $modelItems = AllocatedMaterial::model()->with('file', 'product')->findAll(array(
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(allocation_end_date)=' . date('Y'),
            'select' => 'allocation_end_date, sum(count) as sum_of_count, sum(count*product.rate) as sum_of_total_value',
            'group' => 'MONTH(allocation_end_date)'));
        foreach ($modelItems as $i => $eachItem) {
            $data_array['q'][$i]['name'] = $data_array['v'][$i]['name'] = date('M', strtotime($eachItem->allocation_end_date));
            $data_array['q'][$i]['y'] = floatval($eachItem->sum_of_count);
            $data_array['v'][$i]['y'] = floatval($eachItem->sum_of_total_value);
            $data_array['q'][$i]['color'] = $data_array['v'][$i]['color'] = $this->getARandomColor();
            $total_q +=$data_array['q'][$i]['y'];
            $total_v +=$eachItem->sum_of_total_value;
        }
        $JsonArray['total_v'] = number_format($total_v);
        $JsonArray['total_q'] = number_format($total_q);
        $JsonArray['graph_data'] = $data_array;

        echo CJSON::encode($JsonArray);
    }

    //purchase graphs
    public function actionPurchaseOrder() {
        $data_array = array();
        $total = 0;
        $modelOrders = PurchasingOrder::model()->with('file')->findAll(array(
            'select' => 'MONTH(order_date) as order_date, sum(grand_total*exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 'MONTH(order_date)'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = date("F", mktime(0, 0, 0, $eachOrder->order_date, 10));
            $data_array[$i]['y'] = floatval(round($eachOrder->grand_total, 2));
            $data_array[$i]['id'] = $eachOrder->order_date;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachOrder->grand_total);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionPurchaseInvoice() {
        $data_array = array();
        $total = 0;
        $modelInvoices = PurchasingInvoice::model()->with('file')->findAll(array(
            'select' => 'MONTH(invoice_date) as invoice_date, sum(grand_total * exchange_rate) as grand_total',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id . ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(invoice_date)="' . date('Y') . '"',
            'group' => 'MONTH(invoice_date)'));
        foreach ($modelInvoices as $i => $eachInvoice) {
            $credittedAmount = Purchasingcredit::model()->find('purchasing_invoice_id=' . $eachInvoice->id)->netAmount;
            $data_array[$i]['name'] = date("F", mktime(0, 0, 0, $eachInvoice->invoice_date, 10));
            $data_array[$i]['y'] = floatval(round(($eachInvoice->grand_total - $credittedAmount), 2));
            $data_array[$i]['id'] = $eachInvoice->invoice_date;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round(($eachInvoice->grand_total - $credittedAmount));
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionPurchaseOrderByClass() {
        $data_array = array();
        $total = 0;
        $modelItems = PurchasingOrderItem::model()->with('product', 'product.location', 'parent', 'parent.file')->findAll(array(
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id .
            ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(parent.order_date)="' . date('Y') . '"',
            'select' => '
                sum(t.quantity) as tot_quantity_by_class,
                sum(t.quantity*t.rate) as tot_value_by_class',
            'group' => 'product.product_class_id'));
        foreach ($modelItems as $i => $eachItem) {
            $data_array[$i]['name'] = empty($eachItem->product->product_class_id) ? "No class" : $eachItem->product->productclass->product_class;
            $data_array[$i]['y'] = floatval($eachItem->tot_quantity_by_class > 0 ? $eachItem->tot_quantity_by_class : 1);
            $data_array[$i]['id'] = $eachItem->product->product_class_id;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=$data_array[$i]['y'];
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    public function actionPurchaseOrderByVendor() {
        $data_array = array();
        $total = 0;
        $modelOrders = PurchasingOrder::model()->with('file')->findAll(array(
            'select' => 'vendor_id,SUM(grand_total*exchange_rate) as tot_amount',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id .
            ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id . ' AND YEAR(order_date)="' . date('Y') . '"',
            'group' => 'vendor_id'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array[$i]['name'] = $eachOrder->vendor->company_name;
            $data_array[$i]['y'] = floatval(round($eachOrder->tot_amount, 2));
            $data_array[$i]['id'] = $eachOrder->vendor_id;
            $data_array[$i]['color'] = $this->getARandomColor();
            $total+=round($eachOrder->tot_amount);
        }
        $JsonArray['total'] = number_format($total);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

    //management graphs
    public function actionOrdersDelayed() {
        $data_array = array();
        $totla_q = $total_v = 0;
        $modelOrders = Order::model()->with('file')->findAll(array(
            'select' => 'order_date, sum(grand_total*exchange_rate) as grand_total, COUNT(*) AS no_of_orders ',
            'condition' => 'file.own_company_id =' . Yii::app()->user->master_user_company_id .
            ' AND file.own_branch_id=' . Yii::app()->user->master_user_branch_id .
            ' AND YEAR(order_date)="' . date('Y') . '" AND delivery_date < "' . date('Y-m-d') . '" AND file.current_process_status="O"',
            'group' => 'MONTH(order_date)'));
        foreach ($modelOrders as $i => $eachOrder) {
            $data_array['q'][$i]['name'] = $data_array['v'][$i]['name'] = date('M', strtotime($eachOrder->order_date));
            $data_array['q'][$i]['y'] = floatval($eachOrder->no_of_orders);
            $data_array['v'][$i]['y'] = floatval($eachOrder->grand_total);
            $data_array['q'][$i]['color'] = $data_array['v'][$i]['color'] = $this->getARandomColor();
            $total_q +=$data_array['q'][$i]['y'];
            $total_v +=$data_array['v'][$i]['y'];
        }
        $JsonArray['total_v'] = number_format($total_v);
        $JsonArray['total_q'] = number_format($total_q);
        $JsonArray['graph_data'] = $data_array;
        echo CJSON::encode($JsonArray);
    }

}