<?php

/**
 * This is the model class for table "{{form_approval}}".
 *
 * The followings are the available columns in table '{{form_approval}}':
 * @property integer $id
 * @property integer $form_id
 * @property integer $file_id
 * @property integer $level
 * @property string $arrived_req_for_approval
 * @property integer $approved_or_unapproved_by
 * @property string $notes
 * @property string $remarks
 * @property string $is_approved
 * @property string $date_of_approval
 */
class FormApproval extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_approval}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            //array('form_id, file_id, level, approved_or_unapproved_by, notes, remarks, date_of_approval', 'required'),
            array('form_id, file_id, level, approved_or_unapproved_by', 'numerical', 'integerOnly' => true),
            array('arrived_req_for_approval, is_approved', 'length', 'max' => 1),
            array('date_send_for_approval,date_of_approval, notes, remarks', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, form_id, file_id, level, arrived_req_for_approval, approved_or_unapproved_by, notes, remarks, is_approved, date_of_approval', 'safe', 'on' => 'search'),
        );
    }

//approved_or_unapproved_by: the filed is also using for storing the user id of the sender
    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'formPermission' => array(self::BELONGS_TO, 'FormPermission', array('level', 'form_id')),
            'form' => array(self::BELONGS_TO, 'Form', array('level', 'form_id')),
            'user' => array(self::BELONGS_TO, 'User', 'approved_or_unapproved_by'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'form_id' => 'Form',
            'file_id' => 'File',
            'level' => 'Level',
            'arrived_req_for_approval' => 'Arrived Req For Approval',
            'approved_or_unapproved_by' => 'Approved Or Unapproved By',
            'notes' => 'Notes',
            'remarks' => 'Remarks',
            'is_approved' => 'Please select status',
            'date_of_approval' => 'Date Of Approval',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('form_id', $this->form_id);
        $criteria->compare('file_id', $this->file_id);
        $criteria->compare('level', $this->level);
        $criteria->compare('arrived_req_for_approval', $this->arrived_req_for_approval, true);
        $criteria->compare('approved_or_unapproved_by', $this->approved_or_unapproved_by);
        $criteria->compare('notes', $this->notes, true);
        $criteria->compare('remarks', $this->remarks, true);
        $criteria->compare('is_approved', $this->is_approved, true);
        $criteria->compare('date_of_approval', $this->date_of_approval, true);
        $criteria->order = "level DESC,id ASC";
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            //'pagination' => false,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormApproval the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getLevelAndname() {
        switch ($this->arrived_req_for_approval) {
            case 'Y':
            case 'A':
                return FormPermission::model()->find(array('condition' => 'form_id=' . $this->form_id . ' AND level=' . $this->level))->name;
                break;
            default:
                return PactDepartment::model()->findByPK($this->level)->department_name;
                break;
        }
    }

    public function getStatus() {
        switch ($this->arrived_req_for_approval) {
            case 'Y':
                $status = "Approval Requested";
                break;
            /*case 'N':
                $status = "Notification sent";
                break;*/
            case'A':
                switch ($this->is_approved) {
                    case 'Y':
                        $status = "Approved";
                        break;
                    case 'N':
                        $status = "Rejected";
                        break;
                }
                break;
        }
        return $status;
        //($data->arrived_req_for_approval!="Y")?($data->is_approved=="Y"?"Approved":"Rejecetd"):(($data->arrived_req_for_approval=="N")?"Notification sent":"Approval requested")',
    }

}
