<?php

/**
 * This is the model class for table "{{form_ho_delivery}}".
 *
 * The followings are the available columns in table '{{form_ho_delivery}}':
 * @property integer $form_ho_id
 * @property string $delivery_time
 * @property integer $advance_payment
 * @property integer $letter_of_credit
 * @property integer $approved_drawings_submital
 * @property string $warrantee
 * @property string $inclusions
 * @property string $exclusions
 */
class FormHoDelivery extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_ho_delivery}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('weeks_from,wmfd, wmfc, other_remarks,form_ho_id, delivery_time, advance_payment, letter_of_credit, approved_drawings_submital, warrantee, inclusions, exclusions', 'safe'),
            array('form_ho_id, advance_payment, letter_of_credit, approved_drawings_submital', 'numerical', 'integerOnly' => true),
            array('weeks_from,delivery_time, warrantee', 'length', 'max' => 20),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('form_ho_id, delivery_time, advance_payment, letter_of_credit, approved_drawings_submital, warrantee, inclusions, exclusions', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'form_ho_id' => 'Form Ho',
            'delivery_time' => 'Delivery Time',
            'advance_payment' => 'Advance Payment',
            'letter_of_credit' => 'Letter Of Credit',
            'approved_drawings_submital' => 'Approved Drawings & Technical Submital',
            'warrantee' => 'Warranty details',
            'inclusions' => 'Inclusions',
            'exclusions' => 'Exclusions',
            'other_remarks' => 'Other Remarks',
            'wmfd'=>'Delivery',
            'wmfc'=>'Commissioning'
            
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('form_ho_id', $this->form_ho_id);
        $criteria->compare('delivery_time', $this->delivery_time, true);
        $criteria->compare('advance_payment', $this->advance_payment);
        $criteria->compare('letter_of_credit', $this->letter_of_credit);
        $criteria->compare('approved_drawings_submital', $this->approved_drawings_submital);
        $criteria->compare('warrantee', $this->warrantee, true);
        $criteria->compare('inclusions', $this->inclusions, true);
        $criteria->compare('exclusions', $this->exclusions, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormHoDelivery the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
