<?php

/**
 * This is the model class for table "{{form_jo_general}}".
 *
 * The followings are the available columns in table '{{form_jo_general}}':
 * @property integer $id
 * @property integer $form_id
 * @property integer $file_id
 * @property string $job_order_number
 * @property string $project_reference_number
 * @property string $project_name
 * @property string $project_type
 * @property string $visit_no
 * @property string $date_of_jo
 * @property string $location
 * @property integer $contact_person
 * @property string $contact_number
 * @property string $commercial_status
 * @property string $details_of_job_order
 * @property string $remarks
 * @property string $requested_by
 * @property string $requested_to
 * @property integer $eng
 * @property integer $proc
 * @property integer $fab
 * @property integer $o_and_m
 * @property integer $commercial
 * @property integer $logistics
 * @property string $history_last_jo_no
 * @property string $history_last_visit
 * @property string $site_visitor_schedules_date
 * @property string $site_visitor_schedules_time
 */
class FormJoGeneral extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{form_jo_general}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('form_id, file_id, job_order_number, project_reference_number, project_name, project_type, visit_no, date_of_jo, location, contact_person, contact_number, commercial_status, details_of_job_order, remarks, requested_by, requested_to, eng, proc, fab, o_and_m, commercial, logistics, history_last_jo_no, history_last_visit, site_visitor_schedules_date, site_visitor_schedules_time', 'required'),
			array('form_id, file_id, contact_person, eng, proc, fab, o_and_m, commercial, logistics', 'numerical', 'integerOnly'=>true),
			array('job_order_number, project_reference_number, project_name, visit_no, location, commercial_status, requested_by, requested_to, history_last_jo_no', 'length', 'max'=>255),
			array('project_type', 'length', 'max'=>15),
			array('contact_number', 'length', 'max'=>50),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, form_id, file_id, job_order_number, project_reference_number, project_name, project_type, visit_no, date_of_jo, location, contact_person, contact_number, commercial_status, details_of_job_order, remarks, requested_by, requested_to, eng, proc, fab, o_and_m, commercial, logistics, history_last_jo_no, history_last_visit, site_visitor_schedules_date, site_visitor_schedules_time', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),     
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'form_id' => 'Form',
			'file_id' => 'File',
			'job_order_number' => 'Job Order No.',
			'project_reference_number' => 'Project Reference No.',
			'project_name' => 'Project Name',
			'project_type' => 'Project Type',
			'visit_no' => 'Visit No.',
			'date_of_jo' => 'Date',
			'location' => 'Location',
			'contact_person' => 'Contact Person',
			'contact_number' => 'Contact No.',
			'commercial_status' => 'Commercial Status',
			'details_of_job_order' => 'Details Of Job Order',
			'remarks' => 'Remarks',
			'requested_by' => 'Requested By',
			'requested_to' => 'To',
			'eng' => 'ENG',
			'proc' => 'PROC',
			'fab' => 'FAB',
			'o_and_m' => 'O&M',
			'commercial' => 'COM\'CL',
			'logistics' => 'LOGIST',
			'history_last_jo_no' => 'Last J.O. No.',
			'history_last_visit' => 'Last Visit',
			'site_visitor_schedules_date' => 'Date',
			'site_visitor_schedules_time' => 'Time',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('form_id',$this->form_id);
		$criteria->compare('file_id',$this->file_id);
		$criteria->compare('job_order_number',$this->job_order_number,true);
		$criteria->compare('project_reference_number',$this->project_reference_number,true);
		$criteria->compare('project_name',$this->project_name,true);
		$criteria->compare('project_type',$this->project_type,true);
		$criteria->compare('visit_no',$this->visit_no,true);
		$criteria->compare('date_of_jo',$this->date_of_jo,true);
		$criteria->compare('location',$this->location,true);
		$criteria->compare('contact_person',$this->contact_person);
		$criteria->compare('contact_number',$this->contact_number,true);
		$criteria->compare('commercial_status',$this->commercial_status,true);
		$criteria->compare('details_of_job_order',$this->details_of_job_order,true);
		$criteria->compare('remarks',$this->remarks,true);
		$criteria->compare('requested_by',$this->requested_by,true);
		$criteria->compare('requested_to',$this->requested_to,true);
		$criteria->compare('eng',$this->eng);
		$criteria->compare('proc',$this->proc);
		$criteria->compare('fab',$this->fab);
		$criteria->compare('o_and_m',$this->o_and_m);
		$criteria->compare('commercial',$this->commercial);
		$criteria->compare('logistics',$this->logistics);
		$criteria->compare('history_last_jo_no',$this->history_last_jo_no,true);
		$criteria->compare('history_last_visit',$this->history_last_visit,true);
		$criteria->compare('site_visitor_schedules_date',$this->site_visitor_schedules_date,true);
		$criteria->compare('site_visitor_schedules_time',$this->site_visitor_schedules_time,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return FormJoGeneral the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
