<?php

/**
 * This is the model class for table "{{form_rfq_date}}".
 *
 * The followings are the available columns in table '{{form_rfq_date}}':

 * @property integer $file_id
 * @property string $date_project_bid_date
 * @property string $date_received_by_proposal
 * @property string $date_received_by_pact
 * @property integer $delivery_ex_work_price
 * @property integer $delivery_delivery_to_site
 * @property integer $delivery_cif
 * @property integer $delivery_fob
 * @property integer $delivery_c_f
 * @property integer $proposal_detailed
 * @property integer $proposal_short
 */
class FormRfqDate extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_rfq_date}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('rfq_receive_date,date_project_bid_date, delivery_ex_work_price, delivery_cfr, delivery_cif, delivery_fob, delivery_d_d, proposal_detailed, proposal_short,proposal_firm,proposal_budgetary', 'safe'),
            array('delivery_ex_work_price, delivery_cif, delivery_fob, proposal_detailed, proposal_short,proposal_firm,proposal_budgetary', 'numerical', 'integerOnly' => true),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('file_id, rfq_receive_date,date_project_bid_date, delivery_ex_work_price, delivery_delivery_cfr, delivery_cif, delivery_fob, delivery_d_d, proposal_detailed, proposal_short,proposal_firm,proposal_budgetary', 'safe', 'on' => 'search'),
            array('form_rfq_id', 'safe')
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'formRfqGeneral' => array(self::BELONGS_TO, 'FormRfqGeneral', 'form_rfq_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'file_id' => 'File',
            'date_project_bid_date' => 'Project Bid Date',
            'rfq_receive_date' => 'RFQ Received Date',
            'date_received_by_proposal' => 'Date Received by Proposal',
            'date_received_by_pact' => 'Date Req\'d. by PACT',
            'delivery_ex_work_price' => 'Ex.Works Factory',
            'delivery_cfr' => 'CFR',
            'delivery_cif' => 'CIF',
            'delivery_fob' => 'FOB',
            'delivery_d_d' => 'Door to Door',
            'proposal_detailed' => 'Detailed Proposal',
            'proposal_short' => 'Short Proposal',
            'proposal_firm'=> 'Proposal Firm',
            'proposal_budgetary'=>'Proposal Budgetary'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;


        $criteria->compare('file_id', $this->file_id);
        $criteria->compare('date_project_bid_date', $this->date_project_bid_date, true);
        $criteria->compare('date_received_by_proposal', $this->date_received_by_proposal, true);
        $criteria->compare('date_received_by_pact', $this->date_received_by_pact, true);
        $criteria->compare('delivery_ex_work_price', $this->delivery_ex_work_price);
        $criteria->compare('delivery_cif', $this->delivery_cif);
        $criteria->compare('delivery_fob', $this->delivery_fob);
        $criteria->compare('proposal_detailed', $this->proposal_detailed);
        $criteria->compare('proposal_short', $this->proposal_short);
        $criteria->compare('proposal_firm', $this->proposal_firm);
        $criteria->compare('proposal_budgetary', $this->proposal_budgetary);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormRfqDate the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
