<?php

/**
 * This is the model class for table "{{form_rfq}}".
 *
 * The followings are the available columns in table '{{form_rfq}}':
 * @property integer $id
 * @property integer $form_id
 * @property integer $file_id
 * @property string $project
 * @property string $name
 * @property string $company_id
 * @property string $telephone
 * @property string $email
 * @property integer $contact_id
 * @property integer $date_of_rfq
 * @property integer $sales_engr
 * @property string $location
 * @property string $city
 * @property string $fax
 * @property string $direct_phone
 * @property string $address
 */
class FormRfqGeneral extends CActiveRecord {

    public $company;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_rfq_general}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('file_id, project_name, company, date_of_rfq, sales_engr, location', 'required'),
            array('file_id, project_name, company, telephone, email, contact_id, date_of_rfq, sales_engr, location, city, fax, address', 'safe'),
            array('crm_user_id,form_id, file_id, contact_id, sales_engr', 'numerical', 'integerOnly' => true),
            array('project_name, company, email, location, city,telephone,fax', 'length', 'max' => 255),
            array('direct_phone', 'length', 'max' => 15),
            array('project_name_no,notes', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, form_id, file_id, project_name, company, telephone, email, contact, date_of_rfq, sales_engr, location, city, fax, address', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'formRfqDate' => array(self::HAS_ONE, 'FormRfqDate', 'form_rfq_id'),
            'formRfqType' => array(self::HAS_ONE, 'FormRfqType', 'form_rfq_id'),
            'formRfqRo' => array(self::HAS_ONE, 'FormRfqRo', 'form_rfq_id'),
            'formRfqWwtpStp' => array(self::HAS_ONE, 'FormRfqWwtpStp', 'form_rfq_id'),
            'formRfqMisc' => array(self::HAS_ONE, 'FormRfqMisc', 'form_rfq_id'),
            'formRfqWtd' => array(self::HAS_ONE, 'FormRfqWtd', 'form_rfq_id'),
            'formApproval' => array(self::HAS_MANY, 'FormApproval', 'file_id'),
            'salesEngnr' => array(self::BELONGS_TO, 'User', 'sales_engr'),
            'companyContact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'crmUser' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'form_id' => 'Form',
            'file_id' => 'File',
            'project_name' => 'Project Name',
            'company' => 'Client',
            'telephone' => 'Telephone',
            'email' => 'Email',
            'contact_id' => 'Contact person',
            'date_of_rfq' => 'Date Of RFQ',
            'sales_engr' => 'Sales Engineer',
            'location' => 'Project Location',
            'city' => 'City',
            'fax' => 'Fax',
            'direct_phone' => 'Direct Phone',
            'address' => 'Address',
            'notes' => 'Other Remarks'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($searchterm = null) {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();


        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=2'));
        $notification = Notification::model()->findAll(array('condition' => 'form_id=2'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if (in_array(Yii::app()->user->id, $Dpt_id))
                $file_id[] = $eachnotifcation->file_id;
            $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
        }
        $temp_userids = array();
        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval !== "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=2 AND level=' . (int) $eachApproval->level))->user_id);
            /* else
              $temp = unserialize(PactDepartment::model()->find(array('condition' => 'id='.(int) $eachApproval->level))->user_ids); */
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }
        $file_ids = array_unique($file_id);
        $Dpt_ids = array_unique($Dpt_ids);
        $temp_userid = array_unique($temp_userids);

        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','2')";
            Yii::app()->db->createCommand($query)->execute();
        }

        $temp_userids = implode(',', array_unique($temp_userids));
        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','2')";
        Yii::app()->db->createCommand($query)->execute();

        if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('rfq_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //(int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        } 
        else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('rfq_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('t.file_id IN (tf.file_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'OR');
            //$criteria->addCondition('t.file_id IN (tf.file_id)','AND');
        }
        else {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('rfq_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%"', 'AND');
        }

        if (empty($searchterm)) {
            ((int) Yii::app()->session['company_id'] > 0) ? $criteria->addCondition('file.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
            $criteria->addCondition('file.current_process_status="RFQ"', 'AND');
        }

        $criteria->order = "t.id DESC";
        /* $criteria->compare('id', $this->id);
          $criteria->compare('form_id', $this->form_id);
          $criteria->compare('file_id', $this->file_id);
          $criteria->compare('project_name', $this->project_name, true);


          $criteria->compare('telephone', $this->telephone, true);
          $criteria->compare('email', $this->email, true);
          $criteria->compare('contact_id', $this->contact_id);
          $criteria->compare('date_of_rfq', $this->date_of_rfq);
          $criteria->compare('sales_engr', $this->sales_engr);
          $criteria->compare('location', $this->location, true);
          $criteria->compare('city', $this->city, true);
          $criteria->compare('fax', $this->fax, true);
          $criteria->compare('direct_phone', $this->direct_phone, true);
          $criteria->compare('address', $this->address, true); */

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormRfq the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }
    
    public function getFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->file_id.' and form_id='.$this->form_id, 'order' => 'id asc'));
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_send_for_approval).(($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);;
                
           // $html[].= (($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);
                
            }
        return implode('<br/>', $html);
    }
    

}

