<?php

/**
 * This is the model class for table "{{form_rfq_ro}}".
 *
 * The followings are the available columns in table '{{form_rfq_ro}}':

 * @property integer $form_rfq_id
 * @property string $ro_capacity
 * @property string $feed_tds
 * @property string $product_tds
 * @property integer $well
 * @property integer $river_intake
 * @property integer $sea_well
 * @property integer $sea_open_intake
 * @property integer $tap_water
 * @property integer $others
 * @property integer $water_analysis_by_client
 * @property integer $water_analysis_assumed_by_pact
 * @property integer $water_analysis_others
 * @property string $notes
 */
class FormRfqRo extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_rfq_ro}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('
                desalination_swro,desalination_bwro, desalination_hbro,                
ro_capacity, feed_tds, product_tds,final_capacity,final_product_tds,final_feed_tds, well, river_intake, sea_well, sea_open_intake, tap_water, others, water_analysis_by_client, water_analysis_assumed_by_pact, water_analysis_others, notes', 'safe'),
            array('form_rfq_id, well, river_intake, sea_well, sea_open_intake, tap_water, water_analysis_by_client, water_analysis_assumed_by_pact, water_analysis_others', 'numerical', 'integerOnly' => true),
            array('others,ro_capacity, feed_tds, product_tds,final_capacity,final_product_tds,final_feed_tds', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('form_rfq_id, ro_capacity, feed_tds, product_tds,final_capacity,final_product_tds,final_feed_tds, well, river_intake, sea_well, sea_open_intake, tap_water, h2s, water_analysis_by_client, water_analysis_assumed_by_pact, water_analysis_others, notes', 'safe', 'on' => 'search'),
            array('form_rfq_id', 'safe')
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'form_rfq_id' => 'Form Rfq',
            'ro_capacity' => 'Capacity',
            'feed_tds' => 'Feed TDS',
            'product_tds' => 'Product TDS',
            'final_capacity'=>'Final Capacity',
            'final_product_tds'=>'Final Product TDS',
            'final_feed_tds'=>'Final Feed TDS',
            'well' => 'Well',
            'river_intake' => 'River Intake',
            'sea_well' => 'Sea Well',
            'sea_open_intake' => 'Sea Open Intake',
            'tap_water' => 'Tap Water',
            'others' => 'Others',
            'water_analysis_by_client' => 'By Client',
            'water_analysis_assumed_by_pact' => 'Assumed By PACT',
            'water_analysis_others' => 'Others',
            'notes' => 'Other Notes',
            'desalination_swro' => 'SWRO',
            'desalination_bwro' => 'BWRO',
            'desalination_hbro' => 'HBRO',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;


        $criteria->compare('form_rfq_id', $this->form_rfq_id);
        $criteria->compare('ro_capacity', $this->ro_capacity, true);
        $criteria->compare('feed_tds', $this->feed_tds, true);
        $criteria->compare('product_tds', $this->product_tds, true);
        $criteria->compare('final_capacity', $this->final_capacity, true);
        $criteria->compare('final_product_tds', $this->final_product_tds, true);
        $criteria->compare('final_feed_tds', $this->final_feed_tds, true);
        $criteria->compare('well', $this->well);
        $criteria->compare('river_intake', $this->river_intake);
        $criteria->compare('sea_well', $this->sea_well);
        $criteria->compare('sea_open_intake', $this->sea_open_intake);
        $criteria->compare('tap_water', $this->tap_water);
        $criteria->compare('h2s', $this->h2s);
        $criteria->compare('water_analysis_by_client', $this->water_analysis_by_client);
        $criteria->compare('water_analysis_assumed_by_pact', $this->water_analysis_assumed_by_pact);
        $criteria->compare('water_analysis_others', $this->water_analysis_others);
        $criteria->compare('notes', $this->notes, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormRfqRo the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
