<?php

/**
 * This is the model class for table "{{form_rfq_wwtp_stp}}".
 *
 * The followings are the available columns in table '{{form_rfq_wwtp_stp}}':

 * @property string $form_rfq_id
 * @property string $plant_capacity
 * @property string $bod_in
 * @property string $ss_in
 * @property string $nh3_in
 * @property string $bod_out
 * @property string $ss_out
 * @property string $nh3_out
 * @property string $ambient_temperature
 * @property string $altitude
 * @property string $others
 * @property integer $construction_gls_stacks
 * @property integer $construction_concrete
 * @property integer $construction_packaged
 * @property integer $construction_frp_packaged
 * @property integer $process_type_extended_aeration
 * @property integer $process_type_sbr
 * @property integer $process_type_mbbr
 * @property integer $process_type_saf
 */
class FormRfqWwtpStp extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_rfq_wwtp_stp}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('process_type_grey_water,process_type_mbr,plant_capacity, bod_in, ss_in, nh3_in, bod_out, ss_out, nh3_out,tkn_in,tkn_out,no3_out,ambient_temperature, altitude, others, construction_gls_stacks, construction_concrete, construction_packaged, construction_frp_packaged, process_type_extended_aeration, process_type_sbr, process_type_mbbr, process_type_saf', 'safe'),
            array('process_type_grey_water,construction_gls_stacks, construction_concrete, construction_packaged, construction_frp_packaged, process_type_extended_aeration, process_type_sbr, process_type_mbbr, process_type_saf', 'numerical', 'integerOnly' => true),
            array('process_type_others,form_rfq_id, plant_capacity, bod_in, ss_in, nh3_in, bod_out, ss_out, nh3_out,tkn_in,tkn_out,no3_out,ambient_temperature, altitude, others', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('form_rfq_id, plant_capacity, bod_in, ss_in, nh3_in, bod_out, ss_out, nh3_out,tkn_in,tkn_out,no3_out,ambient_temperature, altitude, others, construction_gls_stacks, construction_concrete, construction_packaged, construction_frp_packaged, process_type_extended_aeration, process_type_sbr, process_type_mbbr, process_type_saf', 'safe', 'on' => 'search'),
            array('form_rfq_id', 'safe')
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'form_rfq_id' => 'Form Rfq',
            'plant_capacity' => 'Capacity',
            'bod_in' => 'BOD-In',
            'ss_in' => 'SS-In',
            'nh3_in' => 'NH3/NH3-N In',
            'bod_out' => 'BOD-Out',
            'ss_out' => 'SS-Out',
            'nh3_out' => 'NH3/NH3-N',
            'tkn_in'=> 'TKN In',
            'tkn_out'=>'TKN Out',
            'no3_out'=>'NO3 Out',
            'ambient_temperature' => 'Ambient Temperature',
            'altitude' => 'Altitude',
            'others' => 'Other Notes',
            'construction_gls_stacks' => 'GLS Tanks',
            'construction_concrete' => 'Concrete',
            'construction_packaged' => 'Steel Packaged',
            'construction_frp_packaged' => 'FRP Packaged',
            'process_type_extended_aeration' => 'Extended Aeration',
            'process_type_sbr' => 'SBR',
            'process_type_mbr' => 'MBR',
            'process_type_mbbr' => 'MBBR',
            'process_type_saf' => 'SAF',
            'process_type_others'=>'Others',
            'process_type_grey_water'=>'Grey Water'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;


        $criteria->compare('form_rfq_id', $this->form_rfq_id, true);
        $criteria->compare('plant_capacity', $this->plant_capacity, true);
        $criteria->compare('bod_in', $this->bod_in, true);
        $criteria->compare('ss_in', $this->ss_in, true);
        $criteria->compare('nh3_in', $this->nh3_in, true);
        $criteria->compare('bod_out', $this->bod_out, true);
        $criteria->compare('ss_out', $this->ss_out, true);
        $criteria->compare('nh3_out', $this->nh3_out, true);
        $criteria->compare('tkn_in', $this->tkn_in, true);
        $criteria->compare('tkn_out', $this->tkn_out, true);
        $criteria->compare('no3_out', $this->no3_out, true);
        $criteria->compare('ambient_temperature', $this->ambient_temperature, true);
        $criteria->compare('altitude', $this->altitude, true);
        $criteria->compare('others', $this->others, true);
        $criteria->compare('construction_gls_stacks', $this->construction_gls_stacks);
        $criteria->compare('construction_concrete', $this->construction_concrete);
        $criteria->compare('construction_packaged', $this->construction_packaged);
        $criteria->compare('construction_frp_packaged', $this->construction_frp_packaged);
        $criteria->compare('process_type_extended_aeration', $this->process_type_extended_aeration);
        $criteria->compare('process_type_sbr', $this->process_type_sbr);
        $criteria->compare('process_type_mbbr', $this->process_type_mbbr);
        $criteria->compare('process_type_saf', $this->process_type_saf);
        $criteria->compare('process_type_grey_water', $this->process_type_grey_water);
        

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormRfqWwtpStp the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
