<?php

/**
 * This is the model class for table "{{form_visible_departments}}".
 *
 * The followings are the available columns in table '{{form_visible_departments}}':
 * @property integer $id
 * @property integer $form_id
 * @property string $department_id
 * @property string $created_date
 */
class FormVisibleDepartments extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{form_visible_departments}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('form_id, department_id', 'required'),
			array('id, form_id', 'numerical', 'integerOnly'=>true),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, form_id, department_id, created_date', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
                    'form' => array(self::BELONGS_TO, 'Form', 'form_id'),
                    'department' => array(self::BELONGS_TO, 'PactDepartment', 'department_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'form_id' => 'Form',
			'department_id' => 'Department',
			'created_date' => 'Created Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('form_id',$this->form_id);
		$criteria->compare('department_id',$this->department_id,true);
		$criteria->compare('created_date',$this->created_date,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return FormVisibleDepartments the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
        public function getForms() {
        $model = Form::model()->findAll(array('order' => 'form_order'));
        return CHtml::listData($model, 'id', 'name');
    }
        public function getDepartments() {
        $model = PactDepartment::model()->findAll(array('order' => 'id'));
        return CHtml::listData($model, 'id', 'department_name');
    }
    public function getPermittedDepartments() {
        $usernames = array();
        $userids = unserialize($this->department_id);
        if (is_array($userids)) {
            $departments = PactDepartment::model()->findAll(array('condition' => 'id in (' . implode(',', $userids) . ')'));
            if (!empty($departments)) {
                foreach ($departments as $eachdepartments)
                    $departmentName[] = $eachdepartments->department_name;
            }
        }
        return implode(',', $departmentName);
    }
}
