<?php

/**
 * This is the model class for table "{{inventory_goods_issue}}".
 *
 * The followings are the available columns in table '{{inventory_goods_issue}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property string $goods_issue_date
 * @property integer $file_id
 * @property string $notes
 * @property string $terms_and_conditions
 * @property string $remarks
 * @property string $isActive
 * @property string $reference
 * @property integer $customer_id
 * @property integer $project
 */
class InventoryGoodsIssue extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $project_name_in_inventorygoodsissue;
    public $customer_name;

    public function tableName() {
        return '{{inventory_goods_issue}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('goods_issue_date,reference', 'required'),
            array('crm_user_id, file_id, customer_id, project', 'numerical', 'integerOnly' => true),
            array('isActive', 'length', 'max' => 1),
            array('reference', 'length', 'max' => 255),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, goods_issue_date, file_id, notes, terms_and_conditions, remarks, isActive, reference, customer_id, project', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'projectname' => array(self::BELONGS_TO, 'MasProject', 'project'),
            'customer' => array(self::BELONGS_TO, 'Company', 'customer_id'),
            'items' => array(self::HAS_MANY, 'InventoryGoodsIssueItem', 'inventory_goods_issue_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'goods_issue_date' => 'Goods Issue Date',
            'file_id' => 'File',
            'notes' => 'Notes',
            'terms_and_conditions' => 'Terms And Conditions',
            'remarks' => 'Remarks',
            'isActive' => 'Is Active',
            'reference' => 'Reference',
            'customer_id' => 'Customer',
            'project' => 'Project',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    
      public function search($searchterm = null) {
        $criteria = new CDbCriteria;
        $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('inventory_goodsissue_search')) : $searchterm;
        $criteria->with = array('file','projectname','customer');
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
         if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        projectname.project_title like "%' . $searchterm . '%" OR 
                                        customer.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%"', 'AND');
        }
         return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC, t.file_id DESC ,t.goods_issue_date DESC',
            ),
            'pagination' => array('pageSize' => 5),
        ));
    }
     


    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return InventoryGoodsIssue the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

}
