<?php

/**
 * This is the model class for table "{{mas_currency}}".
 *
 * The followings are the available columns in table '{{mas_currency}}':
 * @property integer $id
 * @property string $currency
 * @property string $currency_code
 * @property double $exchange_rate
 * @property string $isBaseCurrency
 * @property string $isActive
 */
class MasCurrency extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{mas_currency}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('currency, currency_code, exchange_rate', 'required'),
            array('id', 'numerical', 'integerOnly' => true),
            array('exchange_rate', 'numerical'),
            array('currency, currency_code', 'length', 'max' => 255),
            array('currency', 'unique', 'on' => 'add'),
            array('isBaseCurrency, isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, currency, currency_code, exchange_rate, isBaseCurrency, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'baseCurrency'=>array(self::HAS_MANY, 'MasCompanyBranch', 'currency_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'currency' => 'Currency',
            'currency_code' => 'Currency Code',
            'exchange_rate' => 'Exchange Rate',
            'isBaseCurrency' => 'Base Currency',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */

        public function search() {
        $criteria = new CDbCriteria;
        $searchterm = trim(Yii::app()->request->getParam('currency_name'));
        $criteria->addCondition('isActive =  "Y" AND company_id=' . Yii::app()->user->master_user_company_id, 'AND');
        if (!empty($searchterm))
            $criteria->addCondition('currency like "%' . $searchterm . '%"', 'AND');
        return new CActiveDataProvider($this, array(
            'pagination' => array(
                'pageSize' => 5,
            ),
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.currency ASC',
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return MasCurrency the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public static function getCurrency() {

        $condition = 't.isActive =  "Y" AND t.company_id=' . Yii::app()->user->master_user_company_id;
        $model = self::model()->findAll(array('condition' => $condition,'order'=>'currency'));
        return CHtml::listData($model, 'id', 'currency');
    }
    
    public static function getBaseCurrency() {
        
    }

}
