<?php

/**
 * This is the model class for table "{{mas_project}}".
 *
 * The followings are the available columns in table '{{mas_project}}':
 * @property integer $id
 * @property string $project_title
 * @property string $location
 * @property string $start_date
 * @property string $end_date
 * @property string $isActive
 */
class MasProject extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{mas_project}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('project_title, location, start_date, end_date,project_no,project_head,project_head_mail,isComplete', 'required'),
            array('project_title,project_no,project_head_mail, location', 'length', 'max' => 255),
             array('project_no', 'unique', 'on' => 'add'),
            array('project_head', 'numerical', 'integerOnly' => true),
            array('isActive,isComplete', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, project_title, location, start_date, end_date, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'project_title' => 'Project Title',
            'location' => 'Location',
            'start_date' => 'Start Date',
            'end_date' => 'End Date',
            'isActive' => 'Is Active',
            'isComplete' =>'Is Complete'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */

            public function search() {
        $criteria = new CDbCriteria;
        $searchterm = trim(Yii::app()->request->getParam('project_no'));
        $criteria->addCondition('isActive =  "Y" AND company_id=' . Yii::app()->user->master_user_company_id.' AND company_branch_id='.Yii::app()->user->master_user_branch_id, 'AND');
        if (!empty($searchterm))
            $criteria->addCondition('project_no like "%' . $searchterm . '%"', 'AND');
        return new CActiveDataProvider($this, array(
            'pagination' => array(
                'pageSize' => 5,
            ),
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.project_no',
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return MasProject the static model class
     */
    public static function getProject() {
        $condition = 'isActive =  "Y" AND company_id=' . Yii::app()->user->master_user_company_id.' AND company_branch_id='.Yii::app()->user->master_user_branch_id;
        $model = self::model()->findAll(array('condition' => $condition));
        return CHtml::listData($model, 'id', 'project_title');
    }

    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function renderUserdetails($data, $row) {
        $usedetails = User::model()->findByPk((int) $data->project_head);
        return $usedetails->first_name . ' ' . $usedetails->last_name;
    }

}
