<?php

/**
 * This is the model class for table "{{master_file}}".
 *
 * The followings are the available columns in table '{{master_file}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $company_id
 * @property string $start_from
 * @property string $current_process_status
 * @property integer $lead_owner_id
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property AllocatedMaterials[] $allocatedMaterials
 * @property CreditNote[] $creditNotes
 * @property DeliveryNotes[] $deliveryNotes
 * @property Document[] $documents
 * @property Invoice[] $invoices
 * @property Lead[] $leads
 * @property Order[] $orders
 * @property Quotes[] $quotes
 */
class MasterFile extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $file_for_materialallocation;
    public $avariable;
    public $deliveredQuantity;

    public function tableName() {
        return '{{master_file}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, start_from, current_process_status', 'required'),
            array('file_number, crm_user_id,current_form_id, company_id, lead_owner_id,own_company_id, own_branch_id, approved_by', 'numerical', 'integerOnly' => true),
            array('start_from, isActive, is_approved', 'length', 'max' => 1),
            array('current_process_status', 'length', 'max' => 2),
            array('file_title,date_of_approval', 'length', 'max' => 255),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, company_id, start_from, current_process_status, lead_owner_id, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'allocatedMaterials' => array(self::HAS_MANY, 'AllocatedMaterial', 'file_id'),
            'creditNotes' => array(self::HAS_MANY, 'Creditnote', 'file_id'),
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNote', 'file_id'),
            'deliveredQuantity' => array(self::STAT, 'Order', 'file_id', 'select' => 'SUM(d_item.picked_qty)',
                'join' => '
                    JOIN {{master_file}} as mf 
                    JOIN {{delivery_note}} as d_note 
                    JOIN {{delivery_item}} as d_item 
                    ON d_item.delivery_note_id = d_note.id AND mf.id=t.file_id AND mf.id=d_note.file_id',
            ),
            'materialReceipt' => array(self::HAS_MANY, 'PurchasingMaterialreceipt', 'file_id'),
            'documents' => array(self::HAS_MANY, 'Document', 'file_id'),
            'invoices' => array(self::HAS_MANY, 'Invoice', 'file_id'),
            'lead' => array(self::HAS_ONE, 'Lead', 'file_id'),
            'rfq' => array(self::HAS_ONE, 'FormRfqGeneral', 'file_id'),
            'hor' => array(self::HAS_ONE, 'FormHoGeneral', 'file_id'),
            'order' => array(self::HAS_ONE, 'Order', 'file_id'),
            'preQuote' => array(self::HAS_ONE, 'PreQuotation', 'file_id'),
            'quote' => array(self::HAS_ONE, 'Quotes', 'file_id'),
            'company' => array(self::BELONGS_TO, 'Company', 'company_id'),
            'owncompany' => array(self::BELONGS_TO, 'MasCompany', 'own_company_id'),
            'ownBranch' => array(self::BELONGS_TO, 'MasCompanyBranch', 'own_branch_id'),
            'purchaserequisition' => array(self::HAS_ONE, 'PurchasingRequisition', 'file_id'),
            'purchaseenquiry' => array(self::HAS_ONE, 'PurchasingEnquiry', 'file_id'),
            'purchaseorder' => array(self::HAS_ONE, 'PurchasingOrder', 'file_id'),
            'purchaseinvoice' => array(self::HAS_MANY, 'PurchasingInvoice', 'file_id'),
            'leadowner' => array(self::BELONGS_TO, 'User', 'lead_owner_id'),
            'fileCreator' => array(self::BELONGS_TO, 'User', 'crm_user_id'),
            'approvedBy' => array(self::BELONGS_TO, 'User', 'approved_by'),
            'purchasecredit' => array(self::HAS_MANY, 'Purchasingcredit', 'file_id'),
            'profitCalc0' => array(self::HAS_ONE, 'ProfitCalc', 'file_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'company_id' => 'Company',
            'file_title' => 'File Title',
            'start_from' => 'Start From',
            'current_process_status' => 'Current Process Status',
            'lead_owner_id' => 'Lead Owner',
            'isActive' => 'Is Active',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('company_id', $this->company_id);
        $criteria->compare('start_from', $this->start_from, true);
        $criteria->compare('current_process_status', $this->current_process_status, true);
        $criteria->compare('lead_owner_id', $this->lead_owner_id);
        $criteria->compare('isActive', $this->isActive, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return MasterFile the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public static function getFiles($current_process_status = null, $notNeedlist = false) {
        $condition = 'isActive="Y"';
        if ($current_process_status != null) {
            if (is_array($current_process_status))
                $current_process_status = implode('","', $current_process_status);
            $condition.=' AND current_process_status in ("' . $current_process_status . '")';
        }
        $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC,current_process_status'));
        if ($notNeedlist)
            return $model;
        else
            return CHtml::listData($model, 'id', 'id_with_status');
    }

    public static function getApprovedFiles($current_process_status = null, $notNeedlist = false, $current_form_id, $flag) {

        if ($flag) { //isNewRecord
            $condition = '( current_form_id=' . $current_form_id . ' AND isActive="Y" ) AND (';
            if ($current_process_status != null) {
                if (is_array($current_process_status))
                    $current_process_status = implode('","', $current_process_status);
                $condition.='  current_process_status in ("' . $current_process_status . '")';
            }
            //$sql="SELECT MAX(crm_form_permission) FROM crm_form_permission WHERE form_id=".$current_form_id;
            //$maxvalue=Yii::app()->db->createCommand($sql)->queryScalar();  
            $maxLevel = Yii::app()->db->createCommand()
                    ->select('max(level)')
                    ->from('crm_form_permission')
                    ->where('form_id=' . $current_form_id)
                    ->queryScalar();
            $condition0 = 'form_id = ' . (int)$current_form_id . ' AND level=' . (int)$maxLevel . ' AND is_approved="Y"';
            $approved = FormApproval::model()->findAll(array('condition' => $condition0, 'select' => 'file_id'));
            //print_r($approved);die();

            if (!$approved) {
                return array();
            } else {
                foreach ($approved as $i => $eachApproved) {
                    $aprrovedFile[$i] = $eachApproved['file_id'];
                }
                $aprrovedFile = implode(',', array_unique($aprrovedFile));
                $condition.=" id in (" . $aprrovedFile . "))";

                $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC'));
                return CHtml::listData($model, 'id', 'id_with_status');
            }
        } else {
            $condition = '( isActive="Y" ) AND (';
            if ($current_process_status != null) {
                if (is_array($current_process_status))
                    $current_process_status = implode('","', $current_process_status);
                $condition.='  current_process_status in ("' . $current_process_status . '")';
            }
            $maxLevel = Yii::app()->db->createCommand()
                    ->select('max(level)')
                    ->from('crm_form_permission')
                    ->where('form_id=' . $current_form_id)
                    ->queryScalar();
            $condition1 = 'form_id = ' . $current_form_id . ' AND is_approved="Y"';
            if ((int) $maxLevel > 0)
                $condition1 .= ' AND level=' . $maxLevel;
            $approved = FormApproval::model()->findAll(array('condition' => $condition1, 'select' => 'file_id'));
            foreach ($approved as $i => $eachApproved) {
                $aprrovedFile[$i] = $eachApproved['file_id'];
            }
            $aprrovedFile = array_unique($aprrovedFile);
            foreach ($aprrovedFile as $eachAprrovedFile) {
                $condition.=" id=" . $eachAprrovedFile . " OR ";
            }
            $condition = chop($condition, " OR ");
            $condition.=' ) ';
            //print_r($condition);
            $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC'));
            return CHtml::listData($model, 'id', 'id_with_status');
        }
    }
    
    
    

     public static function getpreQuotationFiles($current_process_status = null, $notNeedlist = false, $current_form_id, $flag) {
            $condition = "current_form_id=".$current_form_id;
            $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC'));
            return CHtml::listData($model, 'id', 'id_with_status');
     }
    
    public static function getFilesForIncentiveCalc() {
        $criteria = new cdbCriteria;
        $current_process_status = implode('","', array("Q", "O", "D", "PD", "I", "PI", "CN"));
        $criteria->addCondition('is_approved="Y" AND current_process_status in ("' . $current_process_status . '")');
        if ((int) Yii::app()->user->havePermissionOn['other_reports_incentives_show_all'])
            $criteria->addCondition('t.lead_owner_id > 0', 'AND');
        else
            $criteria->addCondition('t.lead_owner_id = ' . Yii::app()->user->id, 'AND');
        $criteria->order = "t.id DESC";
        $model = self::model()->findAll($criteria);
        return CHtml::listData($model, 'id', 'id_with_status');
    }

    public function getId_with_status() {
        return $this->id . '-' . $this->company->company_name . ' / ' . $this->file_title . '(' . $this->status . ')';
    }

    public function getStatus() {
        switch ($this->current_process_status) {
            case 'L':
                return 'Pre-RFQ';
                break;
            case 'RFQ':
                return 'RFQ';
                break;
            case 'PQ':
                return 'Pre Quote';
                break;
            case 'Q':
                return 'Quote';
                break;
            case 'HOR':
                return 'HOR';
                break;
            case 'O':
            case 'P_O':
                return 'Order';
                break;
            case 'D':
                return 'Delivery';
                break;
            case 'PD':
                return 'Delivery(P)';
                break;
            case 'I':
            case 'P_I':
                return 'Invoice';
                break;
            case 'PI':
            case 'P_PI':
                return 'Invoice(P)';
                break;
            case 'P_R':
                return 'Requisition';
                break;
            case 'P_E':
                return 'Enquiry';
                break;
            case 'M_R':
                return 'Receipt';
                break;
            case 'P_MR':
                return 'Receipt(P)';
                break;
            case 'P_C':
                return 'DN';
                break;
            case 'C':
                return 'CN';
                break;
            case 'B_M':
                return 'Bill of Mtl';
                break;
            case 'PR_O':
                return 'Prod.Order';
                break;
            case 'G_I':
                return 'Goods Issue';
                break;
            case 'G_R':
                return 'Goods Receipt';
                break;
            case 'BOQ':
                return 'BOQ';
                break;
        }
    }

    public function priority($status) {
        switch ($status) {
            case 'L':
                return 1;
                break;
            case 'Q':
                return 2;
                break;
            case 'O':
                return 3;
                break;
            /* case 'PD':
              return 4;
              break; */
            case 'PD':
            case 'D':
            case 'PI':
            case 'I':
            case 'C': /* because there are siituation after partial invoicing then to invoice */
                return 4;
                break;
            /* case 'I':
              return 7;
              break;
              case 'C':
              return 8;
              break; */
            default:
                return 0;
                break;
        }
    }

    public function getGrand_total_bc() { //used for getting the grand total from quotation or order based on the status
        switch ($this->current_process_status) {
            case 'Q':
                return ($this->quote->grand_total + $this->quote->adTotal - $this->quote->dedTotal) * $this->quote->exchange_rate;
                break;
            case 'O':
                return ($this->order->grand_total + $this->order->adTotal - $this->order->dedTotal) * $this->order->exchange_rate;
                break;
        }
    }

    public function getGrand_total_own_currency() { //used for getting the grand total from quotation or order based on the status
        switch ($this->current_process_status) {
            case 'Q':
                return ($this->quote->grand_total + $this->quote->adTotal - $this->quote->dedTotal);
                break;
            case 'O':
                return ($this->order->grand_total + $this->order->adTotal - $this->order->dedTotal);
                break;
        }
    }

    public function reCalculateSellAndCostValues() {
        $modelProfitCalc = new ProfitCalc;
        $profitCal = $modelProfitCalc->profitCalculation($this->id);
        $modelProfit = ProfitCalc::model()->findByAttributes(array('file_id' => $this->id));
        if (count($modelProfit) == 0)
            $modelProfit = new ProfitCalc;
        $modelProfit->crm_user_id = Yii::app()->user->id;
        $modelProfit->file_id = $this->id;
        $modelProfit->netsellingvalue = $profitCal['netsellingvalue'];
        $modelProfit->netcostvalue = $profitCal['netcostvalue'];
        $modelProfit->save();
        $modelProfit->refresh();
        $default_internal_pricing_group = PricingGroup::getDefaultPricingGroup("I")->id;
        foreach ($profitCal['model']->items as $eachItem) {
            $profitCalcItem = new ProfitCalcItem;
            $cond = 'price_group_id=' . $default_internal_pricing_group .
                    ' AND pricing_product_class_id=' . (int) $eachItem->product->product_class_id .
                    ' AND store_id=' . $eachItem->product->id;
            $costrate = PriceGroupProductRelation::model()->find($cond)->rate;
            $profitCalcItem->profit_calc_id = $modelProfit->id;
            $profitCalcItem->product_id = $eachItem->product_id;
            $profitCalcItem->cost_rate = $costrate;
            $profitCalcItem->save(false);
        }
        return $modelProfit;
    }

    public function getNetSellValue() {
        if (count($this->profitCalc0) == 0 || count($this->profitCalc0->items) == 0) {
            $modelProfit = $this->reCalculateSellAndCostValues();
            return $modelProfit->netsellingvalue;
        } else {
            return $this->profitCalc0->netsellingvalue;
        }
    }

    public function getNetCostValue() {
        if (count($this->profitCalc0) == 0 || count($this->profitCalc0->items) == 0) {
            $modelProfit = $this->reCalculateSellAndCostValues();
            $netcostvalue = $modelProfit->netcostvalue;
        } else {
            $netcostvalue = $this->profitCalc0->netcostvalue;
        }
        if ($this->current_process_status == "I") {
            foreach ($this->invoices as $eachInvoice) {
                if ($eachInvoice->paid == "Y") {
                    foreach ($eachInvoice->processedInvoice as $eachProcessedInvoice) {

                        if ($eachProcessedInvoice->recpt->received_date == $eachInvoice->invoice_date) {
                            $netcostvalue-=($netcostvalue * $eachProcessedInvoice->received_amt / $this->netSellValue) * 0.01;
                        }
                    }
                } else {
                    $netcostvalue+=$netcostvalue * ((strtotime(date('Y-m-d')) - strtotime($eachProcessedInvoice->invoice_date)) % 30);
                }
            }
        }
        return $netcostvalue;
    }

    public function getProfit() {
        $profit = $this->netSellValue - $this->netCostValue;
        return $profit;
    }

    public function getMinProfit() {

        if ($this->netCostValue <= 100000)
            $min_sales_profit_percentage = 0.15;
        else if ($this->netCostValue > 100000 && $this->netCostValue <= 300000)
            $min_sales_profit_percentage = 0.13;
        else // > 100000
            $min_sales_profit_percentage = 0.10;
        return $min_sales_profit_percentage;
    }

    public function getProfitExp() {

        $min_sales_profit = $this->netCostValue * $this->minProfit;
        return $min_sales_profit;
    }

    public function getAmountForIncentiveCalc() {
        $balance_to_calculate_sales_incentive = $this->profit - $this->profitExp;
        return $balance_to_calculate_sales_incentive;
    }

    public function getIncentive() {
        $incentiveAmnt = $this->amountForIncentiveCalc * 0.15;
        return $incentiveAmnt;
    }

    public function getPermission() {
        $form_id = 1;
        $critera = new cdbCriteria;
        $critera->select = 'name,level';
        $critera->order = 'level ASC';
        $critera->condition = 'form_id=' . $form_id;
        $model = FormPermission::model()->findAll($critera);
        if ($model != null) {
            $html = '';
            foreach ($model as $eachModel)
                $html.='<li onclick=\'js:confirm("This will generate a mail to the authorities that are in ' . $eachModel->name . ' approval,are you sure to send?")\' style="width:auto;"><a href="#' . $eachModel->level . '"><i class="icon-ok"></i> Send for ' . $eachModel->name . ' approval </a></li>';
            //$data[$eachModel->level] = "Send to " . $eachModel->level . "th level approval";
            //return CHtml::dropDownList("something", "", $data, array('prompt' => '-Approvals-','onchange'=>'js:confirm("This will generate a mail to the authorities that are on "+this.value+"th level approval,are you sure to send?")'));
            $html = '<ul>
                <li  style="width:auto;"><a href="#pact" data-toggle="dropdown" class="dropdown-toggle"><i class="icon-bullhorn"></i></a>                                
                    <ul class="dropdown-menu" style="width:auto;">  
                        ' . $html . '
                    </ul>
                </li>
              </ul>';
            return $html;
        }
        else
            return "-";
    }

    public function permission($form_id) {
        $form_id = $form_id;
        $critera = new cdbCriteria;
        $critera->select = 'name,level';
        $critera->order = 'level ASC';
        $critera->condition = 'form_id=' . $form_id;
        $model = FormPermission::model()->findAll($critera);
        if ($model != null) {
            $html = '';
            foreach ($model as $eachModel)
                $html.='<li onclick=\'js:confirm("This will generate a mail to the authorities that are in ' . $eachModel->name . ' approval,are you sure to send?")\' style="width:auto;"><a href="#' . $eachModel->level . '"><i class="icon-ok"></i> Send for ' . $eachModel->name . ' approval </a></li>';
            //$data[$eachModel->level] = "Send to " . $eachModel->level . "th level approval";
            //return CHtml::dropDownList("something", "", $data, array('prompt' => '-Approvals-','onchange'=>'js:confirm("This will generate a mail to the authorities that are on "+this.value+"th level approval,are you sure to send?")'));
            $html = '<ul>
                <li  style="width:auto;"><a href="#pact" data-toggle="dropdown" class="dropdown-toggle"><i class="icon-bullhorn"></i></a>                                
                    <ul class="dropdown-menu" style="width:auto;">  
                        ' . $html . '
                    </ul>
                </li>
              </ul>';
            return $html;
        }
        else
            return "-";
    }

    public function getcheckVisible($data) {
        if ($this->file->lead_owner_id == Yii::app()->user->id)
            return 1;
        else
            return 0;
    }

    public function getFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->id, 'order' => 'id asc'));
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_of_approval).(($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);;
                
           // $html[].= (($eachHistory->notes != "") ? ("(".$eachHistory->notes.")") : $eachHistory->notes);
                
            }
        return implode('<br/>', $html);
    }
    
    public function getHorFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->id, 'order' => 'id asc'));
        $maxLevel = Yii::app()->db->createCommand()
                    ->select('max(level)')
                    ->from('crm_form_permission')
                    ->where('form_id= 11')
                    ->queryScalar();
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_of_approval).
                                 (($eachHistory->notes != "" && $eachHistory->level==$maxLevel) ? ("(".$eachHistory->notes.")".'<br/><strong>'."(Approved by General Manager)".'</strong>') : "(".$eachHistory->notes.")");
           
            }
        return implode('<br/>', $html);
    }

    public function getColor($form_id, $file_id) {
        $notified_userids = array(); 
        $modelApproval = FormApproval::model()->find(array('condition' => 'form_id=' . (int) $form_id . ' AND file_id=' . (int) $file_id . ' AND arrived_req_for_approval<>"N"', 'order' => 'level DESC,id DESC'));
       //$Notification = FormApproval::model()->findAll(array('condition' => 'form_id=' . (int) $form_id . ' AND file_id=' . (int) $file_id . ' AND arrived_req_for_approval = "N"'));
       $Notification = Notification::model()->findAll(array('condition' => 'form_id=' . (int) $form_id . ' AND file_id=' . (int) $file_id . ' AND arrived_req_for_notification = "N"'));
        if( is_array($Notification)){
        foreach ($Notification as $eachNotification) {
            $userid = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachNotification->level))->user_ids);
            if( is_array($userid)){
            $notified_userids = array_merge($notified_userids, $userid);
            }}}
        if ($modelApproval) {
            if ($modelApproval->is_approved == "N")
                $color = "colorGrey";
            else {
                $color = in_array(Yii::app()->user->id, $notified_userids) ? "colorBlue" : "colorGreen";
                $usersInLevel = FormPermission::model()->find(array('condition' => 'form_id=' . (int) $this->form_id . ' AND level=' . (int) $modelApproval->level))->usersInLevel;
                $usersInLevel = is_array($usersInLevel) ? $usersInLevel : array(0);
                if ($modelApproval->is_approved == "N")
                    $color = "colorGrey";
                else {
                    if ($this->file->lead_owner_id == Yii::app()->user->id) {
                        $color = $modelApproval->arrived_req_for_approval == "Y" ? $color : "colorRed";
                    } else if (in_array(Yii::app()->user->id, $usersInLevel)) {
                        $color = $modelApproval->arrived_req_for_approval == "A" ? $color : "colorRed";
                    } else {
                        $color = (FormApproval::model()->count(array('condition' => 'form_id=' . (int) $form_id . ' AND file_id=' . (int) $file_id . ' AND arrived_req_for_approval<>"N" AND approved_or_unapproved_by in(' . implode(',', $usersInLevel) . ')'))) > 0 ? "colorGreen" : "-noColor-";
                       
                    }
                }
            }
        } else if ($this->file->lead_owner_id == Yii::app()->user->id) {
            $color = "colorRed";
        }
        else
            $color = "-noColor-";
        
        return $color;
    }
     public static function getOrdereddFiles( $current_form_id= array(),$current_process_status=array(), $flag) {
//print_r($current_form_id);die();
        if ($flag) { //isNewRecord
            $condition = '( current_form_id in ("' . implode('","', $current_form_id) . '")  AND isActive="Y" ) AND (';
            if ($current_process_status != null) {
                if (is_array($current_process_status))
                    $current_process_status = implode('","', $current_process_status);
                $condition.='  current_process_status in ("' . $current_process_status . '") AND';
            }
            //$sql="SELECT MAX(crm_form_permission) FROM crm_form_permission WHERE form_id=".$current_form_id;
            //$maxvalue=Yii::app()->db->createCommand($sql)->queryScalar();  
            $maxLevel = Yii::app()->db->createCommand()
                    ->select('max(level)')
                    ->from('crm_form_permission')
                    ->where('form_id= 11')
                    ->queryScalar();
            $condition0 = 'form_id = 11 AND level=' . $maxLevel . ' AND is_approved="Y"';
            $approved = FormApproval::model()->findAll(array('condition' => $condition0, 'select' => 'file_id'));
            //print_r($approved);die();

            if (!$approved) {
                return array();
            } else {
                foreach ($approved as $i => $eachApproved) {
                    $aprrovedFile[$i] = $eachApproved['file_id'];
                }
                $aprrovedFile = implode(',', array_unique($aprrovedFile));
                $condition.=" id in (" . $aprrovedFile . "))";

                $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC'));
                return CHtml::listData($model, 'id', 'id_with_status');
            }
        } else {
            $condition = '( isActive="Y" ) AND (';
            if ($current_process_status != null) {
                if (is_array($current_process_status))
                    $current_process_status = implode('","', $current_process_status);
                $condition.='  current_process_status in ("' . $current_process_status . '")';
            }
            $maxLevel = Yii::app()->db->createCommand()
                    ->select('max(level)')
                    ->from('crm_form_permission')
                    ->where('form_id=' . $current_form_id)
                    ->queryScalar();
            $condition1 = 'form_id = ' . $current_form_id . ' AND is_approved="Y"';
            if ((int) $maxLevel > 0)
                $condition1 .= ' AND level=' . $maxLevel;
            $approved = FormApproval::model()->findAll(array('condition' => $condition1, 'select' => 'file_id'));
            foreach ($approved as $i => $eachApproved) {
                $aprrovedFile[$i] = $eachApproved['file_id'];
            }
            $aprrovedFile = array_unique($aprrovedFile);
            foreach ($aprrovedFile as $eachAprrovedFile) {
                $condition.=" id=" . $eachAprrovedFile . " OR ";
            }
            $condition = chop($condition, " OR ");
            $condition.=' ) ';
            //print_r($condition);
            $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC'));
            return CHtml::listData($model, 'id', 'id_with_status');
        }
    }
    
     public static function getInvoicedFiles($current_form_id= array(),$current_process_status=array(), $flag) {

        if ($flag) { //isNewRecord
            $condition = '( current_form_id in ("' . implode('","', $current_form_id) . '")  AND isActive="Y" ) AND (';
           // $condition = '( current_form_id=' . $current_form_id . ' AND current_process_status="I"  AND isActive="Y" )' ;
            if ($current_process_status != null) {
                if (is_array($current_process_status))
                    $current_process_status = implode('","', $current_process_status);
                $condition.='  current_process_status in ("' . $current_process_status . '"))';
            }
                $model = self::model()->findAll(array('condition' => $condition, 'order' => 'id DESC '));
                return CHtml::listData($model, 'id', 'id_with_status');
        } 
    }

}
