<?php

/**
 * This is the model class for table "{{notification}}".
 *
 * The followings are the available columns in table '{{notification}}':
 * @property integer $id
 * @property integer $form_id
 * @property integer $file_id
 * @property integer $level
 * @property string $arrived_req_for_notification
 * @property integer $notification_by
 * @property string $date_send_for_notification
 */
class Notification extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{notification}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('form_id, file_id, level, arrived_req_for_notification, notification_by, date_send_for_notification', 'required'),
            array('form_id, file_id, level, notification_by', 'numerical', 'integerOnly' => true),
            array('arrived_req_for_notification', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, form_id, file_id, level, arrived_req_for_notification, notification_by, date_send_for_notification', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'formPermission' => array(self::BELONGS_TO, 'FormPermission', array('level', 'form_id')),
            'form' => array(self::BELONGS_TO, 'Form', array('level', 'form_id')),
            'user' => array(self::BELONGS_TO, 'User', 'notification_by'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'form_id' => 'Form',
            'file_id' => 'File',
            'level' => 'Level',
            'arrived_req_for_notification' => 'Arrived Req For Notification',
            'notification_by' => 'Notification By',
            'date_send_for_notification' => 'Date Send For Notification',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('form_id', $this->form_id);
        $criteria->compare('file_id', $this->file_id);
        $criteria->compare('level', $this->level);
        $criteria->compare('arrived_req_for_notification', $this->arrived_req_for_notification, true);
        $criteria->compare('notification_by', $this->notification_by);
        $criteria->compare('date_send_for_notification', $this->date_send_for_notification, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Notification the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getStatus() {

        $status = "Notified";

        return $status;
        //($data->arrived_req_for_approval!="Y")?($data->is_approved=="Y"?"Approved":"Rejecetd"):(($data->arrived_req_for_approval=="N")?"Notification sent":"Approval requested")',
    }

    public function getLevelAndname() {

        return PactDepartment::model()->findByPK($this->level)->department_name;
    }

}
