<?php

/**
 * This is the model class for table "{{product_location}}".
 *
 * The followings are the available columns in table '{{product_location}}':
 * @property integer $stock_id
 * @property integer $bin
 * @property integer $rack
 * @property integer $weight
 * @property integer $warehouse_id
 * @property integer $quantity
 *
 * The followings are the available model relations:
 * @property MasInvWarehouse $warehouse
 * @property Store $stock
 * @property MasInvBin $bin0
 * @property MasInvRack $rack0
 */
class ProductLocation extends CActiveRecord {

    public $total_value;
    public $sum_of_quantity;
    public $warehouse_name;
    public $rack_name;
    public $bin_name;
    public $sum;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{product_location}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('warehouse_id, quantity', 'required'),
            array('stock_id,sum,bin, rack, company_branch_id, warehouse_id, quantity', 'numerical', 'integerOnly' => true),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('stock_id,sum,bin, rack, warehouse_id, quantity', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'warehouse' => array(self::BELONGS_TO, 'MasInvWarehouse', 'warehouse_id'),
            'stock' => array(self::BELONGS_TO, 'Store', 'stock_id'),
            'bin0' => array(self::BELONGS_TO, 'MasInvBin', 'bin'),
            'rack0' => array(self::BELONGS_TO, 'MasInvRack', 'rack'),
            'inventory' => array(self::BELONGS_TO, 'InventoryItems', 'stock_id'),
            'orderItems' => array(self::HAS_MANY, 'OrderItem', 'product_id'),
            'PurchaseorderItems' => array(self::HAS_MANY, 'PurchasingOrderItem', 'product_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'stock_id' => 'Stock',
            'bin' => 'Bin',
            'rack' => 'Rack',
            'warehouse_id' => 'Warehouse',
            'quantity' => 'Quantity',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function minreport() {
        $criteria = new CDbCriteria;
        $criteria->with = array('stock', 'inventory');
        $criteria->group = 't.stock_id';
        $criteria->having = 'SUM(quantity)<inventory.re_order_level';
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.warehouse_id,t.bin,t.rack',
            ),
            'pagination' => false
        ));
    }

    /* public function minreport() {
      $criteria = new CDbCriteria;
      $criteria->with = array('stock','inventory','orderItems','PurchaseorderItems','orderItems.order','PurchaseorderItems.purchaseorder','orderItems.order.file','PurchaseorderItems.purchaseorder.file');
      $criteria->group='t.stock_id';
      $criteria->condition='purchaseorder.file.current_process_status="P_O" AND order.file.current_process_status="O"';
      $criteria->having='SUM(t.quantity)-SUM(orderItems.quantity)+SUM(PurchaseorderItems.quantity)<inventory.re_order_level';
      return new CActiveDataProvider($this, array(
      'criteria' => $criteria,
      'sort' => array(
      'defaultOrder' => 't.warehouse_id,t.bin,t.rack',
      ),
      'pagination' => false
      ));
      } */

    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('stock_id', Yii::app()->session['stock_id']);
        $criteria->compare('bin', $this->bin);
        $criteria->compare('rack', $this->rack);
        $criteria->compare('warehouse_id', $this->warehouse_id);
        $criteria->compare('quantity', $this->quantity);
        //$criteria->compare('company_id', Yii::app()->user->master_user_company_id , true);
        $criteria->compare('company_branch_id', Yii::app()->user->master_user_branch_id);
        if (isset($_POST['stock_id']))
            $criteria->condition = "stock_id=" . $_POST['stock_id'][0];
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.warehouse_id,t.bin,t.rack',
            ),
            'pagination' => array('pageSize' => 5)
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return ProductLocation the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function renderQuantity($data, $row) {
        $connection = Yii::app()->db;
        $command = $connection->createCommand("SELECT SUM(quantity) FROM 
            {{product_location}} 
            where stock_id=" . $data->stock_id . " AND warehouse_id=" . $data->warehouse_id);
        if ($command->queryScalar() > 0)
            return $command->queryScalar();
        else
            return 0;
    }

    public function getTotals($ids) {
        //$ids = implode(",", $ids);
        $connection = Yii::app()->db;
        if (!empty($ids)) {
            $total = 0;
            foreach ($ids as $id) {
                $product = Store::model()->findByPk($id);
                $total+=$product->rate * $product->total_quantity;
            }
            return $total;
        }
        else
            return "";
    }

    

}
