<?php

/**
 * This is the model class for table "{{profit_calc}}".
 *
 * The followings are the available columns in table '{{profit_calc}}':
 * @property integer $id
 * @property integer $crm_user_id
 * @property integer $file_id
 * @property string $netsellingvalue
 * @property string $netcostvalue
 */
class ProfitCalc extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{profit_calc}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('crm_user_id, file_id, netsellingvalue, netcostvalue', 'required'),
            array('crm_user_id, file_id', 'numerical', 'integerOnly' => true),
            array('netsellingvalue, netcostvalue', 'length', 'max' => 15),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, crm_user_id, file_id, netsellingvalue, netcostvalue', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'items' => array(self::HAS_MANY, 'ProfitCalcItem', 'profit_calc_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'crm_user_id' => 'Crm User',
            'file_id' => 'File',
            'netsellingvalue' => 'Netsellingvalue',
            'netcostvalue' => 'Netcostvalue',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('crm_user_id', $this->crm_user_id);
        $criteria->compare('file_id', $this->file_id);
        $criteria->compare('netsellingvalue', $this->netsellingvalue, true);
        $criteria->compare('netcostvalue', $this->netcostvalue, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return ProfitCalc the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function profitCalculation($file_id) {
        $modelFile = MasterFile::model()->with('quote.items', 'order.items1')->findByPK($file_id, array('order' => 'items.id ASC,items1.id ASC'));
        $modelProfit = ProfitCalc::model()->with('items')->find(array('condition' => 'file_id=' . $file_id, 'order' => 'items.id ASC'));

        $jsondata['file'] = $modelFile;
        if ($modelFile->is_approved == "Y") {
            $jsondata['approved_by'] = $modelFile->approvedBy->fullname;
        }

        switch ($modelFile->current_process_status) {
            case 'Q':
                $model = $modelFile->quote;
                break;
            default:
                $model = $modelFile->order;
                break;
        }
        $jsondata['model'] = $model;
        $jsondata['company'] = $model->company;
        $jsondata['leadowner'] = $model->file->leadowner->fullname;
        $jsondata['currency'] = $model->currency0->currency;
        $jsondata['contact'] = $model->contact;
        $default_internal_pricing_group = PricingGroup::getDefaultPricingGroup("I");
        $jsondata['items'] = '<tr>
            <th>No</th>
            <th>Product</th>
            <th>Description</th>
            <th>Qty.</th>
            <th>Unit</th>
            <th>Selling Price/Ut.</th>
            <th>' . ((int) Yii::app()->user->havePermissionOn['sop_profit_calc_change_pricing_group'] ? CHtml::dropDownList('price-group', '', PricingGroup::getPricingGroup("I"), array(
                            'title' => 'Choose cost price',
                            'style' => 'width:100% !important',
                            'options' => array('selected' => $default_internal_pricing_group->id),
                            'onchange' => 'reCalculateProfit(this.value);'
                        )) : $default_internal_pricing_group->pricing_group) . '</th>
            <th>Add.</th>
            <th>Ded.</th>
            <th>Sell. Val.</th>
            <th>Cost Val.</th>
        </tr>';
        $totalCostvalue = 0;
        foreach ($model->items as $i => $eachItem) {

            $eachItem->rate*=$eachItem->parent->exchange_rate;
            //$eachItem->rate = number_format(round($eachItem->rate, 2), 2, '.', '');

            $jsondata['items'].='<tr>';
            $jsondata['items'].='<td>' . ($i + 1) . '</td>';
            $jsondata['items'].='<td class="cell-left">'
                    . CHtml::hiddenField('product_id_' . $eachItem->product->id, $eachItem->product->id, array('class' => 'product_hidden_ids'))
                    . $eachItem->product->part_number . '</td>';
            $jsondata['items'].='<td  class="cell-left" >' . substr($eachItem->description, 0, 30) . ".." . '</td>';
            $jsondata['items'].='<td class="cell-right">'
                    . CHtml::hiddenField('quantity_' . $eachItem->product->id, $eachItem->quantity)
                    . $eachItem->quantity . '</td>';
            $jsondata['items'].='<td>' . $eachItem->product->unit->symbol . '</td>';
            $jsondata['items'].='<td  class="cell-right" >'
                    . CHtml::hiddenField('sell_price_' . $eachItem->product->id, $eachItem->rate)
                    . number_format(round($eachItem->rate, 2), 2, '.', '') . '</td>';

            $costrate = ProfitCalcItem::model()->with('profitCalc')->find(array('condition' => 'file_id=' . $file_id . ' AND product_id=' . $eachItem->id))->cost_rate;
            if ($modelFile->is_approved != "Y" || $costrate == 0) {
                $cond = 'price_group_id=' . (int) $default_internal_pricing_group->id .
                        ' AND pricing_product_class_id=' . (int) $eachItem->product->product_class_id .
                        ' AND store_id=' . $eachItem->product->id;
                $costrate = PriceGroupProductRelation::model()->find($cond)->rate;
            }

            $jsondata['items'].='<td  class="cell-right" >'
                    . CHtml::hiddenField('cost_price_' . $eachItem->product->id, $costrate)
                    . '<span>' . $costrate . '</span></td>';
            $jsondata['items'].='<td  class="cell-right" >'
                    . CHtml::hiddenField('addition_' . $eachItem->product->id, $eachItem->addition_amount)
                    . $eachItem->addition_amount . '</td>';
            $jsondata['items'].='<td  class="cell-right" >'
                    . CHtml::hiddenField('deduction_' . $eachItem->product->id, $eachItem->deduction_amount)
                    . $eachItem->deduction_amount . '</td>';
            $jsondata['items'].='<td class="cell-right net-amount">'
                    . Yii::app()->numberFormatter->formatCurrency($eachItem->net_amount, "") . '</td>';

            $costvalue = $costrate * $eachItem->quantity;
            $jsondata['items'].='<td class="cell-right cost-amount">'
                    . Yii::app()->numberFormatter->formatCurrency($costvalue, "") . '</td>';
            $totalCostvalue+=$costvalue;
        }
        $netsellingvalue = $model->netAmount * $model->exchange_rate;
        $netcostvalue = $totalCostvalue;
        $jsondata['items'].='<tr><td class="cell-center" colspan="5"><strong> Profit calculations </strong><br/>';
        if ($modelFile->is_approved == "Y")
            $jsondata['items'].='<strong style="color:green; font:bold;">    Approved By: ' . $jsondata['approved_by'] . '</strong>'; //.' On '.$modelFile->date_of_approval
        else
            $jsondata['items'].='<strong style="color:blue; font:bold;">File is waiting for approval</strong>';
        $jsondata['items'].='<br/><span class="below-min-profit-warning" style="color:red; display:none;"> Profit fallen below Minimum profit!</span>';
        $jsondata['items'].='</td>';
        $jsondata['items'].='<td class="cell-right" colspan="6">';

        $jsondata['items'] .= '<table id="profit_calc_footer" style="width:100%"><tr>
    <th>&nbsp;</td>
    <th>Sell amount: <strong class="total-sell-amount">'
                . CHtml::hiddenField('net_sell_amount_' . $model->id, $netsellingvalue)
                . Yii::app()->numberFormatter->formatCurrency($netsellingvalue, "") . '</strong></td>
    <th>Cost amount: <strong class="total-cost-amount">' . Yii::app()->numberFormatter->formatCurrency($totalCostvalue, "") . '</strong></td>
      <th>' . CHtml::link('<i class="icon-plus-sign"></i>', 'javascript:void(0);', array(
                    'onclick' => 'addNewFooter(this);',
                    'title' => 'Add new footer item'
                )) . '</th>  
  </tr>';


        if ($modelFile->is_approved == "Y" && count($modelProfit) > 0) {
            $extras = ProfitCalcExtra::model()->findAll(array('condition' => 'profit_calc_id=' . $modelProfit->id, 'order' => 'id asc'));
            foreach ($extras as $i => $eachDedItem) {
                $jsondata['items'].='<tr>
            <td>' . CHtml::textField("extra[]", $eachDedItem->particular, array(
                            'placeholder' => 'Deduction particular',
                            'class' => 'paricular')) . '</td>
            <td>' . CHtml::textField("extra_addition[]", $eachDedItem->addition, array(
                            'readonly' => false,
                            'class' => "additions paricular",
                            'onkeyup' => 'calcProfit();'
                        )) . '</td>
            <td>' . CHtml::textField("extra_deduction[]", $eachDedItem->deduction, array(
                            'readonly' => false,
                            'class' => "deductions paricular",
                            'onkeyup' => 'calcProfit();'
                        )) . '
            </td><td>' . CHtml::link('<i class="icon-remove"></i>', 'javascript:void(0);', array(
                            'onclick' => 'removeProfitFooterRow(this);')) . '</td>
            </tr>';
                if (floatval($eachDedItem->addition) > 0)
                    $netsellingvalue += floatval($eachDedItem->addition);
                if (floatval($eachDedItem->deduction) > 0)
                    $netsellingvalue -= floatval($eachDedItem->deduction);
            }
        } else {
            foreach ($model->adItems as $eachAddItem) {
                if ($eachAddItem->calculated_value > 0) {
                    $eachDedItem->calculated_value = $eachAddItem->calculated_value * $model->exchange_rate;
                    $jsondata['items'].='<tr>
          <td>' . CHtml::textField("extra[]", $eachAddItem->particular, array(
                                'class' => 'paricular',
                                'placeholder' => 'Addition particular')) . '</td>
          <td>' . CHtml::textField("extra_addition[]", $eachAddItem->calculated_value, array(
                                'readonly' => false,
                                'class' => "additions paricular",
                                'onkeyup' => 'calcProfit();'
                            )) . '</td>
          <td>' . CHtml::textField("extra_deduction[]", 0, array(
                                'readonly' => false,
                                'class' => "deductions paricular",
                                'onkeyup' => 'calcProfit();'
                            )) . '
          </td>
          <td>' . CHtml::link('<i class="icon-remove"></i>', 'javascript:void(0);', array(
                                'onclick' => 'removeProfitFooterRow(this);')) . '</td>
          </tr>';
                    $netsellingvalue+=($eachAddItem->calculated_value );
                }
            }

            foreach ($model->dedItems as $eachDedItem) {
                if ($eachDedItem->calculated_value > 0) {
                    $eachDedItem->calculated_value = $eachDedItem->calculated_value * $model->exchange_rate;
                    $jsondata['items'].='<tr>
          <td>' . CHtml::textField("extra[]", $eachDedItem->particular, array(
                                'placeholder' => 'Deduction particular',
                                'class' => 'paricular')) . '</td>
          <td>' . CHtml::textField("extra_addition[]", 0, array(
                                'readonly' => false,
                                'class' => "additions paricular",
                                'onkeyup' => 'calcProfit();'
                            )) . '</td>
          <td>' . CHtml::textField("extra_deduction[]", $eachDedItem->calculated_value, array(
                                'readonly' => false,
                                'class' => "deductions paricular",
                                'onkeyup' => 'calcProfit();'
                            )) . '
          </td><td>' . CHtml::link('<i class="icon-remove"></i>', 'javascript:void(0);', array(
                                'onclick' => 'removeProfitFooterRow(this);')) . '</td>
          </tr>';
                    $netsellingvalue-=($eachDedItem->calculated_value );
                }
            }
        }
        $jsondata['items'].='
            <tr class="repeating_row" style="display:none;">
            <td>' . CHtml::textField("extra[]", '', array(
                    'readonly' => false,
                    'placeholder' => 'Additional particlars',
                    'class' => 'paricular'
                )) . '</td>
            <td>' . CHtml::textField("extra_addition[]", '', array(
                    'readonly' => false,
                    'class' => "additions paricular",
                    'placeholder' => 'Additions to sell amount',
                    'onkeyup' => 'calcProfit();'
                )) . '</td>
            <td>' . CHtml::textField("extra_deduction[]", '', array(
                    'readonly' => false,
                    'class' => "deductions paricular",
                    'placeholder' => 'Deductions to sell amount or additions to cost amount',
                    'onkeyup' => 'calcProfit();'
                )) . '</td>
            <td>' . CHtml::link('<i class="icon-remove"></i>', 'javascript:void(0);', array(
                    'onclick' => 'removeProfitFooterRow(this);')) . '</td>
            </tr>';
        $jsondata['items'].='
            <tr class="net">
            <td>Net </td>
            <td><strong class="netsellingvalue">' . CHtml::textField('netsellingvalue', $netsellingvalue, array('readonly' => true, 'style' => "width:95%; text-align:right;")) . '</span></td>
            <td colspan="2"><strong class="netcostvalue">' . CHtml::textField('netcostvalue', $netcostvalue, array('readonly' => true, 'style' => "width:95%; text-align:right;")) . '</span></td>
            </tr>';
        $jsondata['netsellingvalue'] = $netsellingvalue;
        $jsondata['netcostvalue'] = $netcostvalue;
        $profit = $netsellingvalue - $netcostvalue;
        $profit_in_percentage = ($netcostvalue > 0) ? round(($profit / $netcostvalue) * 100, 2) : 100;
        $min_sales_profit = 0;
        if ($netcostvalue <= 50000)
            $min_sales_profit = 0.15;
        else if ($netcostvalue > 50000 && $netcostvalue <= 100000)
            $min_sales_profit = 0.13;
        else if ($netcostvalue > 100000)
            $min_sales_profit = 0.10;
        //$min_sales_profit_amnt = $profit - ($profit * $min_sales_profit);
        //$jsondata['items'].='<tr><td colspan="4"></td></tr>';
        $jsondata['items'].='<tr>
    <td>Sales Profit</td>
    <td><span ><strong class="profit_percentage">' . CHtml::textField('profit_percentage', $profit_in_percentage . '%', array('readonly' => true, 'style' => "width:95%; text-align:right;")) . '</strong></span></td>
    <td colspan="2"><span><strong class="profit">' . CHtml::textField('profit', $profit, array('readonly' => true, 'style' => "width:95%; text-align:right;")) . '</strong></span></td>
  </tr>';
        /* $jsondata['items'].='<tr>
          <td>Incentive Amount1</td>
          <td colspan="3"><strong class="incentive-amount">' . Yii::app()->numberFormatter->formatDecimal($min_sales_profit_amnt) . '</strong></td>
          </tr>'; */
        $jsondata['profit_in_percentage'] = $profit_in_percentage;
        $jsondata['items'].='</table></td></tr>';
        return $jsondata;
    }

}
