<?php

/**
 * This is the model class for table "{{purchasing_invoice}}".
 *
 * The followings are the available columns in table '{{purchasing_invoice}}':
 * @property integer $id
 * @property integer $file_id
 * @property integer $po_id
 * @property integer $vend_id
 * @property string $vend_name
 * @property string $dly_no
 * @property string $dly_date
 * @property string $shipped_by
 * @property string $awb_no
 * @property integer $mrv_no
 * @property integer $tracking_no
 * @property string $others
 * @property string $storekeeper_notes
 * @property string $qc_check
 * @property integer $qc_notes
 * @property integer $qc_check_date
 * @property integer $mtl_receipt_date
 * @property integer $invoice_date
 */
class PurchasingInvoice extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public $title;
    public $received_amt;
    public $qc_checked_employee_name;
    public $currency_name;
    public $invoice_table_id;
    public $value;
    public $country;
    public $searchstartdate;
    public $searchenddate;
    public $project;


    public function tableName() {
        return '{{purchasinginvoice}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('vendor_id, invoice_number, invoice_date,payment_terms', 'required'),
            array('file_id, po_id,crm_user_id, vendor_id, tracking_no, qc_checked_employee,currency', 'numerical', 'integerOnly' => true),
            array('vendor_name, dly_no, shipped_by, awb_no, others ,materialreceived, qc_checked_employee_name, invoice_number, qc_check_notes,payment_terms', 'length', 'max' => 255),
            array('qc_check,paid', 'length', 'max' => 1),
            array('exchange_rate,grand_total', 'numerical'),
            array('notes,terms_and_conditions,remarks', 'length', 'max' => 5000),
             array(
                  'invoice_date',
                  'compare',
                  'compareAttribute'=>'dly_date',
                  'operator'=>'>=', 
                  'allowEmpty'=>false , 
                  'message'=>'{attribute} must be greater than "{compareValue}".'
                ),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, file_id, po_id, vendor_id,grand_total,vendor_name, dly_no, dly_date, shipped_by, awb_no, mrv_no, tracking_no, others, storekeeper_notes, qc_check, qc_notes, qc_check_date, mtl_receipt_date, invoice_date', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'vendor' => array(self::BELONGS_TO, 'Company', 'vendor_id'),
            'purchaseorder' => array(self::BELONGS_TO, 'PurchasingOrder', 'po_id'),
            'items' => array(self::HAS_MANY, 'PurchasingInvoiceItem', 'purchasing_invoice_id'),
            'adItems' => array(self::HAS_MANY, 'PurchasingInvoiceAddition', 'purchasing_invoice_id'),
            'dedItems' => array(self::HAS_MANY, 'PurchasingInvoiceDeduction', 'purchasing_invoice_id'),
            'netAmount' => array(self::STAT, 'PurchasingInvoiceItem', 'purchasing_invoice_id', 'select' => 'SUM(net_amount)'),
            'netQuantity' => array(self::STAT, 'PurchasingInvoiceItem', 'purchasing_invoice_id', 'select' => 'SUM(quantity)'),
            'currencyname' => array(self::BELONGS_TO, 'MasCurrency', 'currency'),
            'shippedby' => array(self::BELONGS_TO, 'MasShipping', 'shipped_by'),
            'paymentTerm' => array(self::BELONGS_TO, 'MasPaymentTerm', 'payment_terms'),
            'receivedAmount' => array(self::STAT, 'PaidInvoices', 'invoice_id', 'select' => 'SUM(received_amt)'),
            'paidInvoice' => array(self::HAS_MANY, 'PaidInvoices', 'invoice_id'),
            'returned' => array(self::HAS_ONE, 'Purchasingcredit', 'purchasing_invoice_id'),
            'returnedAmount' => array(self::STAT, 'Purchasingcredit', 'purchasing_invoice_id', 'select' => 'SUM(credited_amount)'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'file_id' => 'File',
            'po_id' => 'Po',
            'vendor_id' => 'Vendor',
            'vendor_name' => 'Vendor Name',
            'dly_no' => 'Dly No',
            'dly_date' => 'Dly Date',
            'shipped_by' => 'Shipped By',
            'awb_no' => 'AWB No',
            'tracking_no' => 'Tracking No',
            'others' => 'Others',
            'storekeeper_notes' => 'Storekeeper Notes',
            'qc_check' => 'QC',
            'qc_notes' => 'QC Notes',
            'qc_check_date' => 'QC Date',
            'mtl_receipt_date' => 'Mtl Receipt Date',
            'invoice_date' => 'Invoice Date',
            'qc_checked_employee'=>'QC By'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
     public function report() {
        $criteria = new CDbCriteria;
        $criteria->with = array('file','vendor','purchaseorder');
        if (!empty($this->vendor_id))
            $condition[] = 't.vendor_id="' . $this->vendor_id . '"';
        if (!empty($this->project))
            $condition[] = 'purchaseorder.project="' . $this->project . '"';
        if (!empty($this->country))
            $condition[] = 'vendor.billing_country="' . $this->country . '"';
        if (!empty($this->value))
            $condition[] = 't.grand_total<="' . $this->value . '"';
        if (is_array($condition))
            $criteria->condition = implode(' AND ', $condition);
        if (!empty($this->searchstartdate) && !empty($this->searchenddate)) {
            $criteria->addBetweenCondition('invoice_date', $this->searchstartdate, $this->searchenddate);
        }
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.invoice_date DESC,t.id DESC,t.file_id DESC,t.vendor_id DESC',
            ),
            'pagination' => false
        ));
    }
    public function search($searchterm = null) {
        $criteria = new CDbCriteria;
        $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('purchase_inv_search')) : $searchterm;
        $criteria->with = array('file', 'file.company');
        $criteria->addCondition('       file.own_company_id=' . Yii::app()->user->master_user_company_id . ' AND 
                                        file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
        //((int) Yii::app()->session['company_id'] > 0 && !isset($_GET['month'])) ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.po_id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%"', 'AND');
        }
        if (isset($_GET['month']))
            $criteria->addCondition("YEAR(invoice_date)='" . date('Y') . "' AND MONTH(invoice_date) ='" . $_GET['month'] . "'", 'AND');
       /* else
            $criteria->addCondition('file.current_process_status="P_I" OR file.current_process_status="P_PI"', 'AND');*/

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC, t.file_id DESC ,t.invoice_date DESC',
            ),
           'pagination' => (Yii::app()->controller->id != "export") ? array('pageSize' => 15) : false,
       ));
    }
    
    public function seacrhInvoice() {
        $criteria = new CDbCriteria;
        $criteria->with = "file";
        $comp_id = isset($_GET['comp_id']) ? $_GET['comp_id'] : ((int) Yii::app()->session['company_id'] > 0 ? Yii::app()->session['company_id'] : 0);
        $criteria->condition = "file.company_id=" . $comp_id;
        $criteria->order = "paid DESC";
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function generatereport() {
        $criteria = new CDbCriteria;
        $criteria->condition = "isActive   =   'Y'";
        if (isset($_POST['rp_from_date']) && isset($_POST['rp_to_date'])) {
            $criteria->condition .= ' AND invoice_date BETWEEN "' . $_POST['rp_from_date'] . '" AND "' . $_POST['rp_to_date'] . '"';
            if (isset($_POST['vendor_id']))
                $criteria->condition .= ' AND vendor_id in ( ' . $_POST['vendor_id'] . ')';
        }
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.id DESC, t.file_id DESC ,t.invoice_date DESC',
            ),
            'pagination' => array('pageSize' => 500)
        ));
    }


    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return PurchasingInvoice the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }
     public function getTotals($ids) {
        $ids = implode(",", $ids);
        $connection = Yii::app()->db;
        if (!empty($ids)) {
            $command = $connection->createCommand("SELECT SUM(grand_total) FROM `crm_purchasinginvoice` where id in ($ids)");
            return $command->queryScalar();
        }
        else
            return "";
    }

}
