<?php

/**
 * This is the model class for table "{{user}}".
 *
 * The followings are the available columns in table '{{user}}':
 * @property integer $id
 * @property string $username
 * @property string $password
 * @property string $isActive
 *
 * The followings are the available model relations:
 * @property Company[] $companies
 * @property CompanyContact[] $companyContacts
 * @property CreditNote[] $creditNotes
 * @property DeliveryNotes[] $deliveryNotes
 * @property GoodsReturn[] $goodsReturns
 * @property Invoice[] $invoices
 * @property Lead[] $leads
 * @property MasterFile[] $masterFiles
 * @property Order[] $orders
 * @property Quotes[] $quotes
 * @property Store $store
 */
class User extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{user}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('username,user_group_id,first_name,last_name,branch_id,email,phno, password', 'required'),
            array('username', 'unique', 'on' => 'add'),
            array('username, password, first_name, last_name, email, designation,user_group_id, auth_code', 'length', 'max' => 255),
            array('company_id, branch_id,  level', 'numerical'),
            array('isActive', 'length', 'max' => 1),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, username, password, isActive', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'own_company' => array(self::BELONGS_TO, 'MasCompany', 'company_id'),
            'companies' => array(self::HAS_MANY, 'Company', 'crm_user_id'),
            'companyContacts' => array(self::HAS_MANY, 'CompanyContact', 'crm_user_id'),
            'creditNotes' => array(self::HAS_MANY, 'CreditNote', 'crm_user_id'),
            'deliveryNotes' => array(self::HAS_MANY, 'DeliveryNotes', 'crm_user_id'),
            'goodsReturns' => array(self::HAS_MANY, 'GoodsReturn', 'crm_user_id'),
            'invoices' => array(self::HAS_MANY, 'Invoice', 'crm_user_id'),
            'leads' => array(self::HAS_MANY, 'Lead', 'crm_user_id'),
            'masterFiles' => array(self::HAS_MANY, 'MasterFile', 'crm_user_id'),
            'orders' => array(self::HAS_MANY, 'Order', 'crm_user_id'),
            'quotes' => array(self::HAS_MANY, 'Quotes', 'crm_user_id'),
            'store' => array(self::HAS_ONE, 'Store', 'id'),
            'ownBranch' => array(self::BELONGS_TO, 'MasCompanyBranch', 'branch_id'),
                //'userGroup' => array(self::BELONGS_TO, 'MasUserGroup', 'user_group_id')
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'username' => 'User Name',
            'password' => 'Password',
            'isActive' => 'Is Active',
            'user_group_id' => 'User Group ID',
            'phno' => 'Phone No.',
            'email' => 'E-mail'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.
        $desigantion = Yii::app()->request->getParam('desigantion');
        $criteria = new CDbCriteria;
        $criteria->addCondition('isActive="Y" AND id<>' . Yii::app()->user->id . ' AND  t.company_id=' . Yii::app()->user->master_user_company_id,
                /* t.branch_id=' . Yii::app()->user->master_user_branch_id, */ 'AND');
        if($desigantion){
            $criteria->addCondition('designation like "%' . $desigantion . '%"','AND');
        }
        return new CActiveDataProvider($this, array(
            'pagination' => array(
                'pageSize' => 25,
            ),
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.user_group_id ,t.username ASC',
            ),
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return User the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * Authenticates the password.
     * This is the 'authenticate' validator as declared in rules().
     */
    public function authenticate($attribute, $params) {
        if (!$this->hasErrors()) {
            $this->_identity = new UserIdentity($this->username, $this->password);
            if (!$this->_identity->authenticate())
                $this->addError('password', 'Incorrect username or password.');
        }
    }

    /**
     * Logs in the user using the given username and password in the model.
     * @return boolean whether login is successful
     */
    public function login() {
        if ($this->_identity === null) {
            $this->_identity = new UserIdentity($this->username, $this->password);
            $this->_identity->authenticate();
        }
        if ($this->_identity->errorCode === UserIdentity::ERROR_NONE) {
            $duration = $this->rememberMe ? 3600 * 24 * 30 : 0; // 30 days
            Yii::app()->user->login($this->_identity, $duration);
            return true;
        } else {
            return false;
        }
    }

    public function getFullname() {
        return ($this->first_name . ' ' . $this->last_name);
    }

    /* bfeore save function for password enecryption 
     * 
     */

    function beforeSave() {
        if (isset($_POST['User']['password']) && $_POST['User']['password'] != '')
            $this->password = crypt($_POST['User']['password'], $_POST['User']['password']);
        return true;
    }

    public static function getLeadOwners() {
        $condition = 'branch_id=' . Yii::app()->user->master_user_branch_id . ' AND isActive =  "Y"';
        $model = self::model()->findAll(array('condition' => $condition, 'order' => 't.first_name,t.username'));
        return CHtml::listData($model, 'id', 'fullname');
    }
    public static function getLeadOwnersForIncentiveCalc1() {
        if ((int) Yii::app()->user->havePermissionOn['other_reports_incentives_show_all']) {
            $condition = 'branch_id=' . Yii::app()->user->master_user_branch_id . ' AND isActive =  "Y"';
            $model = self::model()->findAll(array('condition' => $condition, 'order' => 't.first_name,t.username'));
            return  CHtml::dropDownList('incentive_lead_lead_owner', '', CHtml::listData($model, 'id', 'fullname'), array('prompt' => 'All',
                'class' => 'sales-group-search tooltipster', 'title' => 'Please select Lead Owner'));
        }
        else
            return self::model()->findByPK(Yii::app()->user->id)->fullname; 
    }
    
    public function getLeadOwnersForIncentiveCalc() {
        if ((int) Yii::app()->user->havePermissionOn['other_reports_incentives_show_all']) {
            $condition = 'branch_id=' . Yii::app()->user->master_user_branch_id . ' AND isActive =  "Y"';
            $model = self::model()->findAll(array('condition' => $condition, 'order' => 't.first_name,t.username'));
            return  CHtml::dropDownList('incentive_lead_lead_owner', '', CHtml::listData($model, 'id', 'fullname'), array('prompt' => 'All',
                'ajax' => array(
                            'type' => 'POST',
                            'dataType' => 'json',
                            'url' => CController::createUrl('site/FetchFilesByLeadowner'),
                            'success' => 'function(data){         
                              $("#incentive_file_id").html(data.files);
                             }',
                            'data' => array('leadowner' => 'js:this.value'),
                        ),
                'class' => 'sales-group-search tooltipster', 'title' => 'Please select Lead Owner'));
        }
        else
            return self::model()->findByPK(Yii::app()->user->id)->fullname; 
    }

    public static function getUser() {
        $condition = 'isActive =  "Y"';
        $model = self::model()->findAll(array('condition' => $condition, 'order' => 't.first_name,t.username'));
        return CHtml::listData($model, 'id', 'fullname');
    }
    public static function getUserDesignations() {
        $condition = 'isActive =  "Y"';
        $model = self::model()->findAll(array('select'=>'designation',
    
    'distinct'=>true,
));
        return CHtml::listData($model, 'designation', 'designation');
    }
   
    public static function getdepartmentName($id) {
       // $id  = $this->id;
        $model= PactDepartment::model()->findAll();
        foreach($model as $eachmodel){
            $user_ids = unserialize($eachmodel->user_ids);
            if(in_array($id,$user_ids)){
               $department_name .=  $eachmodel->department_name.',';
            }
        
        }
        
        return trim($department_name, ",");
     
    }
   

    public function renderUseGroup($data, $row) {
        $ugroups = MasUserGroup::model()->findAll('id in (' . $data->user_group_id . ')');
        foreach ($ugroups as $eachGp) {
            $ug[] = $eachGp->group_name;
        }
        return implode(',', $ug);
    }

    public function getSuperios() {
        $userGropups = MasUserGroup::model()->findAll('id in (' . $this->user_group_id . ')'); //parentGroup
        foreach ($userGropups as $eachUserGroup) {
            $users = User::model()->findAll('user_group_id in (' . $eachUserGroup->parent_id . ')');
            foreach ($users as $i => $eachUser) {
                $u[] = $eachUser;
            }
        }
        return $u;
    }

    public function getSubordinates() {
        $userGropups = MasUserGroup::subGroups($this->user_group_id); //parentGroup
        $u = array(Yii::app()->user->id);
        if (is_array($userGropups) && count($userGropups) > 0) {
            $users = User::model()->findAll('user_group_id in (' . (implode(',', $userGropups)) . ')');
            foreach ($users as $i => $eachUser) {
                $u[] = $eachUser->id;
            }
        }
        return $u;
    }
    
     public function report() {
       
        $criteria = new CDbCriteria;
        //$criteria->with = 'companyTypeRelation.companyType';
        
        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'sort' => array(
                'defaultOrder' => 't.username',
            ),
            'pagination' => false
        ));
    }

}
