<?php

/**
 * This is the model class for table "{{form_ho_general}}".
 *
 * The followings are the available columns in table '{{form_ho_general}}':
 * @property integer $id
 * @property integer $form_id
 * @property integer $file_id
 * @property integer $project_no
 * @property string $project_name
 * @property string $project_location
 * @property string $address
 * @property string $location
 * @property string $city
 * @property string $telephone
 * @property string $fax
 * @property string $email
 * @property string $direct_phone
 * @property integer $contact_id
 * @property string $date_of_ho
 * @property integer $sales_engr
 * @property string $notes
 */
class FormHoGeneral extends CActiveRecord {

    public $company;

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return '{{form_ho_general}}';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('contract_value,currency_id,file_id, project_name, project_location, address, city, telephone, email, contact_id, date_of_ho, sales_engr, notes', 'required'),
            array('form_id, file_id, project_no, contact_id, sales_engr', 'numerical', 'integerOnly' => true),
            array('project_name, project_location, location, city, email', 'length', 'max' => 255),
            array('telephone, fax, direct_phone', 'length', 'max' => 15),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, form_id, file_id, project_no, project_name, project_location, address, location, city, telephone, fax, email, direct_phone, contact_id, date_of_ho, sales_engr, notes', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'contact' => array(self::BELONGS_TO, 'CompanyContact', 'contact_id'),
            'file' => array(self::BELONGS_TO, 'MasterFile', 'file_id'),
            'formHoType' => array(self::HAS_ONE, 'FormHoType', 'form_ho_id'),
            'formHoScope' => array(self::HAS_ONE, 'FormHoScope', 'form_ho_id'),
            'formHoDelivery' => array(self::HAS_ONE, 'FormHoDelivery', 'form_ho_id'),
            'currency' => array(self::BELONGS_TO, 'MasCurrency', 'currency_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'company' => 'Client',
            'form_id' => 'Form',
            'file_id' => 'File',
            'project_no' => 'Project No',
            'project_name' => 'Project Name',
            'project_location' => 'Project Location',
            'address' => 'Address',
            'location' => 'Location',
            'city' => 'City',
            'telephone' => 'Telephone',
            'fax' => 'Fax',
            'email' => 'Email',
            'direct_phone' => 'Direct Phone',
            'contact_id' => 'Contact',
            'date_of_ho' => 'Date Of HOR.',
            'sales_engr' => 'Sales Engr',
            'notes' => 'Notes',
            'currency_id' => 'Currency',
            'contract_value' => 'Contract Value'
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search($searchterm = null) {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;
        $Dpt_ids = array();
        $file_ids = array();
        $file_id = array();

        $approvalModel = FormApproval::model()->findAll(array('condition' => 'form_id=11'));
        $notification = Notification::model()->findAll(array('condition' => 'form_id=11'));
        foreach ($notification as $eachnotifcation) {
            $Dpt_id = unserialize(PactDepartment::model()->find(array('condition' => 'id=' . $eachnotifcation->level))->user_ids);
            if (in_array(Yii::app()->user->id, $Dpt_id))
                $file_id[] = $eachnotifcation->file_id;
            $Dpt_ids = array_merge($Dpt_ids, array_unique($Dpt_id));
        }
        $temp_userids = array();
        foreach ($approvalModel as $eachApproval) {
            if ($eachApproval->arrived_req_for_approval !== "N")
                $temp = unserialize(FormPermission::model()->find(array('condition' => 'form_id=11 AND level=' . (int) $eachApproval->level))->user_id);
            /* else
              $temp = unserialize(PactDepartment::model()->find(array('condition' => 'id='.$eachApproval->level))->user_ids); */
            if (is_array($temp))
                $temp_userids = array_merge($temp_userids, $temp);
        }

        $file_ids = array_unique($file_id);
        $Dpt_ids = array_unique($Dpt_ids);
        $temp_userid = array_unique($temp_userids);

        //$file_ids = implode(',', array_unique($file_ids));
        $query = "DROP TABLE if exists TempFileId;";
        $query .= "CREATE TEMPORARY TABLE TempFileId ( file_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8;";
        Yii::app()->db->createCommand($query)->execute();
        foreach ($file_ids as $eachfile_id) {
            $query = "INSERT INTO TempFileId VALUES( '$eachfile_id','11')";
            Yii::app()->db->createCommand($query)->execute();
        }


        $temp_userids = implode(',', array_unique($temp_userids));
        $query = "DROP TABLE if exists TempFormApTable;";
        $query .= "CREATE TEMPORARY TABLE TempFormApTable ( user_id varchar(255),form_id int ) engine=HEAP  DEFAULT CHARSET=utf8";
        $query .= "; INSERT INTO TempFormApTable VALUES( '$temp_userids','11')";
        Yii::app()->db->createCommand($query)->execute();

        if (in_array(Yii::app()->user->id, $Dpt_ids) && in_array(Yii::app()->user->id, $temp_userid) || in_array(Yii::app()->user->id, $temp_userid)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('hor_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //(int) Yii::app()->session['company_id'] > 0 ? $criteria->addCondition('t.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
        } else if (in_array(Yii::app()->user->id, $Dpt_ids)) {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('hor_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFileId tf ON tf.file_id = t.file_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('t.file_id IN (tf.file_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
            //$criteria->addCondition('file.lead_owner_id=' . Yii::app()->user->id, 'OR');
            //$criteria->addCondition('t.file_id IN (tf.file_id)','AND');
            
        } else {
            $searchterm = empty($searchterm) ? trim(Yii::app()->request->getParam('hor_search')) : $searchterm;
            $criteria->with = array('file', 'file.company', 'file.leadowner');
            $criteria->join = 'LEFT JOIN TempFormApTable tft ON tft.form_id = t.form_id';
            $criteria->addCondition('file.own_company_id=' . Yii::app()->user->master_user_company_id, 'AND');
            $criteria->addCondition('file.own_branch_id=' . Yii::app()->user->master_user_branch_id, 'AND');
            $criteria->addCondition('FIND_IN_SET(' . Yii::app()->user->id . ', tft.user_id) OR file.lead_owner_id=' . Yii::app()->user->id, 'AND');
        }
        if (!empty($searchterm)) {
            $criteria->addCondition('   t.id like "%' . $searchterm . '%" OR 
                                        t.file_id like "%' . $searchterm . '%" OR 
                                        company.company_name like "%' . $searchterm . '%" OR 
                                        file.file_title like "%' . $searchterm . '%"', 'AND');
        }

        if (empty($searchterm)) {
            ((int) Yii::app()->session['company_id'] > 0) ? $criteria->addCondition('file.company_id=' . Yii::app()->session['company_id'], 'AND') : '';
            $criteria->addCondition('file.current_process_status="HOR"', 'AND');
        }

        $criteria->order = "t.id DESC";
        /* $criteria = new CDbCriteria;
          $criteria->compare('id', $this->id);
          $criteria->compare('form_id', $this->form_id);
          $criteria->compare('file_id', $this->file_id);
          $criteria->compare('project_no', $this->project_no);
          $criteria->compare('project_name', $this->project_name, true);
          $criteria->compare('project_location', $this->project_location, true);
          $criteria->compare('address', $this->address, true);
          $criteria->compare('location', $this->location, true);
          $criteria->compare('city', $this->city, true);
          $criteria->compare('telephone', $this->telephone, true);
          $criteria->compare('fax', $this->fax, true);
          $criteria->compare('email', $this->email, true);
          $criteria->compare('direct_phone', $this->direct_phone, true);
          $criteria->compare('contact_id', $this->contact_id);
          $criteria->compare('date_of_ho', $this->date_of_ho, true);
          $criteria->compare('sales_engr', $this->sales_engr);
          $criteria->compare('notes', $this->notes, true); */

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    public function getProject() {
        if ((int) $this->project_no > 0)
            $proj[] = $this->project_no;
        $proj[] = $this->project_name;
        //$proj[]=$this->project_location;
        //$proj[]=$model->project_no;
        return implode("\n", $proj);
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return FormHoGeneral the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    public function getColor() {
        return MasterFile::getColor($this->form_id, $this->file_id);
    }
    public function getFileApprovalStatus() {
        $history = FormApproval::model()->findAll(array('condition' => 'file_id=' . $this->file_id.' and form_id='.$this->form_id, 'order' => 'id asc'));
        $maxLevel = Yii::app()->db->createCommand()
                    ->select('max(level)')
                    ->from('crm_form_permission')
                    ->where('form_id= 11')
                    ->queryScalar();
        $html = array();
        if (is_array($history))
            foreach ($history as $eachHistory) {
                $html[] = (($eachHistory->arrived_req_for_approval != "Y") ?
                                ($eachHistory->is_approved == "Y" ? "Approved" : "Rejecetd") :
                                "Approval requested") . " by " . $eachHistory->user->fullName . " at " . (($eachHistory->arrived_req_for_approval != "Y") ? $eachHistory->date_of_approval : $eachHistory->date_of_approval).
                                 (($eachHistory->notes != "" && $eachHistory->level==$maxLevel) ? ("(".$eachHistory->notes.")".'<br/><strong>'."(Approved by General Manager)".'</strong>') : "(".$eachHistory->notes.")");
           
            }
        return implode('<br/>', $html);
    }

}
